Class: Google::Cloud::Dataproc::V1::AutoscalingPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/autoscaling_policies.rb

Overview

Describes an autoscaling policy for Dataproc cluster autoscaler.

Defined Under Namespace

Modules: ClusterType Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#basic_algorithm::Google::Cloud::Dataproc::V1::BasicAutoscalingAlgorithm



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'proto_docs/google/cloud/dataproc/v1/autoscaling_policies.rb', line 65

class AutoscalingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the clusters for which this autoscaling policy is to be
  # configured.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 2
  end
end

#cluster_type::Google::Cloud::Dataproc::V1::AutoscalingPolicy::ClusterType

Returns Optional. The type of the clusters for which this autoscaling policy is to be configured.

Returns:



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'proto_docs/google/cloud/dataproc/v1/autoscaling_policies.rb', line 65

class AutoscalingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the clusters for which this autoscaling policy is to be
  # configured.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 2
  end
end

#id::String

Returns Required. The policy id.

The id must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). Cannot begin or end with underscore or hyphen. Must consist of between 3 and 50 characters.

Returns:

  • (::String)

    Required. The policy id.

    The id must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). Cannot begin or end with underscore or hyphen. Must consist of between 3 and 50 characters.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'proto_docs/google/cloud/dataproc/v1/autoscaling_policies.rb', line 65

class AutoscalingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the clusters for which this autoscaling policy is to be
  # configured.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 2
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. The labels to associate with this autoscaling policy. Label keys must contain 1 to 63 characters, and must conform to RFC 1035. Label values may be empty, but, if present, must contain 1 to 63 characters, and must conform to RFC 1035. No more than 32 labels can be associated with an autoscaling policy.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. The labels to associate with this autoscaling policy. Label keys must contain 1 to 63 characters, and must conform to RFC 1035. Label values may be empty, but, if present, must contain 1 to 63 characters, and must conform to RFC 1035. No more than 32 labels can be associated with an autoscaling policy.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'proto_docs/google/cloud/dataproc/v1/autoscaling_policies.rb', line 65

class AutoscalingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the clusters for which this autoscaling policy is to be
  # configured.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 2
  end
end

#name::String (readonly)

Returns Output only. The "resource name" of the autoscaling policy, as described in https://cloud.google.com/apis/design/resource_names.

  • For projects.regions.autoscalingPolicies, the resource name of the policy has the following format: projects/{project_id}/regions/{region}/autoscalingPolicies/{policy_id}

  • For projects.locations.autoscalingPolicies, the resource name of the policy has the following format: projects/{project_id}/locations/{location}/autoscalingPolicies/{policy_id}.

Returns:

  • (::String)

    Output only. The "resource name" of the autoscaling policy, as described in https://cloud.google.com/apis/design/resource_names.

    • For projects.regions.autoscalingPolicies, the resource name of the policy has the following format: projects/{project_id}/regions/{region}/autoscalingPolicies/{policy_id}

    • For projects.locations.autoscalingPolicies, the resource name of the policy has the following format: projects/{project_id}/locations/{location}/autoscalingPolicies/{policy_id}



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'proto_docs/google/cloud/dataproc/v1/autoscaling_policies.rb', line 65

class AutoscalingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the clusters for which this autoscaling policy is to be
  # configured.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 2
  end
end

#secondary_worker_config::Google::Cloud::Dataproc::V1::InstanceGroupAutoscalingPolicyConfig

Returns Optional. Describes how the autoscaler will operate for secondary workers.

Returns:



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'proto_docs/google/cloud/dataproc/v1/autoscaling_policies.rb', line 65

class AutoscalingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the clusters for which this autoscaling policy is to be
  # configured.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 2
  end
end

#worker_config::Google::Cloud::Dataproc::V1::InstanceGroupAutoscalingPolicyConfig

Returns Required. Describes how the autoscaler will operate for primary workers.

Returns:



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'proto_docs/google/cloud/dataproc/v1/autoscaling_policies.rb', line 65

class AutoscalingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the clusters for which this autoscaling policy is to be
  # configured.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 2
  end
end