Class: Google::Cloud::Dataproc::V1::AutoscalingPolicyService::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::AutoscalingPolicyService::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/dataproc/v1/autoscaling_policy_service/client.rb
Overview
Client for the AutoscalingPolicyService service.
The API interface for managing autoscaling policies in the Dataproc API.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Client
readonly
Get the associated client for mix-in of the IAMPolicy.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the AutoscalingPolicyService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the AutoscalingPolicyService Client instance.
-
#create_autoscaling_policy(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy
Creates new autoscaling policy.
-
#delete_autoscaling_policy(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes an autoscaling policy.
-
#get_autoscaling_policy(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy
Retrieves autoscaling policy.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new AutoscalingPolicyService client object.
-
#list_autoscaling_policies(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataproc::V1::AutoscalingPolicy>
Lists autoscaling policies in the project.
-
#update_autoscaling_policy(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy
Updates (replaces) autoscaling policy.
Methods included from Paths
#autoscaling_policy_path, #location_path, #region_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new AutoscalingPolicyService client object.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/client.rb', line 130 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/dataproc/v1/autoscaling_policies_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-") credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @iam_policy_client = Google::Iam::V1::IAMPolicy::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint end @autoscaling_policy_service_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::Dataproc::V1::AutoscalingPolicyService::Stub, credentials: credentials, endpoint: @config.endpoint, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool ) end |
Instance Attribute Details
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Client (readonly)
Get the associated client for mix-in of the IAMPolicy.
178 179 180 |
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/client.rb', line 178 def iam_policy_client @iam_policy_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the AutoscalingPolicyService Client class.
See Configuration for a description of the configuration fields.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/client.rb', line 58 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Dataproc", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.create_autoscaling_policy.timeout = 600.0 default_config.rpcs.update_autoscaling_policy.timeout = 600.0 default_config.rpcs.update_autoscaling_policy.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.get_autoscaling_policy.timeout = 600.0 default_config.rpcs.get_autoscaling_policy.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.list_autoscaling_policies.timeout = 600.0 default_config.rpcs.list_autoscaling_policies.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.delete_autoscaling_policy.timeout = 600.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the AutoscalingPolicyService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
109 110 111 112 |
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/client.rb', line 109 def configure yield @config if block_given? @config end |
#create_autoscaling_policy(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy #create_autoscaling_policy(parent: nil, policy: nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy
Creates new autoscaling policy.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/client.rb', line 237 def create_autoscaling_policy request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::CreateAutoscalingPolicyRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_autoscaling_policy..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_autoscaling_policy.timeout, metadata: , retry_policy: @config.rpcs.create_autoscaling_policy.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @autoscaling_policy_service_stub.call_rpc :create_autoscaling_policy, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_autoscaling_policy(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_autoscaling_policy(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes an autoscaling policy. It is an error to delete an autoscaling policy that is in use by one or more clusters.
619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/client.rb', line 619 def delete_autoscaling_policy request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::DeleteAutoscalingPolicyRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_autoscaling_policy..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_autoscaling_policy.timeout, metadata: , retry_policy: @config.rpcs.delete_autoscaling_policy.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @autoscaling_policy_service_stub.call_rpc :delete_autoscaling_policy, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_autoscaling_policy(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy #get_autoscaling_policy(name: nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy
Retrieves autoscaling policy.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/client.rb', line 419 def get_autoscaling_policy request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::GetAutoscalingPolicyRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_autoscaling_policy..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_autoscaling_policy.timeout, metadata: , retry_policy: @config.rpcs.get_autoscaling_policy.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @autoscaling_policy_service_stub.call_rpc :get_autoscaling_policy, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_autoscaling_policies(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataproc::V1::AutoscalingPolicy> #list_autoscaling_policies(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataproc::V1::AutoscalingPolicy>
Lists autoscaling policies in the project.
523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 |
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/client.rb', line 523 def list_autoscaling_policies request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::ListAutoscalingPoliciesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_autoscaling_policies..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_autoscaling_policies.timeout, metadata: , retry_policy: @config.rpcs.list_autoscaling_policies.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @autoscaling_policy_service_stub.call_rpc :list_autoscaling_policies, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @autoscaling_policy_service_stub, :list_autoscaling_policies, request, response, operation, yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#update_autoscaling_policy(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy #update_autoscaling_policy(policy: nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy
Updates (replaces) autoscaling policy.
Disabled check for update_mask, because all updates will be full replacements.
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/client.rb', line 325 def update_autoscaling_policy request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::UpdateAutoscalingPolicyRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_autoscaling_policy..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.policy&.name header_params["policy.name"] = request.policy.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_autoscaling_policy.timeout, metadata: , retry_policy: @config.rpcs.update_autoscaling_policy.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @autoscaling_policy_service_stub.call_rpc :update_autoscaling_policy, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |