Class: Google::Cloud::Dataproc::V1::AutoscalingPolicyService::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/dataproc/v1/autoscaling_policy_service/rest/client.rb

Overview

REST client for the AutoscalingPolicyService service.

The API interface for managing autoscaling policies in the Dataproc API.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#autoscaling_policy_path, #location_path, #region_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new AutoscalingPolicyService REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Dataproc::V1::AutoscalingPolicyService::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Dataproc::V1::AutoscalingPolicyService::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the AutoscalingPolicyService client.

Yield Parameters:



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/rest/client.rb', line 132

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-")
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @iam_policy_client = Google::Iam::V1::IAMPolicy::Rest::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @config.endpoint
    config.bindings_override = @config.bindings_override
  end

  @autoscaling_policy_service_stub = ::Google::Cloud::Dataproc::V1::AutoscalingPolicyService::Rest::ServiceStub.new endpoint: @config.endpoint, credentials: credentials
end

Instance Attribute Details

#iam_policy_clientGoogle::Iam::V1::IAMPolicy::Rest::Client (readonly)

Get the associated client for mix-in of the IAMPolicy.

Returns:

  • (Google::Iam::V1::IAMPolicy::Rest::Client)


169
170
171
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/rest/client.rb', line 169

def iam_policy_client
  @iam_policy_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the AutoscalingPolicyService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all AutoscalingPolicyService clients
::Google::Cloud::Dataproc::V1::AutoscalingPolicyService::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/rest/client.rb', line 60

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Dataproc", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.create_autoscaling_policy.timeout = 600.0

    default_config.rpcs.update_autoscaling_policy.timeout = 600.0
    default_config.rpcs.update_autoscaling_policy.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14]
    }

    default_config.rpcs.get_autoscaling_policy.timeout = 600.0
    default_config.rpcs.get_autoscaling_policy.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14]
    }

    default_config.rpcs.list_autoscaling_policies.timeout = 600.0
    default_config.rpcs.list_autoscaling_policies.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14]
    }

    default_config.rpcs.delete_autoscaling_policy.timeout = 600.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the AutoscalingPolicyService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



111
112
113
114
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/rest/client.rb', line 111

def configure
  yield @config if block_given?
  @config
end

#create_autoscaling_policy(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy #create_autoscaling_policy(parent: nil, policy: nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy

Creates new autoscaling policy.

Examples:

Basic example

require "google/cloud/dataproc/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dataproc::V1::AutoscalingPolicyService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dataproc::V1::CreateAutoscalingPolicyRequest.new

# Call the create_autoscaling_policy method.
result = client.create_autoscaling_policy request

# The returned object is of type Google::Cloud::Dataproc::V1::AutoscalingPolicy.
p result

Overloads:

  • #create_autoscaling_policy(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy

    Pass arguments to create_autoscaling_policy via a request object, either of type CreateAutoscalingPolicyRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::CreateAutoscalingPolicyRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_autoscaling_policy(parent: nil, policy: nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy

    Pass arguments to create_autoscaling_policy via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The "resource name" of the region or location, as described in https://cloud.google.com/apis/design/resource_names.

      • For projects.regions.autoscalingPolicies.create, the resource name of the region has the following format: projects/{project_id}/regions/{region}

      • For projects.locations.autoscalingPolicies.create, the resource name of the location has the following format: projects/{project_id}/locations/{location}

    • policy (::Google::Cloud::Dataproc::V1::AutoscalingPolicy, ::Hash) (defaults to: nil)

      Required. The autoscaling policy to create.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/rest/client.rb', line 227

def create_autoscaling_policy request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::CreateAutoscalingPolicyRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_autoscaling_policy..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_autoscaling_policy.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_autoscaling_policy.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @autoscaling_policy_service_stub.create_autoscaling_policy request, options do |result, operation|
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_autoscaling_policy(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_autoscaling_policy(name: nil) ⇒ ::Google::Protobuf::Empty

Deletes an autoscaling policy. It is an error to delete an autoscaling policy that is in use by one or more clusters.

Examples:

Basic example

require "google/cloud/dataproc/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dataproc::V1::AutoscalingPolicyService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dataproc::V1::DeleteAutoscalingPolicyRequest.new

# Call the delete_autoscaling_policy method.
result = client.delete_autoscaling_policy request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_autoscaling_policy(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_autoscaling_policy via a request object, either of type DeleteAutoscalingPolicyRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::DeleteAutoscalingPolicyRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #delete_autoscaling_policy(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_autoscaling_policy via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The "resource name" of the autoscaling policy, as described in https://cloud.google.com/apis/design/resource_names.

      • For projects.regions.autoscalingPolicies.delete, the resource name of the policy has the following format: projects/{project_id}/regions/{region}/autoscalingPolicies/{policy_id}

      • For projects.locations.autoscalingPolicies.delete, the resource name of the policy has the following format: projects/{project_id}/locations/{location}/autoscalingPolicies/{policy_id}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/rest/client.rb', line 581

def delete_autoscaling_policy request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::DeleteAutoscalingPolicyRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_autoscaling_policy..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete_autoscaling_policy.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_autoscaling_policy.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @autoscaling_policy_service_stub.delete_autoscaling_policy request, options do |result, operation|
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_autoscaling_policy(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy #get_autoscaling_policy(name: nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy

Retrieves autoscaling policy.

Examples:

Basic example

require "google/cloud/dataproc/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dataproc::V1::AutoscalingPolicyService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dataproc::V1::GetAutoscalingPolicyRequest.new

# Call the get_autoscaling_policy method.
result = client.get_autoscaling_policy request

# The returned object is of type Google::Cloud::Dataproc::V1::AutoscalingPolicy.
p result

Overloads:

  • #get_autoscaling_policy(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy

    Pass arguments to get_autoscaling_policy via a request object, either of type GetAutoscalingPolicyRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::GetAutoscalingPolicyRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_autoscaling_policy(name: nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy

    Pass arguments to get_autoscaling_policy via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The "resource name" of the autoscaling policy, as described in https://cloud.google.com/apis/design/resource_names.

      • For projects.regions.autoscalingPolicies.get, the resource name of the policy has the following format: projects/{project_id}/regions/{region}/autoscalingPolicies/{policy_id}

      • For projects.locations.autoscalingPolicies.get, the resource name of the policy has the following format: projects/{project_id}/locations/{location}/autoscalingPolicies/{policy_id}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/rest/client.rb', line 395

def get_autoscaling_policy request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::GetAutoscalingPolicyRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_autoscaling_policy..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_autoscaling_policy.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_autoscaling_policy.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @autoscaling_policy_service_stub.get_autoscaling_policy request, options do |result, operation|
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_autoscaling_policies(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dataproc::V1::AutoscalingPolicy> #list_autoscaling_policies(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dataproc::V1::AutoscalingPolicy>

Lists autoscaling policies in the project.

Examples:

Basic example

require "google/cloud/dataproc/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dataproc::V1::AutoscalingPolicyService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dataproc::V1::ListAutoscalingPoliciesRequest.new

# Call the list_autoscaling_policies method.
result = client.list_autoscaling_policies request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Dataproc::V1::AutoscalingPolicy.
  p item
end

Overloads:

  • #list_autoscaling_policies(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dataproc::V1::AutoscalingPolicy>

    Pass arguments to list_autoscaling_policies via a request object, either of type ListAutoscalingPoliciesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::ListAutoscalingPoliciesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_autoscaling_policies(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dataproc::V1::AutoscalingPolicy>

    Pass arguments to list_autoscaling_policies via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The "resource name" of the region or location, as described in https://cloud.google.com/apis/design/resource_names.

      • For projects.regions.autoscalingPolicies.list, the resource name of the region has the following format: projects/{project_id}/regions/{region}

      • For projects.locations.autoscalingPolicies.list, the resource name of the location has the following format: projects/{project_id}/locations/{location}

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of results to return in each response. Must be less than or equal to 1000. Defaults to 100.

    • page_token (::String) (defaults to: nil)

      Optional. The page token, returned by a previous call, to request the next page of results.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/rest/client.rb', line 492

def list_autoscaling_policies request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::ListAutoscalingPoliciesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_autoscaling_policies..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_autoscaling_policies.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_autoscaling_policies.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @autoscaling_policy_service_stub.list_autoscaling_policies request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @autoscaling_policy_service_stub, :list_autoscaling_policies, "policies", request, result, options
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#update_autoscaling_policy(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy #update_autoscaling_policy(policy: nil) ⇒ ::Google::Cloud::Dataproc::V1::AutoscalingPolicy

Updates (replaces) autoscaling policy.

Disabled check for update_mask, because all updates will be full replacements.

Examples:

Basic example

require "google/cloud/dataproc/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dataproc::V1::AutoscalingPolicyService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dataproc::V1::UpdateAutoscalingPolicyRequest.new

# Call the update_autoscaling_policy method.
result = client.update_autoscaling_policy request

# The returned object is of type Google::Cloud::Dataproc::V1::AutoscalingPolicy.
p result

Overloads:

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/google/cloud/dataproc/v1/autoscaling_policy_service/rest/client.rb', line 308

def update_autoscaling_policy request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::UpdateAutoscalingPolicyRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_autoscaling_policy..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_autoscaling_policy.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_autoscaling_policy.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @autoscaling_policy_service_stub.update_autoscaling_policy request, options do |result, operation|
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end