Class: Google::Cloud::Dataproc::V1::Cluster

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/clusters.rb

Overview

Describes the identifying information, config, and status of a Dataproc cluster

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_name::String

Returns Required. The cluster name. Cluster names within a project must be unique. Names of deleted clusters can be reused.

Returns:

  • (::String)

    Required. The cluster name. Cluster names within a project must be unique. Names of deleted clusters can be reused.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 72

class Cluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#cluster_uuid::String (readonly)

Returns Output only. A cluster UUID (Unique Universal Identifier). Dataproc generates this value when it creates the cluster.

Returns:

  • (::String)

    Output only. A cluster UUID (Unique Universal Identifier). Dataproc generates this value when it creates the cluster.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 72

class Cluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#config::Google::Cloud::Dataproc::V1::ClusterConfig

Returns Optional. The cluster config for a cluster of Compute Engine Instances. Note that Dataproc may set default values, and values may change when clusters are updated.

Returns:



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 72

class Cluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. The labels to associate with this cluster. Label keys must contain 1 to 63 characters, and must conform to RFC 1035. Label values may be empty, but, if present, must contain 1 to 63 characters, and must conform to RFC 1035. No more than 32 labels can be associated with a cluster.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. The labels to associate with this cluster. Label keys must contain 1 to 63 characters, and must conform to RFC 1035. Label values may be empty, but, if present, must contain 1 to 63 characters, and must conform to RFC 1035. No more than 32 labels can be associated with a cluster.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 72

class Cluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#metrics::Google::Cloud::Dataproc::V1::ClusterMetrics (readonly)

Returns Output only. Contains cluster daemon metrics such as HDFS and YARN stats.

Beta Feature: This report is available for testing purposes only. It may be changed before final release.

Returns:

  • (::Google::Cloud::Dataproc::V1::ClusterMetrics)

    Output only. Contains cluster daemon metrics such as HDFS and YARN stats.

    Beta Feature: This report is available for testing purposes only. It may be changed before final release.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 72

class Cluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#project_id::String

Returns Required. The Google Cloud Platform project ID that the cluster belongs to.

Returns:

  • (::String)

    Required. The Google Cloud Platform project ID that the cluster belongs to.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 72

class Cluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#status::Google::Cloud::Dataproc::V1::ClusterStatus (readonly)

Returns Output only. Cluster status.

Returns:



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 72

class Cluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#status_history::Array<::Google::Cloud::Dataproc::V1::ClusterStatus> (readonly)

Returns Output only. The previous cluster status.

Returns:



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 72

class Cluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#virtual_cluster_config::Google::Cloud::Dataproc::V1::VirtualClusterConfig

Returns Optional. The virtual cluster config, used when creating a Dataproc cluster that does not directly control the underlying compute resources, for example, when creating a Dataproc-on-GKE cluster. Note that Dataproc may set default values, and values may change when clusters are updated. Exactly one of config or virtualClusterConfig must be specified.

Returns:

  • (::Google::Cloud::Dataproc::V1::VirtualClusterConfig)

    Optional. The virtual cluster config, used when creating a Dataproc cluster that does not directly control the underlying compute resources, for example, when creating a Dataproc-on-GKE cluster. Note that Dataproc may set default values, and values may change when clusters are updated. Exactly one of config or virtualClusterConfig must be specified.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 72

class Cluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end