Class: Google::Cloud::Dataproc::V1::ClusterConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/clusters.rb

Overview

The cluster config.

Defined Under Namespace

Modules: ClusterTier, ClusterType, Engine

Instance Attribute Summary collapse

Instance Attribute Details

#autoscaling_config::Google::Cloud::Dataproc::V1::AutoscalingConfig

Returns Optional. Autoscaling config for the policy associated with the cluster. Cluster does not autoscale if this field is unset.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#auxiliary_node_groups::Array<::Google::Cloud::Dataproc::V1::AuxiliaryNodeGroup>

Returns Optional. The node group settings.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#cluster_tier::Google::Cloud::Dataproc::V1::ClusterConfig::ClusterTier

Returns Optional. The cluster tier.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#cluster_type::Google::Cloud::Dataproc::V1::ClusterConfig::ClusterType

Returns Optional. The type of the cluster.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#config_bucket::String

Returns Optional. A Cloud Storage bucket used to stage job dependencies, config files, and job driver console output. If you do not specify a staging bucket, Cloud Dataproc will determine a Cloud Storage location (US, ASIA, or EU) for your cluster's staging bucket according to the Compute Engine zone where your cluster is deployed, and then create and manage this project-level, per-location bucket (see Dataproc staging and temp buckets). This field requires a Cloud Storage bucket name, not a gs://... URI to a Cloud Storage bucket..

Returns:

  • (::String)

    Optional. A Cloud Storage bucket used to stage job dependencies, config files, and job driver console output. If you do not specify a staging bucket, Cloud Dataproc will determine a Cloud Storage location (US, ASIA, or EU) for your cluster's staging bucket according to the Compute Engine zone where your cluster is deployed, and then create and manage this project-level, per-location bucket (see Dataproc staging and temp buckets). This field requires a Cloud Storage bucket name, not a gs://... URI to a Cloud Storage bucket.



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#dataproc_metric_config::Google::Cloud::Dataproc::V1::DataprocMetricConfig

Returns Optional. The config for Dataproc metrics.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#encryption_config::Google::Cloud::Dataproc::V1::EncryptionConfig

Returns Optional. Encryption settings for the cluster.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#endpoint_config::Google::Cloud::Dataproc::V1::EndpointConfig

Returns Optional. Port/endpoint configuration for this cluster.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#engine::Google::Cloud::Dataproc::V1::ClusterConfig::Engine

Returns Optional. The cluster engine.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#gce_cluster_config::Google::Cloud::Dataproc::V1::GceClusterConfig

Returns Optional. The shared Compute Engine config settings for all instances in a cluster.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#initialization_actions::Array<::Google::Cloud::Dataproc::V1::NodeInitializationAction>

Returns Optional. Commands to execute on each node after config is completed. By default, executables are run on master and all worker nodes. You can test a node's role metadata to run an executable on a master or worker node, as shown below using curl (you can also use wget):

ROLE=$(curl -H Metadata-Flavor:Google
http://metadata/computeMetadata/v1/instance/attributes/dataproc-role)
if [[ "${ROLE}" == 'Master' ]]; then
  ... master specific actions ...
else
  ... worker specific actions ...
fi.

Returns:

  • (::Array<::Google::Cloud::Dataproc::V1::NodeInitializationAction>)

    Optional. Commands to execute on each node after config is completed. By default, executables are run on master and all worker nodes. You can test a node's role metadata to run an executable on a master or worker node, as shown below using curl (you can also use wget):

    ROLE=$(curl -H Metadata-Flavor:Google
    http://metadata/computeMetadata/v1/instance/attributes/dataproc-role)
    if [[ "${ROLE}" == 'Master' ]]; then
      ... master specific actions ...
    else
      ... worker specific actions ...
    fi
    


187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#lifecycle_config::Google::Cloud::Dataproc::V1::LifecycleConfig

Returns Optional. Lifecycle setting for the cluster.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#master_config::Google::Cloud::Dataproc::V1::InstanceGroupConfig

Returns Optional. The Compute Engine config settings for the cluster's master instance.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#metastore_config::Google::Cloud::Dataproc::V1::MetastoreConfig

Returns Optional. Metastore configuration.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#secondary_worker_config::Google::Cloud::Dataproc::V1::InstanceGroupConfig

Returns Optional. The Compute Engine config settings for a cluster's secondary worker instances.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#security_config::Google::Cloud::Dataproc::V1::SecurityConfig

Returns Optional. Security settings for the cluster.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#software_config::Google::Cloud::Dataproc::V1::SoftwareConfig

Returns Optional. The config settings for cluster software.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#temp_bucket::String

Returns Optional. A Cloud Storage bucket used to store ephemeral cluster and jobs data, such as Spark and MapReduce history files. If you do not specify a temp bucket, Dataproc will determine a Cloud Storage location (US, ASIA, or EU) for your cluster's temp bucket according to the Compute Engine zone where your cluster is deployed, and then create and manage this project-level, per-location bucket. The default bucket has a TTL of 90 days, but you can use any TTL (or none) if you specify a bucket (see Dataproc staging and temp buckets). This field requires a Cloud Storage bucket name, not a gs://... URI to a Cloud Storage bucket..

Returns:

  • (::String)

    Optional. A Cloud Storage bucket used to store ephemeral cluster and jobs data, such as Spark and MapReduce history files. If you do not specify a temp bucket, Dataproc will determine a Cloud Storage location (US, ASIA, or EU) for your cluster's temp bucket according to the Compute Engine zone where your cluster is deployed, and then create and manage this project-level, per-location bucket. The default bucket has a TTL of 90 days, but you can use any TTL (or none) if you specify a bucket (see Dataproc staging and temp buckets). This field requires a Cloud Storage bucket name, not a gs://... URI to a Cloud Storage bucket.



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end

#worker_config::Google::Cloud::Dataproc::V1::InstanceGroupConfig

Returns Optional. The Compute Engine config settings for the cluster's worker instances.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 187

class ClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the cluster.
  module ClusterType
    # Not set.
    CLUSTER_TYPE_UNSPECIFIED = 0

    # Standard dataproc cluster with a minimum of two primary workers.
    STANDARD = 1

    # https://cloud.google.com/dataproc/docs/concepts/configuring-clusters/single-node-clusters
    SINGLE_NODE = 2

    # Clusters that can use only secondary workers and be scaled down to zero
    # secondary worker nodes.
    ZERO_SCALE = 3
  end

  # The cluster tier.
  module ClusterTier
    # Not set. Works the same as CLUSTER_TIER_STANDARD.
    CLUSTER_TIER_UNSPECIFIED = 0

    # Standard Dataproc cluster.
    CLUSTER_TIER_STANDARD = 1

    # Premium Dataproc cluster.
    CLUSTER_TIER_PREMIUM = 2
  end

  # The cluster engine.
  module Engine
    # The engine is not specified. Works the same as ENGINE_DEFAULT.
    ENGINE_UNSPECIFIED = 0

    # The cluster is a default engine cluster.
    DEFAULT = 1

    # The cluster is a lightning engine cluster.
    LIGHTNING = 2
  end
end