Class: Google::Cloud::Dataproc::V1::ClusterController::Rest::ServiceStub

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/dataproc/v1/cluster_controller/rest/service_stub.rb

Overview

REST service stub for the ClusterController service. Service stub contains baseline method implementations including transcoding, making the REST call, and deserialing the response.

Instance Method Summary collapse

Constructor Details

#initialize(endpoint:, endpoint_template:, universe_domain:, credentials:) ⇒ ServiceStub

Returns a new instance of ServiceStub.



33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/service_stub.rb', line 33

def initialize endpoint:, endpoint_template:, universe_domain:, credentials:
  # These require statements are intentionally placed here to initialize
  # the REST modules only when it's required.
  require "gapic/rest"

  @client_stub = ::Gapic::Rest::ClientStub.new endpoint: endpoint,
                                               endpoint_template: endpoint_template,
                                               universe_domain: universe_domain,
                                               credentials: credentials,
                                               numeric_enums: true,
                                               raise_faraday_errors: false
end

Instance Method Details

#create_cluster(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Longrunning::Operation

Baseline implementation for the create_cluster REST call

Parameters:

  • request_pb (::Google::Cloud::Dataproc::V1::CreateClusterRequest)

    A request object representing the call parameters. Required.

  • options (::Gapic::CallOptions) (defaults to: nil)

    Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/service_stub.rb', line 69

def create_cluster request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_create_cluster_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Longrunning::Operation.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#delete_cluster(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Longrunning::Operation

Baseline implementation for the delete_cluster REST call

Parameters:

  • request_pb (::Google::Cloud::Dataproc::V1::DeleteClusterRequest)

    A request object representing the call parameters. Required.

  • options (::Gapic::CallOptions) (defaults to: nil)

    Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/service_stub.rb', line 221

def delete_cluster request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_delete_cluster_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Longrunning::Operation.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#diagnose_cluster(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Longrunning::Operation

Baseline implementation for the diagnose_cluster REST call

Parameters:

  • request_pb (::Google::Cloud::Dataproc::V1::DiagnoseClusterRequest)

    A request object representing the call parameters. Required.

  • options (::Gapic::CallOptions) (defaults to: nil)

    Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/service_stub.rb', line 335

def diagnose_cluster request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_diagnose_cluster_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Longrunning::Operation.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#get_cluster(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Dataproc::V1::Cluster

Baseline implementation for the get_cluster REST call

Parameters:

  • request_pb (::Google::Cloud::Dataproc::V1::GetClusterRequest)

    A request object representing the call parameters. Required.

  • options (::Gapic::CallOptions) (defaults to: nil)

    Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/service_stub.rb', line 259

def get_cluster request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_get_cluster_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Cloud::Dataproc::V1::Cluster.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#list_clusters(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Dataproc::V1::ListClustersResponse

Baseline implementation for the list_clusters REST call

Parameters:

  • request_pb (::Google::Cloud::Dataproc::V1::ListClustersRequest)

    A request object representing the call parameters. Required.

  • options (::Gapic::CallOptions) (defaults to: nil)

    Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/service_stub.rb', line 297

def list_clusters request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_list_clusters_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Cloud::Dataproc::V1::ListClustersResponse.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#start_cluster(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Longrunning::Operation

Baseline implementation for the start_cluster REST call

Parameters:

  • request_pb (::Google::Cloud::Dataproc::V1::StartClusterRequest)

    A request object representing the call parameters. Required.

  • options (::Gapic::CallOptions) (defaults to: nil)

    Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/service_stub.rb', line 183

def start_cluster request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_start_cluster_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Longrunning::Operation.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#stop_cluster(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Longrunning::Operation

Baseline implementation for the stop_cluster REST call

Parameters:

  • request_pb (::Google::Cloud::Dataproc::V1::StopClusterRequest)

    A request object representing the call parameters. Required.

  • options (::Gapic::CallOptions) (defaults to: nil)

    Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/service_stub.rb', line 145

def stop_cluster request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_stop_cluster_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Longrunning::Operation.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


51
52
53
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/service_stub.rb', line 51

def universe_domain
  @client_stub.universe_domain
end

#update_cluster(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Longrunning::Operation

Baseline implementation for the update_cluster REST call

Parameters:

  • request_pb (::Google::Cloud::Dataproc::V1::UpdateClusterRequest)

    A request object representing the call parameters. Required.

  • options (::Gapic::CallOptions) (defaults to: nil)

    Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/service_stub.rb', line 107

def update_cluster request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_update_cluster_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Longrunning::Operation.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end