Class: Google::Cloud::Dataproc::V1::ConfidentialInstanceConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/clusters.rb

Overview

Confidential Instance Config for clusters using Confidential VMs

Defined Under Namespace

Modules: ConfidentialInstanceType

Instance Attribute Summary collapse

Instance Attribute Details

#confidential_instance_type::Google::Cloud::Dataproc::V1::ConfidentialInstanceConfig::ConfidentialInstanceType

Returns Optional. Defines the type of Confidential Compute technology to use.

Returns:



564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 564

class ConfidentialInstanceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of Confidential Compute technology as per [Confidential Computing
  # types](https://cloud.google.com/confidential-computing/confidential-vm/docs/create-a-confidential-vm-instance#create-instance).
  # New values may be added in the future.
  module ConfidentialInstanceType
    # Confidential Instance Type is not specified.
    CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 0

    # [AMD Secure Encrypted
    # Virtualization](https://cloud.google.com/confidential-computing/confidential-vm/docs/confidential-vm-overview#amd_sev)
    SEV = 1

    # [AMD Secure Encrypted Virtualization-Secure Nested
    # Paging](https://cloud.google.com/confidential-computing/confidential-vm/docs/confidential-vm-overview#amd_sev-snp)
    SEV_SNP = 2

    # [Intel Trust Domain
    # Extensions](https://cloud.google.com/confidential-computing/confidential-vm/docs/confidential-vm-overview#intel_tdx)
    TDX = 3
  end
end

#enable_confidential_compute::Boolean

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Optional. Deprecated: Use 'confidential_instance_type' instead. Defines whether the instance should have confidential compute enabled.

Returns:

  • (::Boolean)

    Optional. Deprecated: Use 'confidential_instance_type' instead. Defines whether the instance should have confidential compute enabled.



564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 564

class ConfidentialInstanceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of Confidential Compute technology as per [Confidential Computing
  # types](https://cloud.google.com/confidential-computing/confidential-vm/docs/create-a-confidential-vm-instance#create-instance).
  # New values may be added in the future.
  module ConfidentialInstanceType
    # Confidential Instance Type is not specified.
    CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 0

    # [AMD Secure Encrypted
    # Virtualization](https://cloud.google.com/confidential-computing/confidential-vm/docs/confidential-vm-overview#amd_sev)
    SEV = 1

    # [AMD Secure Encrypted Virtualization-Secure Nested
    # Paging](https://cloud.google.com/confidential-computing/confidential-vm/docs/confidential-vm-overview#amd_sev-snp)
    SEV_SNP = 2

    # [Intel Trust Domain
    # Extensions](https://cloud.google.com/confidential-computing/confidential-vm/docs/confidential-vm-overview#intel_tdx)
    TDX = 3
  end
end