Class: Google::Cloud::Dataproc::V1::DataprocMetricConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/clusters.rb

Overview

Dataproc metric config.

Defined Under Namespace

Modules: MetricSource Classes: Metric

Instance Attribute Summary collapse

Instance Attribute Details

#metrics::Array<::Google::Cloud::Dataproc::V1::DataprocMetricConfig::Metric>

Returns Required. Metrics sources to enable.

Returns:



1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1400

class DataprocMetricConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Dataproc custom metric.
  # @!attribute [rw] metric_source
  #   @return [::Google::Cloud::Dataproc::V1::DataprocMetricConfig::MetricSource]
  #     Required. A standard set of metrics is collected unless `metricOverrides`
  #     are specified for the metric source (see [Custom metrics]
  #     (https://cloud.google.com/dataproc/docs/guides/dataproc-metrics#custom_metrics)
  #     for more information).
  # @!attribute [rw] metric_overrides
  #   @return [::Array<::String>]
  #     Optional. Specify one or more [Custom metrics]
  #     (https://cloud.google.com/dataproc/docs/guides/dataproc-metrics#custom_metrics)
  #     to collect for the metric course (for the `SPARK` metric source (any
  #     [Spark metric]
  #     (https://spark.apache.org/docs/latest/monitoring.html#metrics) can be
  #     specified).
  #
  #     Provide metrics in the following format:
  #     <code><var>METRIC_SOURCE</var>:<var>INSTANCE</var>:<var>GROUP</var>:<var>METRIC</var></code>
  #     Use camelcase as appropriate.
  #
  #     Examples:
  #
  #     ```
  #     yarn:ResourceManager:QueueMetrics:AppsCompleted
  #     spark:driver:DAGScheduler:job.allJobs
  #     sparkHistoryServer:JVM:Memory:NonHeapMemoryUsage.committed
  #     hiveserver2:JVM:Memory:NonHeapMemoryUsage.used
  #     ```
  #
  #     Notes:
  #
  #     * Only the specified overridden metrics are collected for the
  #       metric source. For example, if one or more `spark:executive` metrics
  #       are listed as metric overrides, other `SPARK` metrics are not
  #       collected. The collection of the metrics for other enabled custom
  #       metric sources is unaffected. For example, if both `SPARK` andd `YARN`
  #       metric sources are enabled, and overrides are provided for Spark
  #       metrics only, all YARN metrics are collected.
  class Metric
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A source for the collection of Dataproc custom metrics (see [Custom
  # metrics]
  # (https://cloud.google.com//dataproc/docs/guides/dataproc-metrics#custom_metrics)).
  module MetricSource
    # Required unspecified metric source.
    METRIC_SOURCE_UNSPECIFIED = 0

    # Monitoring agent metrics. If this source is enabled,
    # Dataproc enables the monitoring agent in Compute Engine,
    # and collects monitoring agent metrics, which are published
    # with an `agent.googleapis.com` prefix.
    MONITORING_AGENT_DEFAULTS = 1

    # HDFS metric source.
    HDFS = 2

    # Spark metric source.
    SPARK = 3

    # YARN metric source.
    YARN = 4

    # Spark History Server metric source.
    SPARK_HISTORY_SERVER = 5

    # Hiveserver2 metric source.
    HIVESERVER2 = 6

    # hivemetastore metric source
    HIVEMETASTORE = 7

    # flink metric source
    FLINK = 8
  end
end