Class: Google::Cloud::Dataproc::V1::DataprocMetricConfig::Metric
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::DataprocMetricConfig::Metric
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataproc/v1/clusters.rb
Overview
A Dataproc custom metric.
Instance Attribute Summary collapse
-
#metric_overrides ⇒ ::Array<::String>
Optional.
-
#metric_source ⇒ ::Google::Cloud::Dataproc::V1::DataprocMetricConfig::MetricSource
Required.
Instance Attribute Details
#metric_overrides ⇒ ::Array<::String>
Returns Optional. Specify one or more Custom metrics
to collect for the metric course (for the SPARK metric source (any
Spark metric can be
specified).
Provide metrics in the following format:
METRIC_SOURCE:INSTANCE:GROUP:METRIC
Use camelcase as appropriate.
Examples:
yarn:ResourceManager:QueueMetrics:AppsCompleted
spark:driver:DAGScheduler:job.allJobs
sparkHistoryServer:JVM:Memory:NonHeapMemoryUsage.committed
hiveserver2:JVM:Memory:NonHeapMemoryUsage.used
Notes:
- Only the specified overridden metrics are collected for the
metric source. For example, if one or more
spark:executivemetrics are listed as metric overrides, otherSPARKmetrics are not collected. The collection of the metrics for other enabled custom metric sources is unaffected. For example, if bothSPARKanddYARNmetric sources are enabled, and overrides are provided for Spark metrics only, all YARN metrics are collected.
1350 1351 1352 1353 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1350 class Metric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#metric_source ⇒ ::Google::Cloud::Dataproc::V1::DataprocMetricConfig::MetricSource
Returns Required. A standard set of metrics is collected unless metricOverrides
are specified for the metric source (see Custom metrics
for more information).
1350 1351 1352 1353 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1350 class Metric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |