Class: Google::Cloud::Dataproc::V1::GceClusterConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/clusters.rb

Overview

Common config settings for resources of Compute Engine cluster instances, applicable to all instances in the cluster.

Defined Under Namespace

Modules: PrivateIpv6GoogleAccess Classes: MetadataEntry

Instance Attribute Summary collapse

Instance Attribute Details

#confidential_instance_config::Google::Cloud::Dataproc::V1::ConfidentialInstanceConfig

Returns Optional. Confidential Instance Config for clusters using Confidential VMs.

Returns:



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 464

class GceClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # `PrivateIpv6GoogleAccess` controls whether and how Dataproc cluster nodes
  # can communicate with Google Services through gRPC over IPv6.
  # These values are directly mapped to corresponding values in the
  # [Compute Engine Instance
  # fields](https://cloud.google.com/compute/docs/reference/rest/v1/instances).
  module PrivateIpv6GoogleAccess
    # If unspecified, Compute Engine default behavior will apply, which
    # is the same as
    # {::Google::Cloud::Dataproc::V1::GceClusterConfig::PrivateIpv6GoogleAccess::INHERIT_FROM_SUBNETWORK INHERIT_FROM_SUBNETWORK}.
    PRIVATE_IPV6_GOOGLE_ACCESS_UNSPECIFIED = 0

    # Private access to and from Google Services configuration
    # inherited from the subnetwork configuration. This is the
    # default Compute Engine behavior.
    INHERIT_FROM_SUBNETWORK = 1

    # Enables outbound private IPv6 access to Google Services from the Dataproc
    # cluster.
    OUTBOUND = 2

    # Enables bidirectional private IPv6 access between Google Services and the
    # Dataproc cluster.
    BIDIRECTIONAL = 3
  end
end

#internal_ip_only::Boolean

Returns Optional. This setting applies to subnetwork-enabled networks. It is set to true by default in clusters created with image versions 2.2.x.

When set to true:

  • All cluster VMs have internal IP addresses.
  • Google Private Access must be enabled to access Dataproc and other Google Cloud APIs.
  • Off-cluster dependencies must be configured to be accessible without external IP addresses.

When set to false:

  • Cluster VMs are not restricted to internal IP addresses.
  • Ephemeral external IP addresses are assigned to each cluster VM.

Returns:

  • (::Boolean)

    Optional. This setting applies to subnetwork-enabled networks. It is set to true by default in clusters created with image versions 2.2.x.

    When set to true:

    • All cluster VMs have internal IP addresses.
    • Google Private Access must be enabled to access Dataproc and other Google Cloud APIs.
    • Off-cluster dependencies must be configured to be accessible without external IP addresses.

    When set to false:

    • Cluster VMs are not restricted to internal IP addresses.
    • Ephemeral external IP addresses are assigned to each cluster VM.


464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 464

class GceClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # `PrivateIpv6GoogleAccess` controls whether and how Dataproc cluster nodes
  # can communicate with Google Services through gRPC over IPv6.
  # These values are directly mapped to corresponding values in the
  # [Compute Engine Instance
  # fields](https://cloud.google.com/compute/docs/reference/rest/v1/instances).
  module PrivateIpv6GoogleAccess
    # If unspecified, Compute Engine default behavior will apply, which
    # is the same as
    # {::Google::Cloud::Dataproc::V1::GceClusterConfig::PrivateIpv6GoogleAccess::INHERIT_FROM_SUBNETWORK INHERIT_FROM_SUBNETWORK}.
    PRIVATE_IPV6_GOOGLE_ACCESS_UNSPECIFIED = 0

    # Private access to and from Google Services configuration
    # inherited from the subnetwork configuration. This is the
    # default Compute Engine behavior.
    INHERIT_FROM_SUBNETWORK = 1

    # Enables outbound private IPv6 access to Google Services from the Dataproc
    # cluster.
    OUTBOUND = 2

    # Enables bidirectional private IPv6 access between Google Services and the
    # Dataproc cluster.
    BIDIRECTIONAL = 3
  end
end

#metadata::Google::Protobuf::Map{::String => ::String}

Returns Optional. The Compute Engine metadata entries to add to all instances (see Project and instance metadata).

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. The Compute Engine metadata entries to add to all instances (see Project and instance metadata).



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 464

class GceClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # `PrivateIpv6GoogleAccess` controls whether and how Dataproc cluster nodes
  # can communicate with Google Services through gRPC over IPv6.
  # These values are directly mapped to corresponding values in the
  # [Compute Engine Instance
  # fields](https://cloud.google.com/compute/docs/reference/rest/v1/instances).
  module PrivateIpv6GoogleAccess
    # If unspecified, Compute Engine default behavior will apply, which
    # is the same as
    # {::Google::Cloud::Dataproc::V1::GceClusterConfig::PrivateIpv6GoogleAccess::INHERIT_FROM_SUBNETWORK INHERIT_FROM_SUBNETWORK}.
    PRIVATE_IPV6_GOOGLE_ACCESS_UNSPECIFIED = 0

    # Private access to and from Google Services configuration
    # inherited from the subnetwork configuration. This is the
    # default Compute Engine behavior.
    INHERIT_FROM_SUBNETWORK = 1

    # Enables outbound private IPv6 access to Google Services from the Dataproc
    # cluster.
    OUTBOUND = 2

    # Enables bidirectional private IPv6 access between Google Services and the
    # Dataproc cluster.
    BIDIRECTIONAL = 3
  end
end

#network_uri::String

Returns Optional. The Compute Engine network to be used for machine communications. Cannot be specified with subnetwork_uri. If neither network_uri nor subnetwork_uri is specified, the "default" network of the project is used, if it exists. Cannot be a "Custom Subnet Network" (see Using Subnetworks for more information).

A full URL, partial URI, or short name are valid. Examples:

  • https://www.googleapis.com/compute/v1/projects/[project_id]/global/networks/default
  • projects/[project_id]/global/networks/default
  • default.

Returns:

  • (::String)

    Optional. The Compute Engine network to be used for machine communications. Cannot be specified with subnetwork_uri. If neither network_uri nor subnetwork_uri is specified, the "default" network of the project is used, if it exists. Cannot be a "Custom Subnet Network" (see Using Subnetworks for more information).

    A full URL, partial URI, or short name are valid. Examples:

    • https://www.googleapis.com/compute/v1/projects/[project_id]/global/networks/default
    • projects/[project_id]/global/networks/default
    • default


464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 464

class GceClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # `PrivateIpv6GoogleAccess` controls whether and how Dataproc cluster nodes
  # can communicate with Google Services through gRPC over IPv6.
  # These values are directly mapped to corresponding values in the
  # [Compute Engine Instance
  # fields](https://cloud.google.com/compute/docs/reference/rest/v1/instances).
  module PrivateIpv6GoogleAccess
    # If unspecified, Compute Engine default behavior will apply, which
    # is the same as
    # {::Google::Cloud::Dataproc::V1::GceClusterConfig::PrivateIpv6GoogleAccess::INHERIT_FROM_SUBNETWORK INHERIT_FROM_SUBNETWORK}.
    PRIVATE_IPV6_GOOGLE_ACCESS_UNSPECIFIED = 0

    # Private access to and from Google Services configuration
    # inherited from the subnetwork configuration. This is the
    # default Compute Engine behavior.
    INHERIT_FROM_SUBNETWORK = 1

    # Enables outbound private IPv6 access to Google Services from the Dataproc
    # cluster.
    OUTBOUND = 2

    # Enables bidirectional private IPv6 access between Google Services and the
    # Dataproc cluster.
    BIDIRECTIONAL = 3
  end
end

#node_group_affinity::Google::Cloud::Dataproc::V1::NodeGroupAffinity

Returns Optional. Node Group Affinity for sole-tenant clusters.

Returns:



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 464

class GceClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # `PrivateIpv6GoogleAccess` controls whether and how Dataproc cluster nodes
  # can communicate with Google Services through gRPC over IPv6.
  # These values are directly mapped to corresponding values in the
  # [Compute Engine Instance
  # fields](https://cloud.google.com/compute/docs/reference/rest/v1/instances).
  module PrivateIpv6GoogleAccess
    # If unspecified, Compute Engine default behavior will apply, which
    # is the same as
    # {::Google::Cloud::Dataproc::V1::GceClusterConfig::PrivateIpv6GoogleAccess::INHERIT_FROM_SUBNETWORK INHERIT_FROM_SUBNETWORK}.
    PRIVATE_IPV6_GOOGLE_ACCESS_UNSPECIFIED = 0

    # Private access to and from Google Services configuration
    # inherited from the subnetwork configuration. This is the
    # default Compute Engine behavior.
    INHERIT_FROM_SUBNETWORK = 1

    # Enables outbound private IPv6 access to Google Services from the Dataproc
    # cluster.
    OUTBOUND = 2

    # Enables bidirectional private IPv6 access between Google Services and the
    # Dataproc cluster.
    BIDIRECTIONAL = 3
  end
end

#private_ipv6_google_access::Google::Cloud::Dataproc::V1::GceClusterConfig::PrivateIpv6GoogleAccess

Returns Optional. The type of IPv6 access for a cluster.

Returns:



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 464

class GceClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # `PrivateIpv6GoogleAccess` controls whether and how Dataproc cluster nodes
  # can communicate with Google Services through gRPC over IPv6.
  # These values are directly mapped to corresponding values in the
  # [Compute Engine Instance
  # fields](https://cloud.google.com/compute/docs/reference/rest/v1/instances).
  module PrivateIpv6GoogleAccess
    # If unspecified, Compute Engine default behavior will apply, which
    # is the same as
    # {::Google::Cloud::Dataproc::V1::GceClusterConfig::PrivateIpv6GoogleAccess::INHERIT_FROM_SUBNETWORK INHERIT_FROM_SUBNETWORK}.
    PRIVATE_IPV6_GOOGLE_ACCESS_UNSPECIFIED = 0

    # Private access to and from Google Services configuration
    # inherited from the subnetwork configuration. This is the
    # default Compute Engine behavior.
    INHERIT_FROM_SUBNETWORK = 1

    # Enables outbound private IPv6 access to Google Services from the Dataproc
    # cluster.
    OUTBOUND = 2

    # Enables bidirectional private IPv6 access between Google Services and the
    # Dataproc cluster.
    BIDIRECTIONAL = 3
  end
end

#reservation_affinity::Google::Cloud::Dataproc::V1::ReservationAffinity

Returns Optional. Reservation Affinity for consuming Zonal reservation.

Returns:



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 464

class GceClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # `PrivateIpv6GoogleAccess` controls whether and how Dataproc cluster nodes
  # can communicate with Google Services through gRPC over IPv6.
  # These values are directly mapped to corresponding values in the
  # [Compute Engine Instance
  # fields](https://cloud.google.com/compute/docs/reference/rest/v1/instances).
  module PrivateIpv6GoogleAccess
    # If unspecified, Compute Engine default behavior will apply, which
    # is the same as
    # {::Google::Cloud::Dataproc::V1::GceClusterConfig::PrivateIpv6GoogleAccess::INHERIT_FROM_SUBNETWORK INHERIT_FROM_SUBNETWORK}.
    PRIVATE_IPV6_GOOGLE_ACCESS_UNSPECIFIED = 0

    # Private access to and from Google Services configuration
    # inherited from the subnetwork configuration. This is the
    # default Compute Engine behavior.
    INHERIT_FROM_SUBNETWORK = 1

    # Enables outbound private IPv6 access to Google Services from the Dataproc
    # cluster.
    OUTBOUND = 2

    # Enables bidirectional private IPv6 access between Google Services and the
    # Dataproc cluster.
    BIDIRECTIONAL = 3
  end
end

#service_account::String

Returns Optional. The Dataproc service account (also see VM Data Plane identity) used by Dataproc cluster VM instances to access Google Cloud Platform services.

If not specified, the Compute Engine default service account is used.

Returns:



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 464

class GceClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # `PrivateIpv6GoogleAccess` controls whether and how Dataproc cluster nodes
  # can communicate with Google Services through gRPC over IPv6.
  # These values are directly mapped to corresponding values in the
  # [Compute Engine Instance
  # fields](https://cloud.google.com/compute/docs/reference/rest/v1/instances).
  module PrivateIpv6GoogleAccess
    # If unspecified, Compute Engine default behavior will apply, which
    # is the same as
    # {::Google::Cloud::Dataproc::V1::GceClusterConfig::PrivateIpv6GoogleAccess::INHERIT_FROM_SUBNETWORK INHERIT_FROM_SUBNETWORK}.
    PRIVATE_IPV6_GOOGLE_ACCESS_UNSPECIFIED = 0

    # Private access to and from Google Services configuration
    # inherited from the subnetwork configuration. This is the
    # default Compute Engine behavior.
    INHERIT_FROM_SUBNETWORK = 1

    # Enables outbound private IPv6 access to Google Services from the Dataproc
    # cluster.
    OUTBOUND = 2

    # Enables bidirectional private IPv6 access between Google Services and the
    # Dataproc cluster.
    BIDIRECTIONAL = 3
  end
end

#service_account_scopes::Array<::String>

Returns:



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 464

class GceClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # `PrivateIpv6GoogleAccess` controls whether and how Dataproc cluster nodes
  # can communicate with Google Services through gRPC over IPv6.
  # These values are directly mapped to corresponding values in the
  # [Compute Engine Instance
  # fields](https://cloud.google.com/compute/docs/reference/rest/v1/instances).
  module PrivateIpv6GoogleAccess
    # If unspecified, Compute Engine default behavior will apply, which
    # is the same as
    # {::Google::Cloud::Dataproc::V1::GceClusterConfig::PrivateIpv6GoogleAccess::INHERIT_FROM_SUBNETWORK INHERIT_FROM_SUBNETWORK}.
    PRIVATE_IPV6_GOOGLE_ACCESS_UNSPECIFIED = 0

    # Private access to and from Google Services configuration
    # inherited from the subnetwork configuration. This is the
    # default Compute Engine behavior.
    INHERIT_FROM_SUBNETWORK = 1

    # Enables outbound private IPv6 access to Google Services from the Dataproc
    # cluster.
    OUTBOUND = 2

    # Enables bidirectional private IPv6 access between Google Services and the
    # Dataproc cluster.
    BIDIRECTIONAL = 3
  end
end

#shielded_instance_config::Google::Cloud::Dataproc::V1::ShieldedInstanceConfig

Returns Optional. Shielded Instance Config for clusters using Compute Engine Shielded VMs.

Returns:



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 464

class GceClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # `PrivateIpv6GoogleAccess` controls whether and how Dataproc cluster nodes
  # can communicate with Google Services through gRPC over IPv6.
  # These values are directly mapped to corresponding values in the
  # [Compute Engine Instance
  # fields](https://cloud.google.com/compute/docs/reference/rest/v1/instances).
  module PrivateIpv6GoogleAccess
    # If unspecified, Compute Engine default behavior will apply, which
    # is the same as
    # {::Google::Cloud::Dataproc::V1::GceClusterConfig::PrivateIpv6GoogleAccess::INHERIT_FROM_SUBNETWORK INHERIT_FROM_SUBNETWORK}.
    PRIVATE_IPV6_GOOGLE_ACCESS_UNSPECIFIED = 0

    # Private access to and from Google Services configuration
    # inherited from the subnetwork configuration. This is the
    # default Compute Engine behavior.
    INHERIT_FROM_SUBNETWORK = 1

    # Enables outbound private IPv6 access to Google Services from the Dataproc
    # cluster.
    OUTBOUND = 2

    # Enables bidirectional private IPv6 access between Google Services and the
    # Dataproc cluster.
    BIDIRECTIONAL = 3
  end
end

#subnetwork_uri::String

Returns Optional. The Compute Engine subnetwork to be used for machine communications. Cannot be specified with network_uri.

A full URL, partial URI, or short name are valid. Examples:

  • https://www.googleapis.com/compute/v1/projects/[project_id]/regions/[region]/subnetworks/sub0
  • projects/[project_id]/regions/[region]/subnetworks/sub0
  • sub0.

Returns:

  • (::String)

    Optional. The Compute Engine subnetwork to be used for machine communications. Cannot be specified with network_uri.

    A full URL, partial URI, or short name are valid. Examples:

    • https://www.googleapis.com/compute/v1/projects/[project_id]/regions/[region]/subnetworks/sub0
    • projects/[project_id]/regions/[region]/subnetworks/sub0
    • sub0


464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 464

class GceClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # `PrivateIpv6GoogleAccess` controls whether and how Dataproc cluster nodes
  # can communicate with Google Services through gRPC over IPv6.
  # These values are directly mapped to corresponding values in the
  # [Compute Engine Instance
  # fields](https://cloud.google.com/compute/docs/reference/rest/v1/instances).
  module PrivateIpv6GoogleAccess
    # If unspecified, Compute Engine default behavior will apply, which
    # is the same as
    # {::Google::Cloud::Dataproc::V1::GceClusterConfig::PrivateIpv6GoogleAccess::INHERIT_FROM_SUBNETWORK INHERIT_FROM_SUBNETWORK}.
    PRIVATE_IPV6_GOOGLE_ACCESS_UNSPECIFIED = 0

    # Private access to and from Google Services configuration
    # inherited from the subnetwork configuration. This is the
    # default Compute Engine behavior.
    INHERIT_FROM_SUBNETWORK = 1

    # Enables outbound private IPv6 access to Google Services from the Dataproc
    # cluster.
    OUTBOUND = 2

    # Enables bidirectional private IPv6 access between Google Services and the
    # Dataproc cluster.
    BIDIRECTIONAL = 3
  end
end

#tags::Array<::String>

Returns The Compute Engine network tags to add to all instances (see Tagging instances).

Returns:

  • (::Array<::String>)

    The Compute Engine network tags to add to all instances (see Tagging instances).



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 464

class GceClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # `PrivateIpv6GoogleAccess` controls whether and how Dataproc cluster nodes
  # can communicate with Google Services through gRPC over IPv6.
  # These values are directly mapped to corresponding values in the
  # [Compute Engine Instance
  # fields](https://cloud.google.com/compute/docs/reference/rest/v1/instances).
  module PrivateIpv6GoogleAccess
    # If unspecified, Compute Engine default behavior will apply, which
    # is the same as
    # {::Google::Cloud::Dataproc::V1::GceClusterConfig::PrivateIpv6GoogleAccess::INHERIT_FROM_SUBNETWORK INHERIT_FROM_SUBNETWORK}.
    PRIVATE_IPV6_GOOGLE_ACCESS_UNSPECIFIED = 0

    # Private access to and from Google Services configuration
    # inherited from the subnetwork configuration. This is the
    # default Compute Engine behavior.
    INHERIT_FROM_SUBNETWORK = 1

    # Enables outbound private IPv6 access to Google Services from the Dataproc
    # cluster.
    OUTBOUND = 2

    # Enables bidirectional private IPv6 access between Google Services and the
    # Dataproc cluster.
    BIDIRECTIONAL = 3
  end
end

#zone_uri::String

Returns Optional. The Compute Engine zone where the Dataproc cluster will be located. If omitted, the service will pick a zone in the cluster's Compute Engine region. On a get request, zone will always be present.

A full URL, partial URI, or short name are valid. Examples:

  • https://www.googleapis.com/compute/v1/projects/[project_id]/zones/[zone]
  • projects/[project_id]/zones/[zone]
  • [zone].

Returns:

  • (::String)

    Optional. The Compute Engine zone where the Dataproc cluster will be located. If omitted, the service will pick a zone in the cluster's Compute Engine region. On a get request, zone will always be present.

    A full URL, partial URI, or short name are valid. Examples:

    • https://www.googleapis.com/compute/v1/projects/[project_id]/zones/[zone]
    • projects/[project_id]/zones/[zone]
    • [zone]


464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 464

class GceClusterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # `PrivateIpv6GoogleAccess` controls whether and how Dataproc cluster nodes
  # can communicate with Google Services through gRPC over IPv6.
  # These values are directly mapped to corresponding values in the
  # [Compute Engine Instance
  # fields](https://cloud.google.com/compute/docs/reference/rest/v1/instances).
  module PrivateIpv6GoogleAccess
    # If unspecified, Compute Engine default behavior will apply, which
    # is the same as
    # {::Google::Cloud::Dataproc::V1::GceClusterConfig::PrivateIpv6GoogleAccess::INHERIT_FROM_SUBNETWORK INHERIT_FROM_SUBNETWORK}.
    PRIVATE_IPV6_GOOGLE_ACCESS_UNSPECIFIED = 0

    # Private access to and from Google Services configuration
    # inherited from the subnetwork configuration. This is the
    # default Compute Engine behavior.
    INHERIT_FROM_SUBNETWORK = 1

    # Enables outbound private IPv6 access to Google Services from the Dataproc
    # cluster.
    OUTBOUND = 2

    # Enables bidirectional private IPv6 access between Google Services and the
    # Dataproc cluster.
    BIDIRECTIONAL = 3
  end
end