Class: Google::Cloud::Dataproc::V1::InstanceFlexibilityPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/clusters.rb

Overview

Instance flexibility Policy allowing a mixture of VM shapes and provisioning models.

Defined Under Namespace

Classes: InstanceSelection, InstanceSelectionResult, ProvisioningModelMix

Instance Attribute Summary collapse

Instance Attribute Details

#instance_selection_list::Array<::Google::Cloud::Dataproc::V1::InstanceFlexibilityPolicy::InstanceSelection>

Returns Optional. List of instance selection options that the group will use when creating new VMs.

Returns:



794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 794

class InstanceFlexibilityPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines how Dataproc should create VMs with a mixture of provisioning
  # models.
  # @!attribute [rw] standard_capacity_base
  #   @return [::Integer]
  #     Optional. The base capacity that will always use Standard VMs to avoid
  #     risk of more preemption than the minimum capacity you need. Dataproc will
  #     create only standard VMs until it reaches standard_capacity_base, then it
  #     will start using standard_capacity_percent_above_base to mix Spot with
  #     Standard VMs. eg. If 15 instances are requested and
  #     standard_capacity_base is 5, Dataproc will create 5 standard VMs and then
  #     start mixing spot and standard VMs for remaining 10 instances.
  # @!attribute [rw] standard_capacity_percent_above_base
  #   @return [::Integer]
  #     Optional. The percentage of target capacity that should use Standard VM.
  #     The remaining percentage will use Spot VMs. The percentage applies only
  #     to the capacity above standard_capacity_base. eg. If 15 instances are
  #     requested and standard_capacity_base is 5 and
  #     standard_capacity_percent_above_base is 30, Dataproc will create 5
  #     standard VMs and then start mixing spot and standard VMs for remaining 10
  #     instances. The mix will be 30% standard and 70% spot.
  class ProvisioningModelMix
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines machines types and a rank to which the machines types belong.
  # @!attribute [rw] machine_types
  #   @return [::Array<::String>]
  #     Optional. Full machine-type names, e.g. "n1-standard-16".
  # @!attribute [rw] rank
  #   @return [::Integer]
  #     Optional. Preference of this instance selection. Lower number means
  #     higher preference. Dataproc will first try to create a VM based on the
  #     machine-type with priority rank and fallback to next rank based on
  #     availability. Machine types and instance selections with the same
  #     priority have the same preference.
  class InstanceSelection
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines a mapping from machine types to the number of VMs that are created
  # with each machine type.
  # @!attribute [r] machine_type
  #   @return [::String]
  #     Output only. Full machine-type names, e.g. "n1-standard-16".
  # @!attribute [r] vm_count
  #   @return [::Integer]
  #     Output only. Number of VM provisioned with the machine_type.
  class InstanceSelectionResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#instance_selection_results::Array<::Google::Cloud::Dataproc::V1::InstanceFlexibilityPolicy::InstanceSelectionResult> (readonly)

Returns Output only. A list of instance selection results in the group.

Returns:



794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 794

class InstanceFlexibilityPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines how Dataproc should create VMs with a mixture of provisioning
  # models.
  # @!attribute [rw] standard_capacity_base
  #   @return [::Integer]
  #     Optional. The base capacity that will always use Standard VMs to avoid
  #     risk of more preemption than the minimum capacity you need. Dataproc will
  #     create only standard VMs until it reaches standard_capacity_base, then it
  #     will start using standard_capacity_percent_above_base to mix Spot with
  #     Standard VMs. eg. If 15 instances are requested and
  #     standard_capacity_base is 5, Dataproc will create 5 standard VMs and then
  #     start mixing spot and standard VMs for remaining 10 instances.
  # @!attribute [rw] standard_capacity_percent_above_base
  #   @return [::Integer]
  #     Optional. The percentage of target capacity that should use Standard VM.
  #     The remaining percentage will use Spot VMs. The percentage applies only
  #     to the capacity above standard_capacity_base. eg. If 15 instances are
  #     requested and standard_capacity_base is 5 and
  #     standard_capacity_percent_above_base is 30, Dataproc will create 5
  #     standard VMs and then start mixing spot and standard VMs for remaining 10
  #     instances. The mix will be 30% standard and 70% spot.
  class ProvisioningModelMix
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines machines types and a rank to which the machines types belong.
  # @!attribute [rw] machine_types
  #   @return [::Array<::String>]
  #     Optional. Full machine-type names, e.g. "n1-standard-16".
  # @!attribute [rw] rank
  #   @return [::Integer]
  #     Optional. Preference of this instance selection. Lower number means
  #     higher preference. Dataproc will first try to create a VM based on the
  #     machine-type with priority rank and fallback to next rank based on
  #     availability. Machine types and instance selections with the same
  #     priority have the same preference.
  class InstanceSelection
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines a mapping from machine types to the number of VMs that are created
  # with each machine type.
  # @!attribute [r] machine_type
  #   @return [::String]
  #     Output only. Full machine-type names, e.g. "n1-standard-16".
  # @!attribute [r] vm_count
  #   @return [::Integer]
  #     Output only. Number of VM provisioned with the machine_type.
  class InstanceSelectionResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#provisioning_model_mix::Google::Cloud::Dataproc::V1::InstanceFlexibilityPolicy::ProvisioningModelMix

Returns Optional. Defines how the Group selects the provisioning model to ensure required reliability.

Returns:



794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 794

class InstanceFlexibilityPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines how Dataproc should create VMs with a mixture of provisioning
  # models.
  # @!attribute [rw] standard_capacity_base
  #   @return [::Integer]
  #     Optional. The base capacity that will always use Standard VMs to avoid
  #     risk of more preemption than the minimum capacity you need. Dataproc will
  #     create only standard VMs until it reaches standard_capacity_base, then it
  #     will start using standard_capacity_percent_above_base to mix Spot with
  #     Standard VMs. eg. If 15 instances are requested and
  #     standard_capacity_base is 5, Dataproc will create 5 standard VMs and then
  #     start mixing spot and standard VMs for remaining 10 instances.
  # @!attribute [rw] standard_capacity_percent_above_base
  #   @return [::Integer]
  #     Optional. The percentage of target capacity that should use Standard VM.
  #     The remaining percentage will use Spot VMs. The percentage applies only
  #     to the capacity above standard_capacity_base. eg. If 15 instances are
  #     requested and standard_capacity_base is 5 and
  #     standard_capacity_percent_above_base is 30, Dataproc will create 5
  #     standard VMs and then start mixing spot and standard VMs for remaining 10
  #     instances. The mix will be 30% standard and 70% spot.
  class ProvisioningModelMix
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines machines types and a rank to which the machines types belong.
  # @!attribute [rw] machine_types
  #   @return [::Array<::String>]
  #     Optional. Full machine-type names, e.g. "n1-standard-16".
  # @!attribute [rw] rank
  #   @return [::Integer]
  #     Optional. Preference of this instance selection. Lower number means
  #     higher preference. Dataproc will first try to create a VM based on the
  #     machine-type with priority rank and fallback to next rank based on
  #     availability. Machine types and instance selections with the same
  #     priority have the same preference.
  class InstanceSelection
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines a mapping from machine types to the number of VMs that are created
  # with each machine type.
  # @!attribute [r] machine_type
  #   @return [::String]
  #     Output only. Full machine-type names, e.g. "n1-standard-16".
  # @!attribute [r] vm_count
  #   @return [::Integer]
  #     Output only. Number of VM provisioned with the machine_type.
  class InstanceSelectionResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end