Class: Google::Cloud::Dataproc::V1::InstanceFlexibilityPolicy::InstanceSelection

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/clusters.rb

Overview

Defines machines types and a rank to which the machines types belong.

Instance Attribute Summary collapse

Instance Attribute Details

#disk_config::Google::Cloud::Dataproc::V1::DiskConfig

Returns Optional. Disk configuration to apply to the instances in this instance selection. If specified on any entry in instanceSelectionList, then it must be specified on every entry in instanceSelectionList and the instanceGroupConfig must not specify any diskConfig.

Returns:

  • (::Google::Cloud::Dataproc::V1::DiskConfig)

    Optional. Disk configuration to apply to the instances in this instance selection. If specified on any entry in instanceSelectionList, then it must be specified on every entry in instanceSelectionList and the instanceGroupConfig must not specify any diskConfig.



840
841
842
843
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 840

class InstanceSelection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#machine_types::Array<::String>

Returns Optional. Full machine-type names, e.g. "n1-standard-16".

Returns:

  • (::Array<::String>)

    Optional. Full machine-type names, e.g. "n1-standard-16".



840
841
842
843
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 840

class InstanceSelection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rank::Integer

Returns Optional. Preference of this instance selection. Lower number means higher preference. Dataproc will first try to create a VM based on the machine-type with priority rank and fallback to next rank based on availability. Machine types and instance selections with the same priority have the same preference.

Returns:

  • (::Integer)

    Optional. Preference of this instance selection. Lower number means higher preference. Dataproc will first try to create a VM based on the machine-type with priority rank and fallback to next rank based on availability. Machine types and instance selections with the same priority have the same preference.



840
841
842
843
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 840

class InstanceSelection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end