Class: Google::Cloud::Dataproc::V1::JobController::Rest::Client

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/dataproc/v1/job_controller/rest/client.rb

Overview

REST client for the JobController service.

The JobController provides methods to manage jobs.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new JobController REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Dataproc::V1::JobController::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Dataproc::V1::JobController::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the JobController client.

Yield Parameters:



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/google/cloud/dataproc/v1/job_controller/rest/client.rb', line 145

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-")
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @operations_client = ::Google::Cloud::Dataproc::V1::JobController::Rest::Operations.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @config.endpoint
  end

  @iam_policy_client = Google::Iam::V1::IAMPolicy::Rest::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @config.endpoint
    config.bindings_override = @config.bindings_override
  end

  @job_controller_stub = ::Google::Cloud::Dataproc::V1::JobController::Rest::ServiceStub.new endpoint: @config.endpoint, credentials: credentials
end

Instance Attribute Details

#iam_policy_clientGoogle::Iam::V1::IAMPolicy::Rest::Client (readonly)

Get the associated client for mix-in of the IAMPolicy.

Returns:

  • (Google::Iam::V1::IAMPolicy::Rest::Client)


195
196
197
# File 'lib/google/cloud/dataproc/v1/job_controller/rest/client.rb', line 195

def iam_policy_client
  @iam_policy_client
end

#operations_client::Google::Cloud::Dataproc::V1::JobController::Rest::Operations (readonly)

Get the associated client for long-running operations.



188
189
190
# File 'lib/google/cloud/dataproc/v1/job_controller/rest/client.rb', line 188

def operations_client
  @operations_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the JobController Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all JobController clients
::Google::Cloud::Dataproc::V1::JobController::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/google/cloud/dataproc/v1/job_controller/rest/client.rb', line 57

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Dataproc", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.submit_job.timeout = 900.0
    default_config.rpcs.submit_job.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.submit_job_as_operation.timeout = 900.0
    default_config.rpcs.submit_job_as_operation.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_job.timeout = 900.0
    default_config.rpcs.get_job.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 13, 14]
    }

    default_config.rpcs.list_jobs.timeout = 900.0
    default_config.rpcs.list_jobs.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 13, 14]
    }

    default_config.rpcs.update_job.timeout = 900.0
    default_config.rpcs.update_job.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.cancel_job.timeout = 900.0
    default_config.rpcs.cancel_job.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 13, 14]
    }

    default_config.rpcs.delete_job.timeout = 900.0
    default_config.rpcs.delete_job.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#cancel_job(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::Job #cancel_job(project_id: nil, region: nil, job_id: nil) ⇒ ::Google::Cloud::Dataproc::V1::Job

Starts a job cancellation request. To access the job resource after cancellation, call regions/{region}/jobs.list or regions/{region}/jobs.get.

Examples:

Basic example

require "google/cloud/dataproc/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dataproc::V1::JobController::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dataproc::V1::CancelJobRequest.new

# Call the cancel_job method.
result = client.cancel_job request

# The returned object is of type Google::Cloud::Dataproc::V1::Job.
p result

Overloads:

  • #cancel_job(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::Job

    Pass arguments to cancel_job via a request object, either of type CancelJobRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::CancelJobRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #cancel_job(project_id: nil, region: nil, job_id: nil) ⇒ ::Google::Cloud::Dataproc::V1::Job

    Pass arguments to cancel_job via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      Required. The ID of the Google Cloud Platform project that the job belongs to.

    • region (::String) (defaults to: nil)

      Required. The Dataproc region in which to handle the request.

    • job_id (::String) (defaults to: nil)

      Required. The job ID.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'lib/google/cloud/dataproc/v1/job_controller/rest/client.rb', line 740

def cancel_job request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::CancelJobRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.cancel_job..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.cancel_job.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.cancel_job.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @job_controller_stub.cancel_job request, options do |result, operation|
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the JobController Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



124
125
126
127
# File 'lib/google/cloud/dataproc/v1/job_controller/rest/client.rb', line 124

def configure
  yield @config if block_given?
  @config
end

#delete_job(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_job(project_id: nil, region: nil, job_id: nil) ⇒ ::Google::Protobuf::Empty

Deletes the job from the project. If the job is active, the delete fails, and the response returns FAILED_PRECONDITION.

Examples:

Basic example

require "google/cloud/dataproc/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dataproc::V1::JobController::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dataproc::V1::DeleteJobRequest.new

# Call the delete_job method.
result = client.delete_job request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_job(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_job via a request object, either of type DeleteJobRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::DeleteJobRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #delete_job(project_id: nil, region: nil, job_id: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_job via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      Required. The ID of the Google Cloud Platform project that the job belongs to.

    • region (::String) (defaults to: nil)

      Required. The Dataproc region in which to handle the request.

    • job_id (::String) (defaults to: nil)

      Required. The job ID.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
# File 'lib/google/cloud/dataproc/v1/job_controller/rest/client.rb', line 824

def delete_job request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::DeleteJobRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_job..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete_job.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_job.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @job_controller_stub.delete_job request, options do |result, operation|
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_job(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::Job #get_job(project_id: nil, region: nil, job_id: nil) ⇒ ::Google::Cloud::Dataproc::V1::Job

Gets the resource representation for a job in a project.

Examples:

Basic example

require "google/cloud/dataproc/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dataproc::V1::JobController::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dataproc::V1::GetJobRequest.new

# Call the get_job method.
result = client.get_job request

# The returned object is of type Google::Cloud::Dataproc::V1::Job.
p result

Overloads:

  • #get_job(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::Job

    Pass arguments to get_job via a request object, either of type GetJobRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::GetJobRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_job(project_id: nil, region: nil, job_id: nil) ⇒ ::Google::Cloud::Dataproc::V1::Job

    Pass arguments to get_job via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      Required. The ID of the Google Cloud Platform project that the job belongs to.

    • region (::String) (defaults to: nil)

      Required. The Dataproc region in which to handle the request.

    • job_id (::String) (defaults to: nil)

      Required. The job ID.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
# File 'lib/google/cloud/dataproc/v1/job_controller/rest/client.rb', line 447

def get_job request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::GetJobRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_job..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_job.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_job.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @job_controller_stub.get_job request, options do |result, operation|
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_jobs(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dataproc::V1::Job> #list_jobs(project_id: nil, region: nil, page_size: nil, page_token: nil, cluster_name: nil, job_state_matcher: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dataproc::V1::Job>

Lists regions/{region}/jobs in a project.

Examples:

Basic example

require "google/cloud/dataproc/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dataproc::V1::JobController::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dataproc::V1::ListJobsRequest.new

# Call the list_jobs method.
result = client.list_jobs request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Dataproc::V1::Job.
  p item
end

Overloads:

  • #list_jobs(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dataproc::V1::Job>

    Pass arguments to list_jobs via a request object, either of type ListJobsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::ListJobsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_jobs(project_id: nil, region: nil, page_size: nil, page_token: nil, cluster_name: nil, job_state_matcher: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dataproc::V1::Job>

    Pass arguments to list_jobs via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      Required. The ID of the Google Cloud Platform project that the job belongs to.

    • region (::String) (defaults to: nil)

      Required. The Dataproc region in which to handle the request.

    • page_size (::Integer) (defaults to: nil)

      Optional. The number of results to return in each response.

    • page_token (::String) (defaults to: nil)

      Optional. The page token, returned by a previous call, to request the next page of results.

    • cluster_name (::String) (defaults to: nil)

      Optional. If set, the returned jobs list includes only jobs that were submitted to the named cluster.

    • job_state_matcher (::Google::Cloud::Dataproc::V1::ListJobsRequest::JobStateMatcher) (defaults to: nil)

      Optional. Specifies enumerated categories of jobs to list. (default = match ALL jobs).

      If filter is provided, jobStateMatcher will be ignored.

    • filter (::String) (defaults to: nil)

      Optional. A filter constraining the jobs to list. Filters are case-sensitive and have the following syntax:

      [field = value] AND [field [= value]] ...

      where field is status.state or labels.[KEY], and [KEY] is a label key. value can be * to match all values. status.state can be either ACTIVE or NON_ACTIVE. Only the logical AND operator is supported; space-separated items are treated as having an implicit AND operator.

      Example filter:

      status.state = ACTIVE AND labels.env = staging AND labels.starred = *

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
# File 'lib/google/cloud/dataproc/v1/job_controller/rest/client.rb', line 560

def list_jobs request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::ListJobsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_jobs..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_jobs.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_jobs.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @job_controller_stub.list_jobs request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @job_controller_stub, :list_jobs, "jobs", request, result, options
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#submit_job(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::Job #submit_job(project_id: nil, region: nil, job: nil, request_id: nil) ⇒ ::Google::Cloud::Dataproc::V1::Job

Submits a job to a cluster.

Examples:

Basic example

require "google/cloud/dataproc/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dataproc::V1::JobController::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dataproc::V1::SubmitJobRequest.new

# Call the submit_job method.
result = client.submit_job request

# The returned object is of type Google::Cloud::Dataproc::V1::Job.
p result

Overloads:

  • #submit_job(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::Job

    Pass arguments to submit_job via a request object, either of type SubmitJobRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::SubmitJobRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #submit_job(project_id: nil, region: nil, job: nil, request_id: nil) ⇒ ::Google::Cloud::Dataproc::V1::Job

    Pass arguments to submit_job via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      Required. The ID of the Google Cloud Platform project that the job belongs to.

    • region (::String) (defaults to: nil)

      Required. The Dataproc region in which to handle the request.

    • job (::Google::Cloud::Dataproc::V1::Job, ::Hash) (defaults to: nil)

      Required. The job resource.

    • request_id (::String) (defaults to: nil)

      Optional. A unique id used to identify the request. If the server receives two SubmitJobRequests with the same id, then the second request will be ignored and the first Job created and stored in the backend is returned.

      It is recommended to always set this value to a UUID.

      The id must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/google/cloud/dataproc/v1/job_controller/rest/client.rb', line 260

def submit_job request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::SubmitJobRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.submit_job..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.submit_job.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.submit_job.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @job_controller_stub.submit_job request, options do |result, operation|
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#submit_job_as_operation(request, options = nil) ⇒ ::Gapic::Operation #submit_job_as_operation(project_id: nil, region: nil, job: nil, request_id: nil) ⇒ ::Gapic::Operation

Submits job to a cluster.

Examples:

Basic example

require "google/cloud/dataproc/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dataproc::V1::JobController::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dataproc::V1::SubmitJobRequest.new

# Call the submit_job_as_operation method.
result = client.submit_job_as_operation request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #submit_job_as_operation(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to submit_job_as_operation via a request object, either of type SubmitJobRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::SubmitJobRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #submit_job_as_operation(project_id: nil, region: nil, job: nil, request_id: nil) ⇒ ::Gapic::Operation

    Pass arguments to submit_job_as_operation via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      Required. The ID of the Google Cloud Platform project that the job belongs to.

    • region (::String) (defaults to: nil)

      Required. The Dataproc region in which to handle the request.

    • job (::Google::Cloud::Dataproc::V1::Job, ::Hash) (defaults to: nil)

      Required. The job resource.

    • request_id (::String) (defaults to: nil)

      Optional. A unique id used to identify the request. If the server receives two SubmitJobRequests with the same id, then the second request will be ignored and the first Job created and stored in the backend is returned.

      It is recommended to always set this value to a UUID.

      The id must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/google/cloud/dataproc/v1/job_controller/rest/client.rb', line 363

def submit_job_as_operation request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::SubmitJobRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.submit_job_as_operation..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.submit_job_as_operation.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.submit_job_as_operation.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @job_controller_stub.submit_job_as_operation request, options do |result, operation|
    result = ::Gapic::Operation.new result, @operations_client, options: options
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#update_job(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::Job #update_job(project_id: nil, region: nil, job_id: nil, job: nil, update_mask: nil) ⇒ ::Google::Cloud::Dataproc::V1::Job

Updates a job in a project.

Examples:

Basic example

require "google/cloud/dataproc/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dataproc::V1::JobController::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dataproc::V1::UpdateJobRequest.new

# Call the update_job method.
result = client.update_job request

# The returned object is of type Google::Cloud::Dataproc::V1::Job.
p result

Overloads:

  • #update_job(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::Job

    Pass arguments to update_job via a request object, either of type UpdateJobRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::UpdateJobRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #update_job(project_id: nil, region: nil, job_id: nil, job: nil, update_mask: nil) ⇒ ::Google::Cloud::Dataproc::V1::Job

    Pass arguments to update_job via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      Required. The ID of the Google Cloud Platform project that the job belongs to.

    • region (::String) (defaults to: nil)

      Required. The Dataproc region in which to handle the request.

    • job_id (::String) (defaults to: nil)

      Required. The job ID.

    • job (::Google::Cloud::Dataproc::V1::Job, ::Hash) (defaults to: nil)

      Required. The changes to the job.

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Required. Specifies the path, relative to Job, of the field to update. For example, to update the labels of a Job the update_mask parameter would be specified as labels, and the PATCH request body would specify the new value. Note: Currently, labels is the only field that can be updated.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
# File 'lib/google/cloud/dataproc/v1/job_controller/rest/client.rb', line 653

def update_job request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::UpdateJobRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_job..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_job.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_job.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @job_controller_stub.update_job request, options do |result, operation|
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end