Class: Google::Cloud::Dataproc::V1::LifecycleConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::LifecycleConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataproc/v1/clusters.rb
Overview
Specifies the cluster auto-delete schedule configuration.
Instance Attribute Summary collapse
-
#auto_delete_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#auto_delete_ttl ⇒ ::Google::Protobuf::Duration
Optional.
-
#auto_stop_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#auto_stop_ttl ⇒ ::Google::Protobuf::Duration
Optional.
-
#idle_delete_ttl ⇒ ::Google::Protobuf::Duration
Optional.
-
#idle_start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#idle_stop_ttl ⇒ ::Google::Protobuf::Duration
Optional.
Instance Attribute Details
#auto_delete_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. The time when cluster will be auto-deleted (see JSON representation of Timestamp).
Note: The following fields are mutually exclusive: auto_delete_time, auto_delete_ttl. If a field in that set is populated, all other fields in the set will automatically be cleared.
1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1253 class LifecycleConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#auto_delete_ttl ⇒ ::Google::Protobuf::Duration
Returns Optional. The lifetime duration of cluster. The cluster will be auto-deleted at the end of this period. Minimum value is 10 minutes; maximum value is 14 days (see JSON representation of Duration).
Note: The following fields are mutually exclusive: auto_delete_ttl, auto_delete_time. If a field in that set is populated, all other fields in the set will automatically be cleared.
1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1253 class LifecycleConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#auto_stop_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. The time when cluster will be auto-stopped (see JSON representation of Timestamp).
Note: The following fields are mutually exclusive: auto_stop_time, auto_stop_ttl. If a field in that set is populated, all other fields in the set will automatically be cleared.
1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1253 class LifecycleConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#auto_stop_ttl ⇒ ::Google::Protobuf::Duration
Returns Optional. The lifetime duration of the cluster. The cluster will be auto-stopped at the end of this period, calculated from the time of submission of the create or update cluster request. Minimum value is 10 minutes; maximum value is 14 days (see JSON representation of Duration).
Note: The following fields are mutually exclusive: auto_stop_ttl, auto_stop_time. If a field in that set is populated, all other fields in the set will automatically be cleared.
1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1253 class LifecycleConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#idle_delete_ttl ⇒ ::Google::Protobuf::Duration
Returns Optional. The duration to keep the cluster alive while idling (when no jobs are running). Passing this threshold will cause the cluster to be deleted. Minimum value is 5 minutes; maximum value is 14 days (see JSON representation of Duration).
1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1253 class LifecycleConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#idle_start_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when cluster became idle (most recent job finished) and became eligible for deletion due to idleness (see JSON representation of Timestamp).
1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1253 class LifecycleConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#idle_stop_ttl ⇒ ::Google::Protobuf::Duration
Returns Optional. The duration to keep the cluster started while idling (when no jobs are running). Passing this threshold will cause the cluster to be stopped. Minimum value is 5 minutes; maximum value is 14 days (see JSON representation of Duration).
1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1253 class LifecycleConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |