Class: Google::Cloud::Dataproc::V1::ListBatchesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::ListBatchesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataproc/v1/batches.rb
Overview
A request to list batch workloads in a project.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. A filter for the batches to return in the response.
A filter is a logical expression constraining the values of various fields
in each batch resource. Filters are case sensitive, and may contain
multiple clauses combined with logical operators (AND/OR).
Supported fields are batch_id, batch_uuid, state, create_time, and
labels.
e.g. state = RUNNING and create_time < "2023-01-01T00:00:00Z"
filters for batches in state RUNNING that were created before 2023-01-01.
state = RUNNING and labels.environment=production filters for batches in
state in a RUNNING state that have a production environment label.
See https://google.aip.dev/assets/misc/ebnf-filtering.txt for a detailed description of the filter syntax and a list of supported comparisons.
104 105 106 107 |
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 104 class ListBatchesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Optional. Field(s) on which to sort the list of batches.
Currently the only supported sort orders are unspecified (empty) and
create_time desc to sort by most recently created batches first.
See https://google.aip.dev/132#ordering for more details.
104 105 106 107 |
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 104 class ListBatchesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The maximum number of batches to return in each response. The service may return fewer than this value. The default page size is 20; the maximum page size is 1000.
104 105 106 107 |
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 104 class ListBatchesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token received from a previous ListBatches call.
Provide this token to retrieve the subsequent page.
104 105 106 107 |
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 104 class ListBatchesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent, which owns this collection of batches.
104 105 106 107 |
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 104 class ListBatchesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |