Class: Google::Cloud::Dataproc::V1::ListBatchesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/batches.rb

Overview

A list of batch workloads.

Instance Attribute Summary collapse

Instance Attribute Details

#batches::Array<::Google::Cloud::Dataproc::V1::Batch> (readonly)

Returns Output only. The batches from the specified collection.

Returns:



122
123
124
125
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 122

class ListBatchesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



122
123
124
125
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 122

class ListBatchesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String> (readonly)

Returns Output only. List of Batches that could not be included in the response. Attempting to get one of these resources may indicate why it was not included in the list response.

Returns:

  • (::Array<::String>)

    Output only. List of Batches that could not be included in the response. Attempting to get one of these resources may indicate why it was not included in the list response.



122
123
124
125
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 122

class ListBatchesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end