Class: Google::Cloud::Dataproc::V1::ListJobsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/jobs.rb

Overview

A request to list jobs in a project.

Defined Under Namespace

Modules: JobStateMatcher

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_name::String

Returns Optional. If set, the returned jobs list includes only jobs that were submitted to the named cluster.

Returns:

  • (::String)

    Optional. If set, the returned jobs list includes only jobs that were submitted to the named cluster.



1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'proto_docs/google/cloud/dataproc/v1/jobs.rb', line 1092

class ListJobsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A matcher that specifies categories of job states.
  module JobStateMatcher
    # Match all jobs, regardless of state.
    ALL = 0

    # Only match jobs in non-terminal states: PENDING, RUNNING, or
    # CANCEL_PENDING.
    ACTIVE = 1

    # Only match jobs in terminal states: CANCELLED, DONE, or ERROR.
    NON_ACTIVE = 2
  end
end

#filter::String

Returns Optional. A filter constraining the jobs to list. Filters are case-sensitive and have the following syntax:

[field = value] AND [field [= value]] ...

where field is status.state or insertTime, or labels.[KEY], and [KEY] is a label key. value can be * to match all values. status.state can be either ACTIVE or NON_ACTIVE. Allows insertTime to be a timestamp in RFC 3339 format in double quotes, such as 2025-01-01T00:00:00Z. Only the logical AND operator is supported; space-separated items are treated as having an implicit AND operator.

Example filter:

status.state = ACTIVE AND labels.env = staging AND labels.starred = * AND insertTime <= "2025-01-01T00:00:00Z".

Returns:

  • (::String)

    Optional. A filter constraining the jobs to list. Filters are case-sensitive and have the following syntax:

    [field = value] AND [field [= value]] ...

    where field is status.state or insertTime, or labels.[KEY], and [KEY] is a label key. value can be * to match all values. status.state can be either ACTIVE or NON_ACTIVE. Allows insertTime to be a timestamp in RFC 3339 format in double quotes, such as 2025-01-01T00:00:00Z. Only the logical AND operator is supported; space-separated items are treated as having an implicit AND operator.

    Example filter:

    status.state = ACTIVE AND labels.env = staging AND labels.starred = * AND insertTime <= "2025-01-01T00:00:00Z"



1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'proto_docs/google/cloud/dataproc/v1/jobs.rb', line 1092

class ListJobsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A matcher that specifies categories of job states.
  module JobStateMatcher
    # Match all jobs, regardless of state.
    ALL = 0

    # Only match jobs in non-terminal states: PENDING, RUNNING, or
    # CANCEL_PENDING.
    ACTIVE = 1

    # Only match jobs in terminal states: CANCELLED, DONE, or ERROR.
    NON_ACTIVE = 2
  end
end

#job_state_matcher::Google::Cloud::Dataproc::V1::ListJobsRequest::JobStateMatcher

Returns Optional. Specifies enumerated categories of jobs to list. (default = match ALL jobs).

If filter is provided, jobStateMatcher will be ignored.

Returns:



1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'proto_docs/google/cloud/dataproc/v1/jobs.rb', line 1092

class ListJobsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A matcher that specifies categories of job states.
  module JobStateMatcher
    # Match all jobs, regardless of state.
    ALL = 0

    # Only match jobs in non-terminal states: PENDING, RUNNING, or
    # CANCEL_PENDING.
    ACTIVE = 1

    # Only match jobs in terminal states: CANCELLED, DONE, or ERROR.
    NON_ACTIVE = 2
  end
end

#page_size::Integer

Returns Optional. The number of results to return in each response.

Returns:

  • (::Integer)

    Optional. The number of results to return in each response.



1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'proto_docs/google/cloud/dataproc/v1/jobs.rb', line 1092

class ListJobsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A matcher that specifies categories of job states.
  module JobStateMatcher
    # Match all jobs, regardless of state.
    ALL = 0

    # Only match jobs in non-terminal states: PENDING, RUNNING, or
    # CANCEL_PENDING.
    ACTIVE = 1

    # Only match jobs in terminal states: CANCELLED, DONE, or ERROR.
    NON_ACTIVE = 2
  end
end

#page_token::String

Returns Optional. The page token, returned by a previous call, to request the next page of results.

Returns:

  • (::String)

    Optional. The page token, returned by a previous call, to request the next page of results.



1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'proto_docs/google/cloud/dataproc/v1/jobs.rb', line 1092

class ListJobsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A matcher that specifies categories of job states.
  module JobStateMatcher
    # Match all jobs, regardless of state.
    ALL = 0

    # Only match jobs in non-terminal states: PENDING, RUNNING, or
    # CANCEL_PENDING.
    ACTIVE = 1

    # Only match jobs in terminal states: CANCELLED, DONE, or ERROR.
    NON_ACTIVE = 2
  end
end

#project_id::String

Returns Required. The ID of the Google Cloud Platform project that the job belongs to.

Returns:

  • (::String)

    Required. The ID of the Google Cloud Platform project that the job belongs to.



1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'proto_docs/google/cloud/dataproc/v1/jobs.rb', line 1092

class ListJobsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A matcher that specifies categories of job states.
  module JobStateMatcher
    # Match all jobs, regardless of state.
    ALL = 0

    # Only match jobs in non-terminal states: PENDING, RUNNING, or
    # CANCEL_PENDING.
    ACTIVE = 1

    # Only match jobs in terminal states: CANCELLED, DONE, or ERROR.
    NON_ACTIVE = 2
  end
end

#region::String

Returns Required. The Dataproc region in which to handle the request.

Returns:

  • (::String)

    Required. The Dataproc region in which to handle the request.



1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'proto_docs/google/cloud/dataproc/v1/jobs.rb', line 1092

class ListJobsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A matcher that specifies categories of job states.
  module JobStateMatcher
    # Match all jobs, regardless of state.
    ALL = 0

    # Only match jobs in non-terminal states: PENDING, RUNNING, or
    # CANCEL_PENDING.
    ACTIVE = 1

    # Only match jobs in terminal states: CANCELLED, DONE, or ERROR.
    NON_ACTIVE = 2
  end
end