Class: Google::Cloud::Dataproc::V1::NodeGroup

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/clusters.rb

Overview

Dataproc Node Group. The Dataproc NodeGroup resource is not related to the Dataproc NodeGroupAffinity resource.

Defined Under Namespace

Modules: Role Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Node group labels.

  • Label keys must consist of from 1 to 63 characters and conform to RFC 1035.
  • Label values can be empty. If specified, they must consist of from 1 to 63 characters and conform to RFC 1035.
  • The node group must have no more than 32 labels.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Node group labels.

    • Label keys must consist of from 1 to 63 characters and conform to RFC 1035.
    • Label values can be empty. If specified, they must consist of from 1 to 63 characters and conform to RFC 1035.
    • The node group must have no more than 32 labels.


966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 966

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Node pool roles.
  module Role
    # Required unspecified role.
    ROLE_UNSPECIFIED = 0

    # Job drivers run on the node pool.
    DRIVER = 1
  end
end

#name::String

Returns The Node group resource name.

Returns:



966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 966

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Node pool roles.
  module Role
    # Required unspecified role.
    ROLE_UNSPECIFIED = 0

    # Job drivers run on the node pool.
    DRIVER = 1
  end
end

#node_group_config::Google::Cloud::Dataproc::V1::InstanceGroupConfig

Returns Optional. The node group instance group configuration.

Returns:



966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 966

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Node pool roles.
  module Role
    # Required unspecified role.
    ROLE_UNSPECIFIED = 0

    # Job drivers run on the node pool.
    DRIVER = 1
  end
end

#roles::Array<::Google::Cloud::Dataproc::V1::NodeGroup::Role>

Returns Required. Node group roles.

Returns:



966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 966

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Node pool roles.
  module Role
    # Required unspecified role.
    ROLE_UNSPECIFIED = 0

    # Job drivers run on the node pool.
    DRIVER = 1
  end
end