Class: Google::Cloud::Dataproc::V1::PySparkNotebookBatch

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/batches.rb

Overview

A configuration for running a PySpark Notebook batch workload.

Defined Under Namespace

Classes: ParamsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#archive_uris::Array<::String>

Returns Optional. HCFS URIs of archives to be extracted into the working directory of each executor. Supported file types: .jar, .tar, .tar.gz, .tgz, and .zip.

Returns:

  • (::Array<::String>)

    Optional. HCFS URIs of archives to be extracted into the working directory of each executor. Supported file types: .jar, .tar, .tar.gz, .tgz, and .zip.



409
410
411
412
413
414
415
416
417
418
419
420
421
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 409

class PySparkNotebookBatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#file_uris::Array<::String>

Returns Optional. HCFS URIs of files to be placed in the working directory of each executor.

Returns:

  • (::Array<::String>)

    Optional. HCFS URIs of files to be placed in the working directory of each executor



409
410
411
412
413
414
415
416
417
418
419
420
421
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 409

class PySparkNotebookBatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#jar_file_uris::Array<::String>

Returns Optional. HCFS URIs of jar files to be added to the Spark CLASSPATH.

Returns:

  • (::Array<::String>)

    Optional. HCFS URIs of jar files to be added to the Spark CLASSPATH.



409
410
411
412
413
414
415
416
417
418
419
420
421
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 409

class PySparkNotebookBatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#notebook_file_uri::String

Returns Required. The HCFS URI of the notebook file to execute.

Returns:

  • (::String)

    Required. The HCFS URI of the notebook file to execute.



409
410
411
412
413
414
415
416
417
418
419
420
421
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 409

class PySparkNotebookBatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#params::Google::Protobuf::Map{::String => ::String}

Returns Optional. The parameters to pass to the notebook.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. The parameters to pass to the notebook.



409
410
411
412
413
414
415
416
417
418
419
420
421
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 409

class PySparkNotebookBatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#python_file_uris::Array<::String>

Returns Optional. HCFS URIs of Python files to pass to the PySpark framework.

Returns:

  • (::Array<::String>)

    Optional. HCFS URIs of Python files to pass to the PySpark framework.



409
410
411
412
413
414
415
416
417
418
419
420
421
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 409

class PySparkNotebookBatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end