Class: Google::Cloud::Dataproc::V1::RuntimeInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/shared.rb

Overview

Runtime information about workload execution.

Defined Under Namespace

Classes: EndpointsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_usage::Google::Cloud::Dataproc::V1::UsageMetrics (readonly)

Returns Output only. Approximate workload resource usage, calculated when the workload completes (see Dataproc Serverless pricing).

Note: This metric calculation may change in the future, for example, to capture cumulative workload resource consumption during workload execution (see the Dataproc Serverless release notes for announcements, changes, fixes and other Dataproc developments).

Returns:



216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'proto_docs/google/cloud/dataproc/v1/shared.rb', line 216

class RuntimeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#current_usage::Google::Cloud::Dataproc::V1::UsageSnapshot (readonly)

Returns Output only. Snapshot of current workload resource usage.

Returns:



216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'proto_docs/google/cloud/dataproc/v1/shared.rb', line 216

class RuntimeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#diagnostic_output_uri::String (readonly)

Returns Output only. A URI pointing to the location of the diagnostics tarball.

Returns:

  • (::String)

    Output only. A URI pointing to the location of the diagnostics tarball.



216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'proto_docs/google/cloud/dataproc/v1/shared.rb', line 216

class RuntimeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#endpoints::Google::Protobuf::Map{::String => ::String} (readonly)

Returns Output only. Map of remote access endpoints (such as web interfaces and APIs) to their URIs.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Output only. Map of remote access endpoints (such as web interfaces and APIs) to their URIs.



216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'proto_docs/google/cloud/dataproc/v1/shared.rb', line 216

class RuntimeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#output_uri::String (readonly)

Returns Output only. A URI pointing to the location of the stdout and stderr of the workload.

Returns:

  • (::String)

    Output only. A URI pointing to the location of the stdout and stderr of the workload.



216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'proto_docs/google/cloud/dataproc/v1/shared.rb', line 216

class RuntimeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end