Class: Google::Cloud::Dataproc::V1::Session

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/sessions.rb

Overview

A representation of a session.

Defined Under Namespace

Modules: State Classes: LabelsEntry, SessionStateHistory

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the session was created.

Returns:



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end

#creator::String (readonly)

Returns Output only. The email address of the user who created the session.

Returns:

  • (::String)

    Output only. The email address of the user who created the session.



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end

#environment_config::Google::Cloud::Dataproc::V1::EnvironmentConfig

Returns Optional. Environment configuration for the session execution.

Returns:



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end

#jupyter_session::Google::Cloud::Dataproc::V1::JupyterConfig

Returns Optional. Jupyter session config.

Note: The following fields are mutually exclusive: jupyter_session, spark_connect_session. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dataproc::V1::JupyterConfig)

    Optional. Jupyter session config.

    Note: The following fields are mutually exclusive: jupyter_session, spark_connect_session. If a field in that set is populated, all other fields in the set will automatically be cleared.



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. The labels to associate with the session. Label keys must contain 1 to 63 characters, and must conform to RFC 1035. Label values may be empty, but, if present, must contain 1 to 63 characters, and must conform to RFC 1035. No more than 32 labels can be associated with a session.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. The labels to associate with the session. Label keys must contain 1 to 63 characters, and must conform to RFC 1035. Label values may be empty, but, if present, must contain 1 to 63 characters, and must conform to RFC 1035. No more than 32 labels can be associated with a session.



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end

#name::String

Returns Required. The resource name of the session.

Returns:

  • (::String)

    Required. The resource name of the session.



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end

#runtime_config::Google::Cloud::Dataproc::V1::RuntimeConfig

Returns Optional. Runtime configuration for the session execution.

Returns:



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end

#runtime_info::Google::Cloud::Dataproc::V1::RuntimeInfo (readonly)

Returns Output only. Runtime information about session execution.

Returns:



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end

#session_template::String

Returns Optional. The session template used by the session.

Only resource names, including project ID and location, are valid.

Example:

  • https://www.googleapis.com/compute/v1/projects/[project_id]/locations/[dataproc_region]/sessionTemplates/[template_id]
  • projects/[project_id]/locations/[dataproc_region]/sessionTemplates/[template_id]

The template must be in the same project and Dataproc region as the session.

Returns:

  • (::String)

    Optional. The session template used by the session.

    Only resource names, including project ID and location, are valid.

    Example:

    • https://www.googleapis.com/compute/v1/projects/[project_id]/locations/[dataproc_region]/sessionTemplates/[template_id]
    • projects/[project_id]/locations/[dataproc_region]/sessionTemplates/[template_id]

    The template must be in the same project and Dataproc region as the session.



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end

#spark_connect_session::Google::Cloud::Dataproc::V1::SparkConnectConfig

Returns Optional. Spark Connect session config.

Note: The following fields are mutually exclusive: spark_connect_session, jupyter_session. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dataproc::V1::SparkConnectConfig)

    Optional. Spark Connect session config.

    Note: The following fields are mutually exclusive: spark_connect_session, jupyter_session. If a field in that set is populated, all other fields in the set will automatically be cleared.



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end

#state::Google::Cloud::Dataproc::V1::Session::State (readonly)

Returns Output only. A state of the session.

Returns:



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end

#state_history::Array<::Google::Cloud::Dataproc::V1::Session::SessionStateHistory> (readonly)

Returns Output only. Historical state information for the session.

Returns:



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end

#state_message::String (readonly)

Returns Output only. Session state details, such as the failure description if the state is FAILED.

Returns:

  • (::String)

    Output only. Session state details, such as the failure description if the state is FAILED.



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end

#state_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the session entered the current state.

Returns:



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end

#user::String

Returns Optional. The email address of the user who owns the session.

Returns:

  • (::String)

    Optional. The email address of the user who owns the session.



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end

#uuid::String (readonly)

Returns Output only. A session UUID (Unique Universal Identifier). The service generates this value when it creates the session.

Returns:

  • (::String)

    Output only. A session UUID (Unique Universal Identifier). The service generates this value when it creates the session.



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/dataproc/v1/sessions.rb', line 225

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Historical state information.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataproc::V1::Session::State]
  #     Output only. The state of the session at this point in the session
  #     history.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. Details about the state at this point in the session
  #     history.
  # @!attribute [r] state_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time when the session entered the historical state.
  class SessionStateHistory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The session state.
  module State
    # The session state is unknown.
    STATE_UNSPECIFIED = 0

    # The session is created prior to running.
    CREATING = 1

    # The session is running.
    ACTIVE = 2

    # The session is terminating.
    TERMINATING = 3

    # The session is terminated successfully.
    TERMINATED = 4

    # The session is no longer running due to an error.
    FAILED = 5
  end
end