Class: Google::Cloud::Dataproc::V1::StopClusterRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::StopClusterRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataproc/v1/clusters.rb
Overview
A request to stop a cluster.
Instance Attribute Summary collapse
-
#cluster_name ⇒ ::String
Required.
-
#cluster_uuid ⇒ ::String
Optional.
-
#project_id ⇒ ::String
Required.
-
#region ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#cluster_name ⇒ ::String
Returns Required. The cluster name.
1642 1643 1644 1645 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1642 class StopClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cluster_uuid ⇒ ::String
Returns Optional. Specifying the cluster_uuid means the RPC will fail
(with error NOT_FOUND) if a cluster with the specified UUID does not exist.
1642 1643 1644 1645 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1642 class StopClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project_id ⇒ ::String
Returns Required. The ID of the Google Cloud Platform project the cluster belongs to.
1642 1643 1644 1645 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1642 class StopClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#region ⇒ ::String
Returns Required. The Dataproc region in which to handle the request.
1642 1643 1644 1645 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1642 class StopClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. A unique ID used to identify the request. If the server receives two StopClusterRequests with the same id, then the second request will be ignored and the first google.longrunning.Operation created and stored in the backend is returned.
Recommendation: Set this value to a UUID.
The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters.
1642 1643 1644 1645 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1642 class StopClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |