Class: Google::Cloud::Dataproc::V1::VirtualClusterConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::VirtualClusterConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataproc/v1/clusters.rb
Overview
Dataproc cluster config for a cluster that does not directly control the underlying compute resources, such as a Dataproc-on-GKE cluster.
Instance Attribute Summary collapse
-
#auxiliary_services_config ⇒ ::Google::Cloud::Dataproc::V1::AuxiliaryServicesConfig
Optional.
-
#kubernetes_cluster_config ⇒ ::Google::Cloud::Dataproc::V1::KubernetesClusterConfig
Required.
-
#staging_bucket ⇒ ::String
Optional.
-
#temp_bucket ⇒ ::String
Optional.
Instance Attribute Details
#auxiliary_services_config ⇒ ::Google::Cloud::Dataproc::V1::AuxiliaryServicesConfig
Returns Optional. Configuration of auxiliary services used by this cluster.
210 211 212 213 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 210 class VirtualClusterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kubernetes_cluster_config ⇒ ::Google::Cloud::Dataproc::V1::KubernetesClusterConfig
Returns Required. The configuration for running the Dataproc cluster on Kubernetes.
210 211 212 213 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 210 class VirtualClusterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#staging_bucket ⇒ ::String
Returns Optional. A Storage bucket used to stage job
dependencies, config files, and job driver console output.
If you do not specify a staging bucket, Cloud
Dataproc will determine a Cloud Storage location (US,
ASIA, or EU) for your cluster's staging bucket according to the
Compute Engine zone where your cluster is deployed, and then create
and manage this project-level, per-location bucket (see
Dataproc staging and temp
buckets).
This field requires a Cloud Storage bucket name, not a gs://... URI to
a Cloud Storage bucket..
210 211 212 213 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 210 class VirtualClusterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#temp_bucket ⇒ ::String
Returns Optional. A Cloud Storage bucket used to store ephemeral cluster and jobs data,
such as Spark and MapReduce history files.
If you do not specify a temp bucket,
Dataproc will determine a Cloud Storage location (US,
ASIA, or EU) for your cluster's temp bucket according to the
Compute Engine zone where your cluster is deployed, and then create
and manage this project-level, per-location bucket. The default bucket has
a TTL of 90 days, but you can use any TTL (or none) if you specify a
bucket (see
Dataproc staging and temp
buckets).
This field requires a Cloud Storage bucket name, not a gs://... URI to
a Cloud Storage bucket..
210 211 212 213 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 210 class VirtualClusterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |