Class: Google::Cloud::Dataproc::V1::WorkflowTemplateService::Rest::Client::Configuration

Inherits:
Object
  • Object
show all
Extended by:
Gapic::Config
Defined in:
lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb

Overview

Configuration class for the WorkflowTemplateService REST API.

This class represents the configuration for WorkflowTemplateService REST, providing control over timeouts, retry behavior, logging, transport parameters, and other low-level controls. Certain parameters can also be applied individually to specific RPCs. See Rpcs for a list of RPCs that can be configured independently.

Configuration can be applied globally to all clients, or to a single client on construction.

Examples:


# Modify the global config, setting the timeout for
# create_workflow_template to 20 seconds,
# and all remaining timeouts to 10 seconds.
::Google::Cloud::Dataproc::V1::WorkflowTemplateService::Rest::Client.configure do |config|
  config.timeout = 10.0
  config.rpcs.create_workflow_template.timeout = 20.0
end

# Apply the above configuration only to a new client.
client = ::Google::Cloud::Dataproc::V1::WorkflowTemplateService::Rest::Client.new do |config|
  config.timeout = 10.0
  config.rpcs.create_workflow_template.timeout = 20.0
end

Defined Under Namespace

Classes: Rpcs

Constant Summary collapse

DEFAULT_ENDPOINT =
"dataproc.googleapis.com"

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#credentials::Object

Credentials to send with calls. You may provide any of the following types:

  • (String) The path to a service account key file in JSON format
  • (Hash) A service account key as a Hash
  • (Google::Auth::Credentials) A googleauth credentials object (see the googleauth docs)
  • (Signet::OAuth2::Client) A signet oauth2 client object (see the signet docs)
  • (nil) indicating no credentials

Returns:

  • (::Object)


990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 990

class Configuration
  extend ::Gapic::Config

  DEFAULT_ENDPOINT = "dataproc.googleapis.com"

  config_attr :endpoint,      DEFAULT_ENDPOINT, ::String
  config_attr :credentials,   nil do |value|
    allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil]
    allowed.any? { |klass| klass === value }
  end
  config_attr :scope,         nil, ::String, ::Array, nil
  config_attr :lib_name,      nil, ::String, nil
  config_attr :lib_version,   nil, ::String, nil
  config_attr :timeout,       nil, ::Numeric, nil
  config_attr :metadata,      nil, ::Hash, nil
  config_attr :retry_policy,  nil, ::Hash, ::Proc, nil
  config_attr :quota_project, nil, ::String, nil

  # @private
  # Overrides for http bindings for the RPCs of this service
  # are only used when this service is used as mixin, and only
  # by the host service.
  # @return [::Hash{::Symbol=>::Array<::Gapic::Rest::GrpcTranscoder::HttpBinding>}]
  config_attr :bindings_override, {}, ::Hash, nil

  # @private
  def initialize parent_config = nil
    @parent_config = parent_config unless parent_config.nil?

    yield self if block_given?
  end

  ##
  # Configurations for individual RPCs
  # @return [Rpcs]
  #
  def rpcs
    @rpcs ||= begin
      parent_rpcs = nil
      parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs)
      Rpcs.new parent_rpcs
    end
  end

  ##
  # Configuration RPC class for the WorkflowTemplateService API.
  #
  # Includes fields providing the configuration for each RPC in this service.
  # Each configuration object is of type `Gapic::Config::Method` and includes
  # the following configuration fields:
  #
  #  *  `timeout` (*type:* `Numeric`) - The call timeout in seconds
  #  *  `metadata` (*type:* `Hash{Symbol=>String}`) - Additional headers
  #  *  `retry_policy (*type:* `Hash`) - The retry policy. The policy fields
  #     include the following keys:
  #      *  `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
  #      *  `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
  #      *  `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
  #      *  `:retry_codes` (*type:* `Array<String>`) - The error codes that should
  #         trigger a retry.
  #
  class Rpcs
    ##
    # RPC-specific configuration for `create_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :create_workflow_template
    ##
    # RPC-specific configuration for `get_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :get_workflow_template
    ##
    # RPC-specific configuration for `instantiate_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_workflow_template
    ##
    # RPC-specific configuration for `instantiate_inline_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_inline_workflow_template
    ##
    # RPC-specific configuration for `update_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :update_workflow_template
    ##
    # RPC-specific configuration for `list_workflow_templates`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :list_workflow_templates
    ##
    # RPC-specific configuration for `delete_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :delete_workflow_template

    # @private
    def initialize parent_rpcs = nil
      create_workflow_template_config = parent_rpcs.create_workflow_template if parent_rpcs.respond_to? :create_workflow_template
      @create_workflow_template = ::Gapic::Config::Method.new create_workflow_template_config
      get_workflow_template_config = parent_rpcs.get_workflow_template if parent_rpcs.respond_to? :get_workflow_template
      @get_workflow_template = ::Gapic::Config::Method.new get_workflow_template_config
      instantiate_workflow_template_config = parent_rpcs.instantiate_workflow_template if parent_rpcs.respond_to? :instantiate_workflow_template
      @instantiate_workflow_template = ::Gapic::Config::Method.new instantiate_workflow_template_config
      instantiate_inline_workflow_template_config = parent_rpcs.instantiate_inline_workflow_template if parent_rpcs.respond_to? :instantiate_inline_workflow_template
      @instantiate_inline_workflow_template = ::Gapic::Config::Method.new instantiate_inline_workflow_template_config
      update_workflow_template_config = parent_rpcs.update_workflow_template if parent_rpcs.respond_to? :update_workflow_template
      @update_workflow_template = ::Gapic::Config::Method.new update_workflow_template_config
      list_workflow_templates_config = parent_rpcs.list_workflow_templates if parent_rpcs.respond_to? :list_workflow_templates
      @list_workflow_templates = ::Gapic::Config::Method.new list_workflow_templates_config
      delete_workflow_template_config = parent_rpcs.delete_workflow_template if parent_rpcs.respond_to? :delete_workflow_template
      @delete_workflow_template = ::Gapic::Config::Method.new delete_workflow_template_config

      yield self if block_given?
    end
  end
end

#endpoint::String

The hostname or hostname:port of the service endpoint. Defaults to "dataproc.googleapis.com".

Returns:

  • (::String)


990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 990

class Configuration
  extend ::Gapic::Config

  DEFAULT_ENDPOINT = "dataproc.googleapis.com"

  config_attr :endpoint,      DEFAULT_ENDPOINT, ::String
  config_attr :credentials,   nil do |value|
    allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil]
    allowed.any? { |klass| klass === value }
  end
  config_attr :scope,         nil, ::String, ::Array, nil
  config_attr :lib_name,      nil, ::String, nil
  config_attr :lib_version,   nil, ::String, nil
  config_attr :timeout,       nil, ::Numeric, nil
  config_attr :metadata,      nil, ::Hash, nil
  config_attr :retry_policy,  nil, ::Hash, ::Proc, nil
  config_attr :quota_project, nil, ::String, nil

  # @private
  # Overrides for http bindings for the RPCs of this service
  # are only used when this service is used as mixin, and only
  # by the host service.
  # @return [::Hash{::Symbol=>::Array<::Gapic::Rest::GrpcTranscoder::HttpBinding>}]
  config_attr :bindings_override, {}, ::Hash, nil

  # @private
  def initialize parent_config = nil
    @parent_config = parent_config unless parent_config.nil?

    yield self if block_given?
  end

  ##
  # Configurations for individual RPCs
  # @return [Rpcs]
  #
  def rpcs
    @rpcs ||= begin
      parent_rpcs = nil
      parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs)
      Rpcs.new parent_rpcs
    end
  end

  ##
  # Configuration RPC class for the WorkflowTemplateService API.
  #
  # Includes fields providing the configuration for each RPC in this service.
  # Each configuration object is of type `Gapic::Config::Method` and includes
  # the following configuration fields:
  #
  #  *  `timeout` (*type:* `Numeric`) - The call timeout in seconds
  #  *  `metadata` (*type:* `Hash{Symbol=>String}`) - Additional headers
  #  *  `retry_policy (*type:* `Hash`) - The retry policy. The policy fields
  #     include the following keys:
  #      *  `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
  #      *  `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
  #      *  `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
  #      *  `:retry_codes` (*type:* `Array<String>`) - The error codes that should
  #         trigger a retry.
  #
  class Rpcs
    ##
    # RPC-specific configuration for `create_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :create_workflow_template
    ##
    # RPC-specific configuration for `get_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :get_workflow_template
    ##
    # RPC-specific configuration for `instantiate_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_workflow_template
    ##
    # RPC-specific configuration for `instantiate_inline_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_inline_workflow_template
    ##
    # RPC-specific configuration for `update_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :update_workflow_template
    ##
    # RPC-specific configuration for `list_workflow_templates`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :list_workflow_templates
    ##
    # RPC-specific configuration for `delete_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :delete_workflow_template

    # @private
    def initialize parent_rpcs = nil
      create_workflow_template_config = parent_rpcs.create_workflow_template if parent_rpcs.respond_to? :create_workflow_template
      @create_workflow_template = ::Gapic::Config::Method.new create_workflow_template_config
      get_workflow_template_config = parent_rpcs.get_workflow_template if parent_rpcs.respond_to? :get_workflow_template
      @get_workflow_template = ::Gapic::Config::Method.new get_workflow_template_config
      instantiate_workflow_template_config = parent_rpcs.instantiate_workflow_template if parent_rpcs.respond_to? :instantiate_workflow_template
      @instantiate_workflow_template = ::Gapic::Config::Method.new instantiate_workflow_template_config
      instantiate_inline_workflow_template_config = parent_rpcs.instantiate_inline_workflow_template if parent_rpcs.respond_to? :instantiate_inline_workflow_template
      @instantiate_inline_workflow_template = ::Gapic::Config::Method.new instantiate_inline_workflow_template_config
      update_workflow_template_config = parent_rpcs.update_workflow_template if parent_rpcs.respond_to? :update_workflow_template
      @update_workflow_template = ::Gapic::Config::Method.new update_workflow_template_config
      list_workflow_templates_config = parent_rpcs.list_workflow_templates if parent_rpcs.respond_to? :list_workflow_templates
      @list_workflow_templates = ::Gapic::Config::Method.new list_workflow_templates_config
      delete_workflow_template_config = parent_rpcs.delete_workflow_template if parent_rpcs.respond_to? :delete_workflow_template
      @delete_workflow_template = ::Gapic::Config::Method.new delete_workflow_template_config

      yield self if block_given?
    end
  end
end

#lib_name::String

The library name as recorded in instrumentation and logging

Returns:

  • (::String)


990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 990

class Configuration
  extend ::Gapic::Config

  DEFAULT_ENDPOINT = "dataproc.googleapis.com"

  config_attr :endpoint,      DEFAULT_ENDPOINT, ::String
  config_attr :credentials,   nil do |value|
    allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil]
    allowed.any? { |klass| klass === value }
  end
  config_attr :scope,         nil, ::String, ::Array, nil
  config_attr :lib_name,      nil, ::String, nil
  config_attr :lib_version,   nil, ::String, nil
  config_attr :timeout,       nil, ::Numeric, nil
  config_attr :metadata,      nil, ::Hash, nil
  config_attr :retry_policy,  nil, ::Hash, ::Proc, nil
  config_attr :quota_project, nil, ::String, nil

  # @private
  # Overrides for http bindings for the RPCs of this service
  # are only used when this service is used as mixin, and only
  # by the host service.
  # @return [::Hash{::Symbol=>::Array<::Gapic::Rest::GrpcTranscoder::HttpBinding>}]
  config_attr :bindings_override, {}, ::Hash, nil

  # @private
  def initialize parent_config = nil
    @parent_config = parent_config unless parent_config.nil?

    yield self if block_given?
  end

  ##
  # Configurations for individual RPCs
  # @return [Rpcs]
  #
  def rpcs
    @rpcs ||= begin
      parent_rpcs = nil
      parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs)
      Rpcs.new parent_rpcs
    end
  end

  ##
  # Configuration RPC class for the WorkflowTemplateService API.
  #
  # Includes fields providing the configuration for each RPC in this service.
  # Each configuration object is of type `Gapic::Config::Method` and includes
  # the following configuration fields:
  #
  #  *  `timeout` (*type:* `Numeric`) - The call timeout in seconds
  #  *  `metadata` (*type:* `Hash{Symbol=>String}`) - Additional headers
  #  *  `retry_policy (*type:* `Hash`) - The retry policy. The policy fields
  #     include the following keys:
  #      *  `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
  #      *  `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
  #      *  `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
  #      *  `:retry_codes` (*type:* `Array<String>`) - The error codes that should
  #         trigger a retry.
  #
  class Rpcs
    ##
    # RPC-specific configuration for `create_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :create_workflow_template
    ##
    # RPC-specific configuration for `get_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :get_workflow_template
    ##
    # RPC-specific configuration for `instantiate_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_workflow_template
    ##
    # RPC-specific configuration for `instantiate_inline_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_inline_workflow_template
    ##
    # RPC-specific configuration for `update_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :update_workflow_template
    ##
    # RPC-specific configuration for `list_workflow_templates`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :list_workflow_templates
    ##
    # RPC-specific configuration for `delete_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :delete_workflow_template

    # @private
    def initialize parent_rpcs = nil
      create_workflow_template_config = parent_rpcs.create_workflow_template if parent_rpcs.respond_to? :create_workflow_template
      @create_workflow_template = ::Gapic::Config::Method.new create_workflow_template_config
      get_workflow_template_config = parent_rpcs.get_workflow_template if parent_rpcs.respond_to? :get_workflow_template
      @get_workflow_template = ::Gapic::Config::Method.new get_workflow_template_config
      instantiate_workflow_template_config = parent_rpcs.instantiate_workflow_template if parent_rpcs.respond_to? :instantiate_workflow_template
      @instantiate_workflow_template = ::Gapic::Config::Method.new instantiate_workflow_template_config
      instantiate_inline_workflow_template_config = parent_rpcs.instantiate_inline_workflow_template if parent_rpcs.respond_to? :instantiate_inline_workflow_template
      @instantiate_inline_workflow_template = ::Gapic::Config::Method.new instantiate_inline_workflow_template_config
      update_workflow_template_config = parent_rpcs.update_workflow_template if parent_rpcs.respond_to? :update_workflow_template
      @update_workflow_template = ::Gapic::Config::Method.new update_workflow_template_config
      list_workflow_templates_config = parent_rpcs.list_workflow_templates if parent_rpcs.respond_to? :list_workflow_templates
      @list_workflow_templates = ::Gapic::Config::Method.new list_workflow_templates_config
      delete_workflow_template_config = parent_rpcs.delete_workflow_template if parent_rpcs.respond_to? :delete_workflow_template
      @delete_workflow_template = ::Gapic::Config::Method.new delete_workflow_template_config

      yield self if block_given?
    end
  end
end

#lib_version::String

The library version as recorded in instrumentation and logging

Returns:

  • (::String)


990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 990

class Configuration
  extend ::Gapic::Config

  DEFAULT_ENDPOINT = "dataproc.googleapis.com"

  config_attr :endpoint,      DEFAULT_ENDPOINT, ::String
  config_attr :credentials,   nil do |value|
    allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil]
    allowed.any? { |klass| klass === value }
  end
  config_attr :scope,         nil, ::String, ::Array, nil
  config_attr :lib_name,      nil, ::String, nil
  config_attr :lib_version,   nil, ::String, nil
  config_attr :timeout,       nil, ::Numeric, nil
  config_attr :metadata,      nil, ::Hash, nil
  config_attr :retry_policy,  nil, ::Hash, ::Proc, nil
  config_attr :quota_project, nil, ::String, nil

  # @private
  # Overrides for http bindings for the RPCs of this service
  # are only used when this service is used as mixin, and only
  # by the host service.
  # @return [::Hash{::Symbol=>::Array<::Gapic::Rest::GrpcTranscoder::HttpBinding>}]
  config_attr :bindings_override, {}, ::Hash, nil

  # @private
  def initialize parent_config = nil
    @parent_config = parent_config unless parent_config.nil?

    yield self if block_given?
  end

  ##
  # Configurations for individual RPCs
  # @return [Rpcs]
  #
  def rpcs
    @rpcs ||= begin
      parent_rpcs = nil
      parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs)
      Rpcs.new parent_rpcs
    end
  end

  ##
  # Configuration RPC class for the WorkflowTemplateService API.
  #
  # Includes fields providing the configuration for each RPC in this service.
  # Each configuration object is of type `Gapic::Config::Method` and includes
  # the following configuration fields:
  #
  #  *  `timeout` (*type:* `Numeric`) - The call timeout in seconds
  #  *  `metadata` (*type:* `Hash{Symbol=>String}`) - Additional headers
  #  *  `retry_policy (*type:* `Hash`) - The retry policy. The policy fields
  #     include the following keys:
  #      *  `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
  #      *  `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
  #      *  `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
  #      *  `:retry_codes` (*type:* `Array<String>`) - The error codes that should
  #         trigger a retry.
  #
  class Rpcs
    ##
    # RPC-specific configuration for `create_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :create_workflow_template
    ##
    # RPC-specific configuration for `get_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :get_workflow_template
    ##
    # RPC-specific configuration for `instantiate_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_workflow_template
    ##
    # RPC-specific configuration for `instantiate_inline_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_inline_workflow_template
    ##
    # RPC-specific configuration for `update_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :update_workflow_template
    ##
    # RPC-specific configuration for `list_workflow_templates`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :list_workflow_templates
    ##
    # RPC-specific configuration for `delete_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :delete_workflow_template

    # @private
    def initialize parent_rpcs = nil
      create_workflow_template_config = parent_rpcs.create_workflow_template if parent_rpcs.respond_to? :create_workflow_template
      @create_workflow_template = ::Gapic::Config::Method.new create_workflow_template_config
      get_workflow_template_config = parent_rpcs.get_workflow_template if parent_rpcs.respond_to? :get_workflow_template
      @get_workflow_template = ::Gapic::Config::Method.new get_workflow_template_config
      instantiate_workflow_template_config = parent_rpcs.instantiate_workflow_template if parent_rpcs.respond_to? :instantiate_workflow_template
      @instantiate_workflow_template = ::Gapic::Config::Method.new instantiate_workflow_template_config
      instantiate_inline_workflow_template_config = parent_rpcs.instantiate_inline_workflow_template if parent_rpcs.respond_to? :instantiate_inline_workflow_template
      @instantiate_inline_workflow_template = ::Gapic::Config::Method.new instantiate_inline_workflow_template_config
      update_workflow_template_config = parent_rpcs.update_workflow_template if parent_rpcs.respond_to? :update_workflow_template
      @update_workflow_template = ::Gapic::Config::Method.new update_workflow_template_config
      list_workflow_templates_config = parent_rpcs.list_workflow_templates if parent_rpcs.respond_to? :list_workflow_templates
      @list_workflow_templates = ::Gapic::Config::Method.new list_workflow_templates_config
      delete_workflow_template_config = parent_rpcs.delete_workflow_template if parent_rpcs.respond_to? :delete_workflow_template
      @delete_workflow_template = ::Gapic::Config::Method.new delete_workflow_template_config

      yield self if block_given?
    end
  end
end

#metadata::Hash{::Symbol=>::String}

Additional headers to be sent with the call.

Returns:

  • (::Hash{::Symbol=>::String})


990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 990

class Configuration
  extend ::Gapic::Config

  DEFAULT_ENDPOINT = "dataproc.googleapis.com"

  config_attr :endpoint,      DEFAULT_ENDPOINT, ::String
  config_attr :credentials,   nil do |value|
    allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil]
    allowed.any? { |klass| klass === value }
  end
  config_attr :scope,         nil, ::String, ::Array, nil
  config_attr :lib_name,      nil, ::String, nil
  config_attr :lib_version,   nil, ::String, nil
  config_attr :timeout,       nil, ::Numeric, nil
  config_attr :metadata,      nil, ::Hash, nil
  config_attr :retry_policy,  nil, ::Hash, ::Proc, nil
  config_attr :quota_project, nil, ::String, nil

  # @private
  # Overrides for http bindings for the RPCs of this service
  # are only used when this service is used as mixin, and only
  # by the host service.
  # @return [::Hash{::Symbol=>::Array<::Gapic::Rest::GrpcTranscoder::HttpBinding>}]
  config_attr :bindings_override, {}, ::Hash, nil

  # @private
  def initialize parent_config = nil
    @parent_config = parent_config unless parent_config.nil?

    yield self if block_given?
  end

  ##
  # Configurations for individual RPCs
  # @return [Rpcs]
  #
  def rpcs
    @rpcs ||= begin
      parent_rpcs = nil
      parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs)
      Rpcs.new parent_rpcs
    end
  end

  ##
  # Configuration RPC class for the WorkflowTemplateService API.
  #
  # Includes fields providing the configuration for each RPC in this service.
  # Each configuration object is of type `Gapic::Config::Method` and includes
  # the following configuration fields:
  #
  #  *  `timeout` (*type:* `Numeric`) - The call timeout in seconds
  #  *  `metadata` (*type:* `Hash{Symbol=>String}`) - Additional headers
  #  *  `retry_policy (*type:* `Hash`) - The retry policy. The policy fields
  #     include the following keys:
  #      *  `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
  #      *  `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
  #      *  `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
  #      *  `:retry_codes` (*type:* `Array<String>`) - The error codes that should
  #         trigger a retry.
  #
  class Rpcs
    ##
    # RPC-specific configuration for `create_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :create_workflow_template
    ##
    # RPC-specific configuration for `get_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :get_workflow_template
    ##
    # RPC-specific configuration for `instantiate_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_workflow_template
    ##
    # RPC-specific configuration for `instantiate_inline_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_inline_workflow_template
    ##
    # RPC-specific configuration for `update_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :update_workflow_template
    ##
    # RPC-specific configuration for `list_workflow_templates`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :list_workflow_templates
    ##
    # RPC-specific configuration for `delete_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :delete_workflow_template

    # @private
    def initialize parent_rpcs = nil
      create_workflow_template_config = parent_rpcs.create_workflow_template if parent_rpcs.respond_to? :create_workflow_template
      @create_workflow_template = ::Gapic::Config::Method.new create_workflow_template_config
      get_workflow_template_config = parent_rpcs.get_workflow_template if parent_rpcs.respond_to? :get_workflow_template
      @get_workflow_template = ::Gapic::Config::Method.new get_workflow_template_config
      instantiate_workflow_template_config = parent_rpcs.instantiate_workflow_template if parent_rpcs.respond_to? :instantiate_workflow_template
      @instantiate_workflow_template = ::Gapic::Config::Method.new instantiate_workflow_template_config
      instantiate_inline_workflow_template_config = parent_rpcs.instantiate_inline_workflow_template if parent_rpcs.respond_to? :instantiate_inline_workflow_template
      @instantiate_inline_workflow_template = ::Gapic::Config::Method.new instantiate_inline_workflow_template_config
      update_workflow_template_config = parent_rpcs.update_workflow_template if parent_rpcs.respond_to? :update_workflow_template
      @update_workflow_template = ::Gapic::Config::Method.new update_workflow_template_config
      list_workflow_templates_config = parent_rpcs.list_workflow_templates if parent_rpcs.respond_to? :list_workflow_templates
      @list_workflow_templates = ::Gapic::Config::Method.new list_workflow_templates_config
      delete_workflow_template_config = parent_rpcs.delete_workflow_template if parent_rpcs.respond_to? :delete_workflow_template
      @delete_workflow_template = ::Gapic::Config::Method.new delete_workflow_template_config

      yield self if block_given?
    end
  end
end

#quota_project::String

A separate project against which to charge quota.

Returns:

  • (::String)


990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 990

class Configuration
  extend ::Gapic::Config

  DEFAULT_ENDPOINT = "dataproc.googleapis.com"

  config_attr :endpoint,      DEFAULT_ENDPOINT, ::String
  config_attr :credentials,   nil do |value|
    allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil]
    allowed.any? { |klass| klass === value }
  end
  config_attr :scope,         nil, ::String, ::Array, nil
  config_attr :lib_name,      nil, ::String, nil
  config_attr :lib_version,   nil, ::String, nil
  config_attr :timeout,       nil, ::Numeric, nil
  config_attr :metadata,      nil, ::Hash, nil
  config_attr :retry_policy,  nil, ::Hash, ::Proc, nil
  config_attr :quota_project, nil, ::String, nil

  # @private
  # Overrides for http bindings for the RPCs of this service
  # are only used when this service is used as mixin, and only
  # by the host service.
  # @return [::Hash{::Symbol=>::Array<::Gapic::Rest::GrpcTranscoder::HttpBinding>}]
  config_attr :bindings_override, {}, ::Hash, nil

  # @private
  def initialize parent_config = nil
    @parent_config = parent_config unless parent_config.nil?

    yield self if block_given?
  end

  ##
  # Configurations for individual RPCs
  # @return [Rpcs]
  #
  def rpcs
    @rpcs ||= begin
      parent_rpcs = nil
      parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs)
      Rpcs.new parent_rpcs
    end
  end

  ##
  # Configuration RPC class for the WorkflowTemplateService API.
  #
  # Includes fields providing the configuration for each RPC in this service.
  # Each configuration object is of type `Gapic::Config::Method` and includes
  # the following configuration fields:
  #
  #  *  `timeout` (*type:* `Numeric`) - The call timeout in seconds
  #  *  `metadata` (*type:* `Hash{Symbol=>String}`) - Additional headers
  #  *  `retry_policy (*type:* `Hash`) - The retry policy. The policy fields
  #     include the following keys:
  #      *  `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
  #      *  `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
  #      *  `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
  #      *  `:retry_codes` (*type:* `Array<String>`) - The error codes that should
  #         trigger a retry.
  #
  class Rpcs
    ##
    # RPC-specific configuration for `create_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :create_workflow_template
    ##
    # RPC-specific configuration for `get_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :get_workflow_template
    ##
    # RPC-specific configuration for `instantiate_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_workflow_template
    ##
    # RPC-specific configuration for `instantiate_inline_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_inline_workflow_template
    ##
    # RPC-specific configuration for `update_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :update_workflow_template
    ##
    # RPC-specific configuration for `list_workflow_templates`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :list_workflow_templates
    ##
    # RPC-specific configuration for `delete_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :delete_workflow_template

    # @private
    def initialize parent_rpcs = nil
      create_workflow_template_config = parent_rpcs.create_workflow_template if parent_rpcs.respond_to? :create_workflow_template
      @create_workflow_template = ::Gapic::Config::Method.new create_workflow_template_config
      get_workflow_template_config = parent_rpcs.get_workflow_template if parent_rpcs.respond_to? :get_workflow_template
      @get_workflow_template = ::Gapic::Config::Method.new get_workflow_template_config
      instantiate_workflow_template_config = parent_rpcs.instantiate_workflow_template if parent_rpcs.respond_to? :instantiate_workflow_template
      @instantiate_workflow_template = ::Gapic::Config::Method.new instantiate_workflow_template_config
      instantiate_inline_workflow_template_config = parent_rpcs.instantiate_inline_workflow_template if parent_rpcs.respond_to? :instantiate_inline_workflow_template
      @instantiate_inline_workflow_template = ::Gapic::Config::Method.new instantiate_inline_workflow_template_config
      update_workflow_template_config = parent_rpcs.update_workflow_template if parent_rpcs.respond_to? :update_workflow_template
      @update_workflow_template = ::Gapic::Config::Method.new update_workflow_template_config
      list_workflow_templates_config = parent_rpcs.list_workflow_templates if parent_rpcs.respond_to? :list_workflow_templates
      @list_workflow_templates = ::Gapic::Config::Method.new list_workflow_templates_config
      delete_workflow_template_config = parent_rpcs.delete_workflow_template if parent_rpcs.respond_to? :delete_workflow_template
      @delete_workflow_template = ::Gapic::Config::Method.new delete_workflow_template_config

      yield self if block_given?
    end
  end
end

#retry_policy::Hash

The retry policy. The value is a hash with the following keys:

  • :initial_delay (type: Numeric) - The initial delay in seconds.
  • :max_delay (type: Numeric) - The max delay in seconds.
  • :multiplier (type: Numeric) - The incremental backoff multiplier.
  • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Returns:

  • (::Hash)


990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 990

class Configuration
  extend ::Gapic::Config

  DEFAULT_ENDPOINT = "dataproc.googleapis.com"

  config_attr :endpoint,      DEFAULT_ENDPOINT, ::String
  config_attr :credentials,   nil do |value|
    allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil]
    allowed.any? { |klass| klass === value }
  end
  config_attr :scope,         nil, ::String, ::Array, nil
  config_attr :lib_name,      nil, ::String, nil
  config_attr :lib_version,   nil, ::String, nil
  config_attr :timeout,       nil, ::Numeric, nil
  config_attr :metadata,      nil, ::Hash, nil
  config_attr :retry_policy,  nil, ::Hash, ::Proc, nil
  config_attr :quota_project, nil, ::String, nil

  # @private
  # Overrides for http bindings for the RPCs of this service
  # are only used when this service is used as mixin, and only
  # by the host service.
  # @return [::Hash{::Symbol=>::Array<::Gapic::Rest::GrpcTranscoder::HttpBinding>}]
  config_attr :bindings_override, {}, ::Hash, nil

  # @private
  def initialize parent_config = nil
    @parent_config = parent_config unless parent_config.nil?

    yield self if block_given?
  end

  ##
  # Configurations for individual RPCs
  # @return [Rpcs]
  #
  def rpcs
    @rpcs ||= begin
      parent_rpcs = nil
      parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs)
      Rpcs.new parent_rpcs
    end
  end

  ##
  # Configuration RPC class for the WorkflowTemplateService API.
  #
  # Includes fields providing the configuration for each RPC in this service.
  # Each configuration object is of type `Gapic::Config::Method` and includes
  # the following configuration fields:
  #
  #  *  `timeout` (*type:* `Numeric`) - The call timeout in seconds
  #  *  `metadata` (*type:* `Hash{Symbol=>String}`) - Additional headers
  #  *  `retry_policy (*type:* `Hash`) - The retry policy. The policy fields
  #     include the following keys:
  #      *  `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
  #      *  `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
  #      *  `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
  #      *  `:retry_codes` (*type:* `Array<String>`) - The error codes that should
  #         trigger a retry.
  #
  class Rpcs
    ##
    # RPC-specific configuration for `create_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :create_workflow_template
    ##
    # RPC-specific configuration for `get_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :get_workflow_template
    ##
    # RPC-specific configuration for `instantiate_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_workflow_template
    ##
    # RPC-specific configuration for `instantiate_inline_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_inline_workflow_template
    ##
    # RPC-specific configuration for `update_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :update_workflow_template
    ##
    # RPC-specific configuration for `list_workflow_templates`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :list_workflow_templates
    ##
    # RPC-specific configuration for `delete_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :delete_workflow_template

    # @private
    def initialize parent_rpcs = nil
      create_workflow_template_config = parent_rpcs.create_workflow_template if parent_rpcs.respond_to? :create_workflow_template
      @create_workflow_template = ::Gapic::Config::Method.new create_workflow_template_config
      get_workflow_template_config = parent_rpcs.get_workflow_template if parent_rpcs.respond_to? :get_workflow_template
      @get_workflow_template = ::Gapic::Config::Method.new get_workflow_template_config
      instantiate_workflow_template_config = parent_rpcs.instantiate_workflow_template if parent_rpcs.respond_to? :instantiate_workflow_template
      @instantiate_workflow_template = ::Gapic::Config::Method.new instantiate_workflow_template_config
      instantiate_inline_workflow_template_config = parent_rpcs.instantiate_inline_workflow_template if parent_rpcs.respond_to? :instantiate_inline_workflow_template
      @instantiate_inline_workflow_template = ::Gapic::Config::Method.new instantiate_inline_workflow_template_config
      update_workflow_template_config = parent_rpcs.update_workflow_template if parent_rpcs.respond_to? :update_workflow_template
      @update_workflow_template = ::Gapic::Config::Method.new update_workflow_template_config
      list_workflow_templates_config = parent_rpcs.list_workflow_templates if parent_rpcs.respond_to? :list_workflow_templates
      @list_workflow_templates = ::Gapic::Config::Method.new list_workflow_templates_config
      delete_workflow_template_config = parent_rpcs.delete_workflow_template if parent_rpcs.respond_to? :delete_workflow_template
      @delete_workflow_template = ::Gapic::Config::Method.new delete_workflow_template_config

      yield self if block_given?
    end
  end
end

#scope::Array<::String>

The OAuth scopes

Returns:

  • (::Array<::String>)


990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 990

class Configuration
  extend ::Gapic::Config

  DEFAULT_ENDPOINT = "dataproc.googleapis.com"

  config_attr :endpoint,      DEFAULT_ENDPOINT, ::String
  config_attr :credentials,   nil do |value|
    allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil]
    allowed.any? { |klass| klass === value }
  end
  config_attr :scope,         nil, ::String, ::Array, nil
  config_attr :lib_name,      nil, ::String, nil
  config_attr :lib_version,   nil, ::String, nil
  config_attr :timeout,       nil, ::Numeric, nil
  config_attr :metadata,      nil, ::Hash, nil
  config_attr :retry_policy,  nil, ::Hash, ::Proc, nil
  config_attr :quota_project, nil, ::String, nil

  # @private
  # Overrides for http bindings for the RPCs of this service
  # are only used when this service is used as mixin, and only
  # by the host service.
  # @return [::Hash{::Symbol=>::Array<::Gapic::Rest::GrpcTranscoder::HttpBinding>}]
  config_attr :bindings_override, {}, ::Hash, nil

  # @private
  def initialize parent_config = nil
    @parent_config = parent_config unless parent_config.nil?

    yield self if block_given?
  end

  ##
  # Configurations for individual RPCs
  # @return [Rpcs]
  #
  def rpcs
    @rpcs ||= begin
      parent_rpcs = nil
      parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs)
      Rpcs.new parent_rpcs
    end
  end

  ##
  # Configuration RPC class for the WorkflowTemplateService API.
  #
  # Includes fields providing the configuration for each RPC in this service.
  # Each configuration object is of type `Gapic::Config::Method` and includes
  # the following configuration fields:
  #
  #  *  `timeout` (*type:* `Numeric`) - The call timeout in seconds
  #  *  `metadata` (*type:* `Hash{Symbol=>String}`) - Additional headers
  #  *  `retry_policy (*type:* `Hash`) - The retry policy. The policy fields
  #     include the following keys:
  #      *  `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
  #      *  `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
  #      *  `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
  #      *  `:retry_codes` (*type:* `Array<String>`) - The error codes that should
  #         trigger a retry.
  #
  class Rpcs
    ##
    # RPC-specific configuration for `create_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :create_workflow_template
    ##
    # RPC-specific configuration for `get_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :get_workflow_template
    ##
    # RPC-specific configuration for `instantiate_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_workflow_template
    ##
    # RPC-specific configuration for `instantiate_inline_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_inline_workflow_template
    ##
    # RPC-specific configuration for `update_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :update_workflow_template
    ##
    # RPC-specific configuration for `list_workflow_templates`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :list_workflow_templates
    ##
    # RPC-specific configuration for `delete_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :delete_workflow_template

    # @private
    def initialize parent_rpcs = nil
      create_workflow_template_config = parent_rpcs.create_workflow_template if parent_rpcs.respond_to? :create_workflow_template
      @create_workflow_template = ::Gapic::Config::Method.new create_workflow_template_config
      get_workflow_template_config = parent_rpcs.get_workflow_template if parent_rpcs.respond_to? :get_workflow_template
      @get_workflow_template = ::Gapic::Config::Method.new get_workflow_template_config
      instantiate_workflow_template_config = parent_rpcs.instantiate_workflow_template if parent_rpcs.respond_to? :instantiate_workflow_template
      @instantiate_workflow_template = ::Gapic::Config::Method.new instantiate_workflow_template_config
      instantiate_inline_workflow_template_config = parent_rpcs.instantiate_inline_workflow_template if parent_rpcs.respond_to? :instantiate_inline_workflow_template
      @instantiate_inline_workflow_template = ::Gapic::Config::Method.new instantiate_inline_workflow_template_config
      update_workflow_template_config = parent_rpcs.update_workflow_template if parent_rpcs.respond_to? :update_workflow_template
      @update_workflow_template = ::Gapic::Config::Method.new update_workflow_template_config
      list_workflow_templates_config = parent_rpcs.list_workflow_templates if parent_rpcs.respond_to? :list_workflow_templates
      @list_workflow_templates = ::Gapic::Config::Method.new list_workflow_templates_config
      delete_workflow_template_config = parent_rpcs.delete_workflow_template if parent_rpcs.respond_to? :delete_workflow_template
      @delete_workflow_template = ::Gapic::Config::Method.new delete_workflow_template_config

      yield self if block_given?
    end
  end
end

#timeout::Numeric

The call timeout in seconds.

Returns:

  • (::Numeric)


990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 990

class Configuration
  extend ::Gapic::Config

  DEFAULT_ENDPOINT = "dataproc.googleapis.com"

  config_attr :endpoint,      DEFAULT_ENDPOINT, ::String
  config_attr :credentials,   nil do |value|
    allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil]
    allowed.any? { |klass| klass === value }
  end
  config_attr :scope,         nil, ::String, ::Array, nil
  config_attr :lib_name,      nil, ::String, nil
  config_attr :lib_version,   nil, ::String, nil
  config_attr :timeout,       nil, ::Numeric, nil
  config_attr :metadata,      nil, ::Hash, nil
  config_attr :retry_policy,  nil, ::Hash, ::Proc, nil
  config_attr :quota_project, nil, ::String, nil

  # @private
  # Overrides for http bindings for the RPCs of this service
  # are only used when this service is used as mixin, and only
  # by the host service.
  # @return [::Hash{::Symbol=>::Array<::Gapic::Rest::GrpcTranscoder::HttpBinding>}]
  config_attr :bindings_override, {}, ::Hash, nil

  # @private
  def initialize parent_config = nil
    @parent_config = parent_config unless parent_config.nil?

    yield self if block_given?
  end

  ##
  # Configurations for individual RPCs
  # @return [Rpcs]
  #
  def rpcs
    @rpcs ||= begin
      parent_rpcs = nil
      parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs)
      Rpcs.new parent_rpcs
    end
  end

  ##
  # Configuration RPC class for the WorkflowTemplateService API.
  #
  # Includes fields providing the configuration for each RPC in this service.
  # Each configuration object is of type `Gapic::Config::Method` and includes
  # the following configuration fields:
  #
  #  *  `timeout` (*type:* `Numeric`) - The call timeout in seconds
  #  *  `metadata` (*type:* `Hash{Symbol=>String}`) - Additional headers
  #  *  `retry_policy (*type:* `Hash`) - The retry policy. The policy fields
  #     include the following keys:
  #      *  `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
  #      *  `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
  #      *  `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
  #      *  `:retry_codes` (*type:* `Array<String>`) - The error codes that should
  #         trigger a retry.
  #
  class Rpcs
    ##
    # RPC-specific configuration for `create_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :create_workflow_template
    ##
    # RPC-specific configuration for `get_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :get_workflow_template
    ##
    # RPC-specific configuration for `instantiate_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_workflow_template
    ##
    # RPC-specific configuration for `instantiate_inline_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :instantiate_inline_workflow_template
    ##
    # RPC-specific configuration for `update_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :update_workflow_template
    ##
    # RPC-specific configuration for `list_workflow_templates`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :list_workflow_templates
    ##
    # RPC-specific configuration for `delete_workflow_template`
    # @return [::Gapic::Config::Method]
    #
    attr_reader :delete_workflow_template

    # @private
    def initialize parent_rpcs = nil
      create_workflow_template_config = parent_rpcs.create_workflow_template if parent_rpcs.respond_to? :create_workflow_template
      @create_workflow_template = ::Gapic::Config::Method.new create_workflow_template_config
      get_workflow_template_config = parent_rpcs.get_workflow_template if parent_rpcs.respond_to? :get_workflow_template
      @get_workflow_template = ::Gapic::Config::Method.new get_workflow_template_config
      instantiate_workflow_template_config = parent_rpcs.instantiate_workflow_template if parent_rpcs.respond_to? :instantiate_workflow_template
      @instantiate_workflow_template = ::Gapic::Config::Method.new instantiate_workflow_template_config
      instantiate_inline_workflow_template_config = parent_rpcs.instantiate_inline_workflow_template if parent_rpcs.respond_to? :instantiate_inline_workflow_template
      @instantiate_inline_workflow_template = ::Gapic::Config::Method.new instantiate_inline_workflow_template_config
      update_workflow_template_config = parent_rpcs.update_workflow_template if parent_rpcs.respond_to? :update_workflow_template
      @update_workflow_template = ::Gapic::Config::Method.new update_workflow_template_config
      list_workflow_templates_config = parent_rpcs.list_workflow_templates if parent_rpcs.respond_to? :list_workflow_templates
      @list_workflow_templates = ::Gapic::Config::Method.new list_workflow_templates_config
      delete_workflow_template_config = parent_rpcs.delete_workflow_template if parent_rpcs.respond_to? :delete_workflow_template
      @delete_workflow_template = ::Gapic::Config::Method.new delete_workflow_template_config

      yield self if block_given?
    end
  end
end

Instance Method Details

#rpcsRpcs

Configurations for individual RPCs

Returns:



1026
1027
1028
1029
1030
1031
1032
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 1026

def rpcs
  @rpcs ||= begin
    parent_rpcs = nil
    parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs)
    Rpcs.new parent_rpcs
  end
end