Class: Google::Cloud::Dataproc::V1::AttachedDiskConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::AttachedDiskConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataproc/v1/clusters.rb
Overview
Specifies the config of attached disk options for single VM instance.
Defined Under Namespace
Modules: DiskType
Instance Attribute Summary collapse
-
#disk_size_gb ⇒ ::Integer
Optional.
-
#disk_type ⇒ ::Google::Cloud::Dataproc::V1::AttachedDiskConfig::DiskType
Optional.
-
#provisioned_iops ⇒ ::Integer
Optional.
-
#provisioned_throughput ⇒ ::Integer
Optional.
Instance Attribute Details
#disk_size_gb ⇒ ::Integer
Returns Optional. Disk size in GB.
958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 958 class AttachedDiskConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module DiskType # Required unspecified disk type. DISK_TYPE_UNSPECIFIED = 0 # Hyperdisk Balanced disk type. HYPERDISK_BALANCED = 1 # Hyperdisk Extreme disk type. HYPERDISK_EXTREME = 2 # Hyperdisk ML disk type. HYPERDISK_ML = 3 # Hyperdisk Throughput disk type. HYPERDISK_THROUGHPUT = 4 end end |
#disk_type ⇒ ::Google::Cloud::Dataproc::V1::AttachedDiskConfig::DiskType
Returns Optional. Disk type.
958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 958 class AttachedDiskConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module DiskType # Required unspecified disk type. DISK_TYPE_UNSPECIFIED = 0 # Hyperdisk Balanced disk type. HYPERDISK_BALANCED = 1 # Hyperdisk Extreme disk type. HYPERDISK_EXTREME = 2 # Hyperdisk ML disk type. HYPERDISK_ML = 3 # Hyperdisk Throughput disk type. HYPERDISK_THROUGHPUT = 4 end end |
#provisioned_iops ⇒ ::Integer
Returns Optional. Indicates how many IOPS to provision for the attached disk. This sets the number of I/O operations per second that the disk can handle. See https://cloud.google.com/compute/docs/disks/hyperdisks#hyperdisk-features.
958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 958 class AttachedDiskConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module DiskType # Required unspecified disk type. DISK_TYPE_UNSPECIFIED = 0 # Hyperdisk Balanced disk type. HYPERDISK_BALANCED = 1 # Hyperdisk Extreme disk type. HYPERDISK_EXTREME = 2 # Hyperdisk ML disk type. HYPERDISK_ML = 3 # Hyperdisk Throughput disk type. HYPERDISK_THROUGHPUT = 4 end end |
#provisioned_throughput ⇒ ::Integer
Returns Optional. Indicates how much throughput to provision for the attached disk. This sets the number of throughput mb per second that the disk can handle. See https://cloud.google.com/compute/docs/disks/hyperdisks#hyperdisk-features.
958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 958 class AttachedDiskConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module DiskType # Required unspecified disk type. DISK_TYPE_UNSPECIFIED = 0 # Hyperdisk Balanced disk type. HYPERDISK_BALANCED = 1 # Hyperdisk Extreme disk type. HYPERDISK_EXTREME = 2 # Hyperdisk ML disk type. HYPERDISK_ML = 3 # Hyperdisk Throughput disk type. HYPERDISK_THROUGHPUT = 4 end end |