Class: Google::Cloud::Dataproc::V1::AuthenticationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::AuthenticationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataproc/v1/shared.rb
Overview
Authentication configuration for a workload is used to set the default identity for the workload execution. The config specifies the type of identity (service account or user) that will be used by workloads to access resources on the project(s).
Defined Under Namespace
Modules: AuthenticationType
Instance Attribute Summary collapse
Instance Attribute Details
#user_workload_authentication_type ⇒ ::Google::Cloud::Dataproc::V1::AuthenticationConfig::AuthenticationType
Returns Optional. Authentication type for the user workload running in containers.
555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'proto_docs/google/cloud/dataproc/v1/shared.rb', line 555 class AuthenticationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Authentication types for workload execution. module AuthenticationType # If AuthenticationType is unspecified then END_USER_CREDENTIALS is used # for 3.0 and newer runtimes, and SERVICE_ACCOUNT is used for older # runtimes. AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Use service account credentials for authenticating to other services. SERVICE_ACCOUNT = 1 # Use OAuth credentials associated with the workload creator/user for # authenticating to other services. END_USER_CREDENTIALS = 2 end end |