Class: Google::Cloud::Dataproc::V1::ClusterController::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/dataproc/v1/cluster_controller/rest/client.rb

Overview

REST client for the ClusterController service.

The ClusterControllerService provides methods to manage clusters of Compute Engine instances.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#cluster_path, #node_group_path, #service_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new ClusterController REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Dataproc::V1::ClusterController::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Dataproc::V1::ClusterController::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the ClusterController client.

Yield Parameters:



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/client.rb', line 143

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint == Client.configure.endpoint &&
                           !@config.endpoint.split(".").first.include?("-")
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @operations_client = ::Google::Cloud::Dataproc::V1::ClusterController::Rest::Operations.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @config.endpoint
  end

  @iam_policy_client = Google::Iam::V1::IAMPolicy::Rest::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @config.endpoint
    config.bindings_override = @config.bindings_override
  end

  @cluster_controller_stub = ::Google::Cloud::Dataproc::V1::ClusterController::Rest::ServiceStub.new endpoint: @config.endpoint, credentials: credentials
end

Instance Attribute Details

#iam_policy_clientGoogle::Iam::V1::IAMPolicy::Rest::Client (readonly)

Get the associated client for mix-in of the IAMPolicy.

Returns:

  • (Google::Iam::V1::IAMPolicy::Rest::Client)


193
194
195
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/client.rb', line 193

def iam_policy_client
  @iam_policy_client
end

#operations_client::Google::Cloud::Dataproc::V1::ClusterController::Rest::Operations (readonly)

Get the associated client for long-running operations.



186
187
188
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/client.rb', line 186

def operations_client
  @operations_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the ClusterController Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all ClusterController clients
::Google::Cloud::Dataproc::V1::ClusterController::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/client.rb', line 60

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Dataproc", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.create_cluster.timeout = 300.0
    default_config.rpcs.create_cluster.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.update_cluster.timeout = 300.0
    default_config.rpcs.update_cluster.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.delete_cluster.timeout = 300.0
    default_config.rpcs.delete_cluster.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_cluster.timeout = 300.0
    default_config.rpcs.get_cluster.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [13, 4, 14]
    }

    default_config.rpcs.list_clusters.timeout = 300.0
    default_config.rpcs.list_clusters.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [13, 4, 14]
    }

    default_config.rpcs.diagnose_cluster.timeout = 300.0
    default_config.rpcs.diagnose_cluster.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the ClusterController Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



122
123
124
125
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/client.rb', line 122

def configure
  yield @config if block_given?
  @config
end

#create_cluster(request, options = nil) ⇒ ::Gapic::Operation #create_cluster(project_id: nil, region: nil, cluster: nil, request_id: nil, action_on_failed_primary_workers: nil) ⇒ ::Gapic::Operation

Creates a cluster in a project. The returned Operation.metadata will be ClusterOperationMetadata.

Overloads:

  • #create_cluster(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to create_cluster via a request object, either of type Google::Cloud::Dataproc::V1::CreateClusterRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::CreateClusterRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_cluster(project_id: nil, region: nil, cluster: nil, request_id: nil, action_on_failed_primary_workers: nil) ⇒ ::Gapic::Operation

    Pass arguments to create_cluster via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      Required. The ID of the Google Cloud Platform project that the cluster belongs to.

    • region (::String) (defaults to: nil)

      Required. The Dataproc region in which to handle the request.

    • cluster (::Google::Cloud::Dataproc::V1::Cluster, ::Hash) (defaults to: nil)

      Required. The cluster to create.

    • request_id (::String) (defaults to: nil)

      Optional. A unique ID used to identify the request. If the server receives two CreateClusterRequests with the same id, then the second request will be ignored and the first google.longrunning.Operation created and stored in the backend is returned.

      It is recommended to always set this value to a UUID.

      The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters.

    • action_on_failed_primary_workers (::Google::Cloud::Dataproc::V1::FailureAction) (defaults to: nil)

      Optional. Failure action when primary worker creation fails.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/client.rb', line 246

def create_cluster request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::CreateClusterRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_cluster..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_cluster.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_cluster.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cluster_controller_stub.create_cluster request, options do |result, operation|
    result = ::Gapic::Operation.new result, @operations_client, options: options
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_cluster(request, options = nil) ⇒ ::Gapic::Operation #delete_cluster(project_id: nil, region: nil, cluster_name: nil, cluster_uuid: nil, request_id: nil) ⇒ ::Gapic::Operation

Deletes a cluster in a project. The returned Operation.metadata will be ClusterOperationMetadata.

Overloads:

  • #delete_cluster(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to delete_cluster via a request object, either of type DeleteClusterRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::DeleteClusterRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #delete_cluster(project_id: nil, region: nil, cluster_name: nil, cluster_uuid: nil, request_id: nil) ⇒ ::Gapic::Operation

    Pass arguments to delete_cluster via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      Required. The ID of the Google Cloud Platform project that the cluster belongs to.

    • region (::String) (defaults to: nil)

      Required. The Dataproc region in which to handle the request.

    • cluster_name (::String) (defaults to: nil)

      Required. The cluster name.

    • cluster_uuid (::String) (defaults to: nil)

      Optional. Specifying the cluster_uuid means the RPC should fail (with error NOT_FOUND) if cluster with specified UUID does not exist.

    • request_id (::String) (defaults to: nil)

      Optional. A unique ID used to identify the request. If the server receives two DeleteClusterRequests with the same id, then the second request will be ignored and the first google.longrunning.Operation created and stored in the backend is returned.

      It is recommended to always set this value to a UUID.

      The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/client.rb', line 650

def delete_cluster request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::DeleteClusterRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_cluster..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete_cluster.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_cluster.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cluster_controller_stub.delete_cluster request, options do |result, operation|
    result = ::Gapic::Operation.new result, @operations_client, options: options
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#diagnose_cluster(request, options = nil) ⇒ ::Gapic::Operation #diagnose_cluster(project_id: nil, region: nil, cluster_name: nil) ⇒ ::Gapic::Operation

Gets cluster diagnostic information. The returned Operation.metadata will be ClusterOperationMetadata. After the operation completes, Operation.response contains DiagnoseClusterResults.

Overloads:

  • #diagnose_cluster(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to diagnose_cluster via a request object, either of type DiagnoseClusterRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::DiagnoseClusterRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #diagnose_cluster(project_id: nil, region: nil, cluster_name: nil) ⇒ ::Gapic::Operation

    Pass arguments to diagnose_cluster via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      Required. The ID of the Google Cloud Platform project that the cluster belongs to.

    • region (::String) (defaults to: nil)

      Required. The Dataproc region in which to handle the request.

    • cluster_name (::String) (defaults to: nil)

      Required. The cluster name.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/client.rb', line 881

def diagnose_cluster request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::DiagnoseClusterRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.diagnose_cluster..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.diagnose_cluster.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.diagnose_cluster.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cluster_controller_stub.diagnose_cluster request, options do |result, operation|
    result = ::Gapic::Operation.new result, @operations_client, options: options
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_cluster(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::Cluster #get_cluster(project_id: nil, region: nil, cluster_name: nil) ⇒ ::Google::Cloud::Dataproc::V1::Cluster

Gets the resource representation for a cluster in a project.

Overloads:

  • #get_cluster(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::Cluster

    Pass arguments to get_cluster via a request object, either of type GetClusterRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::GetClusterRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_cluster(project_id: nil, region: nil, cluster_name: nil) ⇒ ::Google::Cloud::Dataproc::V1::Cluster

    Pass arguments to get_cluster via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      Required. The ID of the Google Cloud Platform project that the cluster belongs to.

    • region (::String) (defaults to: nil)

      Required. The Dataproc region in which to handle the request.

    • cluster_name (::String) (defaults to: nil)

      Required. The cluster name.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/client.rb', line 718

def get_cluster request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::GetClusterRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_cluster..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_cluster.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_cluster.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cluster_controller_stub.get_cluster request, options do |result, operation|
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_clusters(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dataproc::V1::Cluster> #list_clusters(project_id: nil, region: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dataproc::V1::Cluster>

Lists all regions/{region}/clusters in a project alphabetically.

Overloads:

  • #list_clusters(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dataproc::V1::Cluster>

    Pass arguments to list_clusters via a request object, either of type ListClustersRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::ListClustersRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_clusters(project_id: nil, region: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dataproc::V1::Cluster>

    Pass arguments to list_clusters via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      Required. The ID of the Google Cloud Platform project that the cluster belongs to.

    • region (::String) (defaults to: nil)

      Required. The Dataproc region in which to handle the request.

    • filter (::String) (defaults to: nil)

      Optional. A filter constraining the clusters to list. Filters are case-sensitive and have the following syntax:

      field = value [AND [field = value]] ...

      where field is one of status.state, clusterName, or labels.[KEY], and [KEY] is a label key. value can be * to match all values. status.state can be one of the following: ACTIVE, INACTIVE, CREATING, RUNNING, ERROR, DELETING, or UPDATING. ACTIVE contains the CREATING, UPDATING, and RUNNING states. INACTIVE contains the DELETING and ERROR states. clusterName is the name of the cluster provided at creation time. Only the logical AND operator is supported; space-separated items are treated as having an implicit AND operator.

      Example filter:

      status.state = ACTIVE AND clusterName = mycluster AND labels.env = staging AND labels.starred = *

    • page_size (::Integer) (defaults to: nil)

      Optional. The standard List page size.

    • page_token (::String) (defaults to: nil)

      Optional. The standard List page token.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/client.rb', line 807

def list_clusters request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::ListClustersRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_clusters..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_clusters.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_clusters.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cluster_controller_stub.list_clusters request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @cluster_controller_stub, :list_clusters, "clusters", request, result, options
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#start_cluster(request, options = nil) ⇒ ::Gapic::Operation #start_cluster(project_id: nil, region: nil, cluster_name: nil, cluster_uuid: nil, request_id: nil) ⇒ ::Gapic::Operation

Starts a cluster in a project.

Overloads:

  • #start_cluster(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to start_cluster via a request object, either of type StartClusterRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::StartClusterRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #start_cluster(project_id: nil, region: nil, cluster_name: nil, cluster_uuid: nil, request_id: nil) ⇒ ::Gapic::Operation

    Pass arguments to start_cluster via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      Required. The ID of the Google Cloud Platform project the cluster belongs to.

    • region (::String) (defaults to: nil)

      Required. The Dataproc region in which to handle the request.

    • cluster_name (::String) (defaults to: nil)

      Required. The cluster name.

    • cluster_uuid (::String) (defaults to: nil)

      Optional. Specifying the cluster_uuid means the RPC will fail (with error NOT_FOUND) if a cluster with the specified UUID does not exist.

    • request_id (::String) (defaults to: nil)

      Optional. A unique ID used to identify the request. If the server receives two StartClusterRequests with the same id, then the second request will be ignored and the first google.longrunning.Operation created and stored in the backend is returned.

      Recommendation: Set this value to a UUID.

      The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/client.rb', line 564

def start_cluster request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::StartClusterRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.start_cluster..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.start_cluster.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.start_cluster.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cluster_controller_stub.start_cluster request, options do |result, operation|
    result = ::Gapic::Operation.new result, @operations_client, options: options
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#stop_cluster(request, options = nil) ⇒ ::Gapic::Operation #stop_cluster(project_id: nil, region: nil, cluster_name: nil, cluster_uuid: nil, request_id: nil) ⇒ ::Gapic::Operation

Stops a cluster in a project.

Overloads:

  • #stop_cluster(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to stop_cluster via a request object, either of type StopClusterRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::StopClusterRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #stop_cluster(project_id: nil, region: nil, cluster_name: nil, cluster_uuid: nil, request_id: nil) ⇒ ::Gapic::Operation

    Pass arguments to stop_cluster via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      Required. The ID of the Google Cloud Platform project the cluster belongs to.

    • region (::String) (defaults to: nil)

      Required. The Dataproc region in which to handle the request.

    • cluster_name (::String) (defaults to: nil)

      Required. The cluster name.

    • cluster_uuid (::String) (defaults to: nil)

      Optional. Specifying the cluster_uuid means the RPC will fail (with error NOT_FOUND) if a cluster with the specified UUID does not exist.

    • request_id (::String) (defaults to: nil)

      Optional. A unique ID used to identify the request. If the server receives two StopClusterRequests with the same id, then the second request will be ignored and the first google.longrunning.Operation created and stored in the backend is returned.

      Recommendation: Set this value to a UUID.

      The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/client.rb', line 480

def stop_cluster request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::StopClusterRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.stop_cluster..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.stop_cluster.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.stop_cluster.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cluster_controller_stub.stop_cluster request, options do |result, operation|
    result = ::Gapic::Operation.new result, @operations_client, options: options
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#update_cluster(request, options = nil) ⇒ ::Gapic::Operation #update_cluster(project_id: nil, region: nil, cluster_name: nil, cluster: nil, graceful_decommission_timeout: nil, update_mask: nil, request_id: nil) ⇒ ::Gapic::Operation

Updates a cluster in a project. The returned Operation.metadata will be ClusterOperationMetadata. The cluster must be in a RUNNING state or an error is returned.

Overloads:

  • #update_cluster(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to update_cluster via a request object, either of type UpdateClusterRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataproc::V1::UpdateClusterRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #update_cluster(project_id: nil, region: nil, cluster_name: nil, cluster: nil, graceful_decommission_timeout: nil, update_mask: nil, request_id: nil) ⇒ ::Gapic::Operation

    Pass arguments to update_cluster via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      Required. The ID of the Google Cloud Platform project the cluster belongs to.

    • region (::String) (defaults to: nil)

      Required. The Dataproc region in which to handle the request.

    • cluster_name (::String) (defaults to: nil)

      Required. The cluster name.

    • cluster (::Google::Cloud::Dataproc::V1::Cluster, ::Hash) (defaults to: nil)

      Required. The changes to the cluster.

    • graceful_decommission_timeout (::Google::Protobuf::Duration, ::Hash) (defaults to: nil)

      Optional. Timeout for graceful YARN decommissioning. Graceful decommissioning allows removing nodes from the cluster without interrupting jobs in progress. Timeout specifies how long to wait for jobs in progress to finish before forcefully removing nodes (and potentially interrupting jobs). Default timeout is 0 (for forceful decommission), and the maximum allowed timeout is 1 day. (see JSON representation of Duration).

      Only supported on Dataproc image versions 1.2 and higher.

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Required. Specifies the path, relative to Cluster, of the field to update. For example, to change the number of workers in a cluster to 5, the update_mask parameter would be specified as config.worker_config.num_instances, and the PATCH request body would specify the new value, as follows:

      {
        "config":{
          "workerConfig":{
            "numInstances":"5"
          }
        }
      }
      

      Similarly, to change the number of preemptible workers in a cluster to 5, the update_mask parameter would be config.secondary_worker_config.num_instances, and the PATCH request body would be set as follows:

      {
        "config":{
          "secondaryWorkerConfig":{
            "numInstances":"5"
          }
        }
      }
      

      Note: Currently, only the following fields can be updated:

      Mask Purpose
      labels Update labels
      config.worker_config.num_instances Resize primary worker group
      config.secondary_worker_config.num_instances Resize secondary worker group
      config.autoscaling_config.policy_uriUse, stop using, or change autoscaling policies

    • request_id (::String) (defaults to: nil)

      Optional. A unique ID used to identify the request. If the server receives two UpdateClusterRequests with the same id, then the second request will be ignored and the first google.longrunning.Operation created and stored in the backend is returned.

      It is recommended to always set this value to a UUID.

      The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/google/cloud/dataproc/v1/cluster_controller/rest/client.rb', line 396

def update_cluster request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::UpdateClusterRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_cluster..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataproc::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_cluster.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_cluster.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cluster_controller_stub.update_cluster request, options do |result, operation|
    result = ::Gapic::Operation.new result, @operations_client, options: options
    yield result, operation if block_given?
    return result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end