Class: Google::Cloud::Dataproc::V1::ClusterStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/clusters.rb

Overview

The status of a cluster and its instances.

Defined Under Namespace

Modules: State, Substate

Instance Attribute Summary collapse

Instance Attribute Details

#detail::String (readonly)

Returns Optional. Output only. Details of cluster's state.

Returns:

  • (::String)

    Optional. Output only. Details of cluster's state.



1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1023

class ClusterStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The cluster state.
  module State
    # The cluster state is unknown.
    UNKNOWN = 0

    # The cluster is being created and set up. It is not ready for use.
    CREATING = 1

    # The cluster is currently running and healthy. It is ready for use.
    #
    # **Note:** The cluster state changes from "creating" to "running" status
    # after the master node(s), first two primary worker nodes (and the last
    # primary worker node if primary workers > 2) are running.
    RUNNING = 2

    # The cluster encountered an error. It is not ready for use.
    ERROR = 3

    # The cluster has encountered an error while being updated. Jobs can
    # be submitted to the cluster, but the cluster cannot be updated.
    ERROR_DUE_TO_UPDATE = 9

    # The cluster is being deleted. It cannot be used.
    DELETING = 4

    # The cluster is being updated. It continues to accept and process jobs.
    UPDATING = 5

    # The cluster is being stopped. It cannot be used.
    STOPPING = 6

    # The cluster is currently stopped. It is not ready for use.
    STOPPED = 7

    # The cluster is being started. It is not ready for use.
    STARTING = 8

    # The cluster is being repaired. It is not ready for use.
    REPAIRING = 10
  end

  # The cluster substate.
  module Substate
    # The cluster substate is unknown.
    UNSPECIFIED = 0

    # The cluster is known to be in an unhealthy state
    # (for example, critical daemons are not running or HDFS capacity is
    # exhausted).
    #
    # Applies to RUNNING state.
    UNHEALTHY = 1

    # The agent-reported status is out of date (may occur if
    # Dataproc loses communication with Agent).
    #
    # Applies to RUNNING state.
    STALE_STATUS = 2
  end
end

#state::Google::Cloud::Dataproc::V1::ClusterStatus::State (readonly)

Returns Output only. The cluster's state.

Returns:



1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1023

class ClusterStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The cluster state.
  module State
    # The cluster state is unknown.
    UNKNOWN = 0

    # The cluster is being created and set up. It is not ready for use.
    CREATING = 1

    # The cluster is currently running and healthy. It is ready for use.
    #
    # **Note:** The cluster state changes from "creating" to "running" status
    # after the master node(s), first two primary worker nodes (and the last
    # primary worker node if primary workers > 2) are running.
    RUNNING = 2

    # The cluster encountered an error. It is not ready for use.
    ERROR = 3

    # The cluster has encountered an error while being updated. Jobs can
    # be submitted to the cluster, but the cluster cannot be updated.
    ERROR_DUE_TO_UPDATE = 9

    # The cluster is being deleted. It cannot be used.
    DELETING = 4

    # The cluster is being updated. It continues to accept and process jobs.
    UPDATING = 5

    # The cluster is being stopped. It cannot be used.
    STOPPING = 6

    # The cluster is currently stopped. It is not ready for use.
    STOPPED = 7

    # The cluster is being started. It is not ready for use.
    STARTING = 8

    # The cluster is being repaired. It is not ready for use.
    REPAIRING = 10
  end

  # The cluster substate.
  module Substate
    # The cluster substate is unknown.
    UNSPECIFIED = 0

    # The cluster is known to be in an unhealthy state
    # (for example, critical daemons are not running or HDFS capacity is
    # exhausted).
    #
    # Applies to RUNNING state.
    UNHEALTHY = 1

    # The agent-reported status is out of date (may occur if
    # Dataproc loses communication with Agent).
    #
    # Applies to RUNNING state.
    STALE_STATUS = 2
  end
end

#state_start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Time when this state was entered (see JSON representation of Timestamp).

Returns:



1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1023

class ClusterStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The cluster state.
  module State
    # The cluster state is unknown.
    UNKNOWN = 0

    # The cluster is being created and set up. It is not ready for use.
    CREATING = 1

    # The cluster is currently running and healthy. It is ready for use.
    #
    # **Note:** The cluster state changes from "creating" to "running" status
    # after the master node(s), first two primary worker nodes (and the last
    # primary worker node if primary workers > 2) are running.
    RUNNING = 2

    # The cluster encountered an error. It is not ready for use.
    ERROR = 3

    # The cluster has encountered an error while being updated. Jobs can
    # be submitted to the cluster, but the cluster cannot be updated.
    ERROR_DUE_TO_UPDATE = 9

    # The cluster is being deleted. It cannot be used.
    DELETING = 4

    # The cluster is being updated. It continues to accept and process jobs.
    UPDATING = 5

    # The cluster is being stopped. It cannot be used.
    STOPPING = 6

    # The cluster is currently stopped. It is not ready for use.
    STOPPED = 7

    # The cluster is being started. It is not ready for use.
    STARTING = 8

    # The cluster is being repaired. It is not ready for use.
    REPAIRING = 10
  end

  # The cluster substate.
  module Substate
    # The cluster substate is unknown.
    UNSPECIFIED = 0

    # The cluster is known to be in an unhealthy state
    # (for example, critical daemons are not running or HDFS capacity is
    # exhausted).
    #
    # Applies to RUNNING state.
    UNHEALTHY = 1

    # The agent-reported status is out of date (may occur if
    # Dataproc loses communication with Agent).
    #
    # Applies to RUNNING state.
    STALE_STATUS = 2
  end
end

#substate::Google::Cloud::Dataproc::V1::ClusterStatus::Substate (readonly)

Returns Output only. Additional state information that includes status reported by the agent.

Returns:



1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1023

class ClusterStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The cluster state.
  module State
    # The cluster state is unknown.
    UNKNOWN = 0

    # The cluster is being created and set up. It is not ready for use.
    CREATING = 1

    # The cluster is currently running and healthy. It is ready for use.
    #
    # **Note:** The cluster state changes from "creating" to "running" status
    # after the master node(s), first two primary worker nodes (and the last
    # primary worker node if primary workers > 2) are running.
    RUNNING = 2

    # The cluster encountered an error. It is not ready for use.
    ERROR = 3

    # The cluster has encountered an error while being updated. Jobs can
    # be submitted to the cluster, but the cluster cannot be updated.
    ERROR_DUE_TO_UPDATE = 9

    # The cluster is being deleted. It cannot be used.
    DELETING = 4

    # The cluster is being updated. It continues to accept and process jobs.
    UPDATING = 5

    # The cluster is being stopped. It cannot be used.
    STOPPING = 6

    # The cluster is currently stopped. It is not ready for use.
    STOPPED = 7

    # The cluster is being started. It is not ready for use.
    STARTING = 8

    # The cluster is being repaired. It is not ready for use.
    REPAIRING = 10
  end

  # The cluster substate.
  module Substate
    # The cluster substate is unknown.
    UNSPECIFIED = 0

    # The cluster is known to be in an unhealthy state
    # (for example, critical daemons are not running or HDFS capacity is
    # exhausted).
    #
    # Applies to RUNNING state.
    UNHEALTHY = 1

    # The agent-reported status is out of date (may occur if
    # Dataproc loses communication with Agent).
    #
    # Applies to RUNNING state.
    STALE_STATUS = 2
  end
end