Class: Google::Cloud::Dataproc::V1::ClusterStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::ClusterStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataproc/v1/clusters.rb
Overview
The status of a cluster and its instances.
Defined Under Namespace
Instance Attribute Summary collapse
-
#detail ⇒ ::String
readonly
Optional.
-
#state ⇒ ::Google::Cloud::Dataproc::V1::ClusterStatus::State
readonly
Output only.
-
#state_start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#substate ⇒ ::Google::Cloud::Dataproc::V1::ClusterStatus::Substate
readonly
Output only.
Instance Attribute Details
#detail ⇒ ::String (readonly)
Returns Optional. Output only. Details of cluster's state.
658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 658 class ClusterStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The cluster state. module State # The cluster state is unknown. UNKNOWN = 0 # The cluster is being created and set up. It is not ready for use. CREATING = 1 # The cluster is currently running and healthy. It is ready for use. # # **Note:** The cluster state changes from "creating" to "running" status # after the master node(s), first two primary worker nodes (and the last # primary worker node if primary workers > 2) are running. RUNNING = 2 # The cluster encountered an error. It is not ready for use. ERROR = 3 # The cluster has encountered an error while being updated. Jobs can # be submitted to the cluster, but the cluster cannot be updated. ERROR_DUE_TO_UPDATE = 9 # The cluster is being deleted. It cannot be used. DELETING = 4 # The cluster is being updated. It continues to accept and process jobs. UPDATING = 5 # The cluster is being stopped. It cannot be used. STOPPING = 6 # The cluster is currently stopped. It is not ready for use. STOPPED = 7 # The cluster is being started. It is not ready for use. STARTING = 8 end # The cluster substate. module Substate # The cluster substate is unknown. UNSPECIFIED = 0 # The cluster is known to be in an unhealthy state # (for example, critical daemons are not running or HDFS capacity is # exhausted). # # Applies to RUNNING state. UNHEALTHY = 1 # The agent-reported status is out of date (may occur if # Dataproc loses communication with Agent). # # Applies to RUNNING state. STALE_STATUS = 2 end end |
#state ⇒ ::Google::Cloud::Dataproc::V1::ClusterStatus::State (readonly)
Returns Output only. The cluster's state.
658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 658 class ClusterStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The cluster state. module State # The cluster state is unknown. UNKNOWN = 0 # The cluster is being created and set up. It is not ready for use. CREATING = 1 # The cluster is currently running and healthy. It is ready for use. # # **Note:** The cluster state changes from "creating" to "running" status # after the master node(s), first two primary worker nodes (and the last # primary worker node if primary workers > 2) are running. RUNNING = 2 # The cluster encountered an error. It is not ready for use. ERROR = 3 # The cluster has encountered an error while being updated. Jobs can # be submitted to the cluster, but the cluster cannot be updated. ERROR_DUE_TO_UPDATE = 9 # The cluster is being deleted. It cannot be used. DELETING = 4 # The cluster is being updated. It continues to accept and process jobs. UPDATING = 5 # The cluster is being stopped. It cannot be used. STOPPING = 6 # The cluster is currently stopped. It is not ready for use. STOPPED = 7 # The cluster is being started. It is not ready for use. STARTING = 8 end # The cluster substate. module Substate # The cluster substate is unknown. UNSPECIFIED = 0 # The cluster is known to be in an unhealthy state # (for example, critical daemons are not running or HDFS capacity is # exhausted). # # Applies to RUNNING state. UNHEALTHY = 1 # The agent-reported status is out of date (may occur if # Dataproc loses communication with Agent). # # Applies to RUNNING state. STALE_STATUS = 2 end end |
#state_start_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Time when this state was entered (see JSON representation of Timestamp).
658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 658 class ClusterStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The cluster state. module State # The cluster state is unknown. UNKNOWN = 0 # The cluster is being created and set up. It is not ready for use. CREATING = 1 # The cluster is currently running and healthy. It is ready for use. # # **Note:** The cluster state changes from "creating" to "running" status # after the master node(s), first two primary worker nodes (and the last # primary worker node if primary workers > 2) are running. RUNNING = 2 # The cluster encountered an error. It is not ready for use. ERROR = 3 # The cluster has encountered an error while being updated. Jobs can # be submitted to the cluster, but the cluster cannot be updated. ERROR_DUE_TO_UPDATE = 9 # The cluster is being deleted. It cannot be used. DELETING = 4 # The cluster is being updated. It continues to accept and process jobs. UPDATING = 5 # The cluster is being stopped. It cannot be used. STOPPING = 6 # The cluster is currently stopped. It is not ready for use. STOPPED = 7 # The cluster is being started. It is not ready for use. STARTING = 8 end # The cluster substate. module Substate # The cluster substate is unknown. UNSPECIFIED = 0 # The cluster is known to be in an unhealthy state # (for example, critical daemons are not running or HDFS capacity is # exhausted). # # Applies to RUNNING state. UNHEALTHY = 1 # The agent-reported status is out of date (may occur if # Dataproc loses communication with Agent). # # Applies to RUNNING state. STALE_STATUS = 2 end end |
#substate ⇒ ::Google::Cloud::Dataproc::V1::ClusterStatus::Substate (readonly)
Returns Output only. Additional state information that includes status reported by the agent.
658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 658 class ClusterStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The cluster state. module State # The cluster state is unknown. UNKNOWN = 0 # The cluster is being created and set up. It is not ready for use. CREATING = 1 # The cluster is currently running and healthy. It is ready for use. # # **Note:** The cluster state changes from "creating" to "running" status # after the master node(s), first two primary worker nodes (and the last # primary worker node if primary workers > 2) are running. RUNNING = 2 # The cluster encountered an error. It is not ready for use. ERROR = 3 # The cluster has encountered an error while being updated. Jobs can # be submitted to the cluster, but the cluster cannot be updated. ERROR_DUE_TO_UPDATE = 9 # The cluster is being deleted. It cannot be used. DELETING = 4 # The cluster is being updated. It continues to accept and process jobs. UPDATING = 5 # The cluster is being stopped. It cannot be used. STOPPING = 6 # The cluster is currently stopped. It is not ready for use. STOPPED = 7 # The cluster is being started. It is not ready for use. STARTING = 8 end # The cluster substate. module Substate # The cluster substate is unknown. UNSPECIFIED = 0 # The cluster is known to be in an unhealthy state # (for example, critical daemons are not running or HDFS capacity is # exhausted). # # Applies to RUNNING state. UNHEALTHY = 1 # The agent-reported status is out of date (may occur if # Dataproc loses communication with Agent). # # Applies to RUNNING state. STALE_STATUS = 2 end end |