Class: Google::Cloud::Dataproc::V1::DataprocMetricConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::DataprocMetricConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataproc/v1/clusters.rb
Overview
Dataproc metric config.
Defined Under Namespace
Modules: MetricSource Classes: Metric
Instance Attribute Summary collapse
Instance Attribute Details
#metrics ⇒ ::Array<::Google::Cloud::Dataproc::V1::DataprocMetricConfig::Metric>
Returns Required. Metrics sources to enable.
1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1308 class DataprocMetricConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A Dataproc custom metric. # @!attribute [rw] metric_source # @return [::Google::Cloud::Dataproc::V1::DataprocMetricConfig::MetricSource] # Required. A standard set of metrics is collected unless `metricOverrides` # are specified for the metric source (see [Custom metrics] # (https://cloud.google.com/dataproc/docs/guides/dataproc-metrics#custom_metrics) # for more information). # @!attribute [rw] metric_overrides # @return [::Array<::String>] # Optional. Specify one or more [Custom metrics] # (https://cloud.google.com/dataproc/docs/guides/dataproc-metrics#custom_metrics) # to collect for the metric course (for the `SPARK` metric source (any # [Spark metric] # (https://spark.apache.org/docs/latest/monitoring.html#metrics) can be # specified). # # Provide metrics in the following format: # <code><var>METRIC_SOURCE</var>:<var>INSTANCE</var>:<var>GROUP</var>:<var>METRIC</var></code> # Use camelcase as appropriate. # # Examples: # # ``` # yarn:ResourceManager:QueueMetrics:AppsCompleted # spark:driver:DAGScheduler:job.allJobs # sparkHistoryServer:JVM:Memory:NonHeapMemoryUsage.committed # hiveserver2:JVM:Memory:NonHeapMemoryUsage.used # ``` # # Notes: # # * Only the specified overridden metrics are collected for the # metric source. For example, if one or more `spark:executive` metrics # are listed as metric overrides, other `SPARK` metrics are not # collected. The collection of the metrics for other enabled custom # metric sources is unaffected. For example, if both `SPARK` andd `YARN` # metric sources are enabled, and overrides are provided for Spark # metrics only, all YARN metrics are collected. class Metric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A source for the collection of Dataproc custom metrics (see [Custom # metrics] # (https://cloud.google.com//dataproc/docs/guides/dataproc-metrics#custom_metrics)). module MetricSource # Required unspecified metric source. METRIC_SOURCE_UNSPECIFIED = 0 # Monitoring agent metrics. If this source is enabled, # Dataproc enables the monitoring agent in Compute Engine, # and collects monitoring agent metrics, which are published # with an `agent.googleapis.com` prefix. MONITORING_AGENT_DEFAULTS = 1 # HDFS metric source. HDFS = 2 # Spark metric source. SPARK = 3 # YARN metric source. YARN = 4 # Spark History Server metric source. SPARK_HISTORY_SERVER = 5 # Hiveserver2 metric source. HIVESERVER2 = 6 # hivemetastore metric source HIVEMETASTORE = 7 # flink metric source FLINK = 8 end end |