Class: Google::Cloud::Dataproc::V1::DataprocMetricConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/clusters.rb

Overview

Dataproc metric config.

Defined Under Namespace

Modules: MetricSource Classes: Metric

Instance Attribute Summary collapse

Instance Attribute Details

#metrics::Array<::Google::Cloud::Dataproc::V1::DataprocMetricConfig::Metric>

Returns Required. Metrics sources to enable.

Returns:



921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 921

class DataprocMetricConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Dataproc OSS metric.
  # @!attribute [rw] metric_source
  #   @return [::Google::Cloud::Dataproc::V1::DataprocMetricConfig::MetricSource]
  #     Required. Default metrics are collected unless `metricOverrides` are
  #     specified for the metric source (see [Available OSS metrics]
  #     (https://cloud.google.com/dataproc/docs/guides/monitoring#available_oss_metrics)
  #     for more information).
  # @!attribute [rw] metric_overrides
  #   @return [::Array<::String>]
  #     Optional. Specify one or more [available OSS metrics]
  #     (https://cloud.google.com/dataproc/docs/guides/monitoring#available_oss_metrics)
  #     to collect for the metric course (for the `SPARK` metric source, any
  #     [Spark metric]
  #     (https://spark.apache.org/docs/latest/monitoring.html#metrics) can be
  #     specified).
  #
  #     Provide metrics in the following format:
  #     <code><var>METRIC_SOURCE</var>:<var>INSTANCE</var>:<var>GROUP</var>:<var>METRIC</var></code>
  #     Use camelcase as appropriate.
  #
  #     Examples:
  #
  #     ```
  #     yarn:ResourceManager:QueueMetrics:AppsCompleted
  #     spark:driver:DAGScheduler:job.allJobs
  #     sparkHistoryServer:JVM:Memory:NonHeapMemoryUsage.committed
  #     hiveserver2:JVM:Memory:NonHeapMemoryUsage.used
  #     ```
  #
  #     Notes:
  #
  #     * Only the specified overridden metrics will be collected for the
  #       metric source. For example, if one or more `spark:executive` metrics
  #       are listed as metric overrides, other `SPARK` metrics will not be
  #       collected. The collection of the default metrics for other OSS metric
  #       sources is unaffected. For example, if both `SPARK` andd `YARN` metric
  #       sources are enabled, and overrides are provided for Spark metrics only,
  #       all default YARN metrics will be collected.
  class Metric
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A source for the collection of Dataproc OSS metrics (see [available OSS
  # metrics]
  # (https://cloud.google.com//dataproc/docs/guides/monitoring#available_oss_metrics)).
  module MetricSource
    # Required unspecified metric source.
    METRIC_SOURCE_UNSPECIFIED = 0

    # Default monitoring agent metrics. If this source is enabled,
    # Dataproc enables the monitoring agent in Compute Engine,
    # and collects default monitoring agent metrics, which are published
    # with an `agent.googleapis.com` prefix.
    MONITORING_AGENT_DEFAULTS = 1

    # HDFS metric source.
    HDFS = 2

    # Spark metric source.
    SPARK = 3

    # YARN metric source.
    YARN = 4

    # Spark History Server metric source.
    SPARK_HISTORY_SERVER = 5

    # Hiveserver2 metric source.
    HIVESERVER2 = 6
  end
end