Class: Google::Cloud::Dataproc::V1::DiagnoseClusterRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::DiagnoseClusterRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataproc/v1/clusters.rb
Overview
A request to collect cluster diagnostic information.
Defined Under Namespace
Modules: TarballAccess
Instance Attribute Summary collapse
-
#cluster_name ⇒ ::String
Required.
-
#diagnosis_interval ⇒ ::Google::Type::Interval
Optional.
-
#jobs ⇒ ::Array<::String>
Optional.
-
#project_id ⇒ ::String
Required.
-
#region ⇒ ::String
Required.
-
#tarball_access ⇒ ::Google::Cloud::Dataproc::V1::DiagnoseClusterRequest::TarballAccess
Optional.
-
#tarball_gcs_dir ⇒ ::String
Optional.
-
#yarn_application_ids ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#cluster_name ⇒ ::String
Returns Required. The cluster name.
1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1725 class DiagnoseClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines who has access to the diagnostic tarball module TarballAccess # Tarball Access unspecified. Falls back to default access of the bucket TARBALL_ACCESS_UNSPECIFIED = 0 # Google Cloud Support group has read access to the # diagnostic tarball GOOGLE_CLOUD_SUPPORT = 1 # Google Cloud Dataproc Diagnose service account has read access to the # diagnostic tarball GOOGLE_DATAPROC_DIAGNOSE = 2 end end |
#diagnosis_interval ⇒ ::Google::Type::Interval
Returns Optional. Time interval in which diagnosis should be carried out on the cluster.
1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1725 class DiagnoseClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines who has access to the diagnostic tarball module TarballAccess # Tarball Access unspecified. Falls back to default access of the bucket TARBALL_ACCESS_UNSPECIFIED = 0 # Google Cloud Support group has read access to the # diagnostic tarball GOOGLE_CLOUD_SUPPORT = 1 # Google Cloud Dataproc Diagnose service account has read access to the # diagnostic tarball GOOGLE_DATAPROC_DIAGNOSE = 2 end end |
#jobs ⇒ ::Array<::String>
Returns Optional. Specifies a list of jobs on which diagnosis is to be performed. Format: projects/{project}/regions/{region}/jobs/{job}.
1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1725 class DiagnoseClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines who has access to the diagnostic tarball module TarballAccess # Tarball Access unspecified. Falls back to default access of the bucket TARBALL_ACCESS_UNSPECIFIED = 0 # Google Cloud Support group has read access to the # diagnostic tarball GOOGLE_CLOUD_SUPPORT = 1 # Google Cloud Dataproc Diagnose service account has read access to the # diagnostic tarball GOOGLE_DATAPROC_DIAGNOSE = 2 end end |
#project_id ⇒ ::String
Returns Required. The ID of the Google Cloud Platform project that the cluster belongs to.
1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1725 class DiagnoseClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines who has access to the diagnostic tarball module TarballAccess # Tarball Access unspecified. Falls back to default access of the bucket TARBALL_ACCESS_UNSPECIFIED = 0 # Google Cloud Support group has read access to the # diagnostic tarball GOOGLE_CLOUD_SUPPORT = 1 # Google Cloud Dataproc Diagnose service account has read access to the # diagnostic tarball GOOGLE_DATAPROC_DIAGNOSE = 2 end end |
#region ⇒ ::String
Returns Required. The Dataproc region in which to handle the request.
1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1725 class DiagnoseClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines who has access to the diagnostic tarball module TarballAccess # Tarball Access unspecified. Falls back to default access of the bucket TARBALL_ACCESS_UNSPECIFIED = 0 # Google Cloud Support group has read access to the # diagnostic tarball GOOGLE_CLOUD_SUPPORT = 1 # Google Cloud Dataproc Diagnose service account has read access to the # diagnostic tarball GOOGLE_DATAPROC_DIAGNOSE = 2 end end |
#tarball_access ⇒ ::Google::Cloud::Dataproc::V1::DiagnoseClusterRequest::TarballAccess
Returns Optional. (Optional) The access type to the diagnostic tarball. If not specified, falls back to default access of the bucket.
1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1725 class DiagnoseClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines who has access to the diagnostic tarball module TarballAccess # Tarball Access unspecified. Falls back to default access of the bucket TARBALL_ACCESS_UNSPECIFIED = 0 # Google Cloud Support group has read access to the # diagnostic tarball GOOGLE_CLOUD_SUPPORT = 1 # Google Cloud Dataproc Diagnose service account has read access to the # diagnostic tarball GOOGLE_DATAPROC_DIAGNOSE = 2 end end |
#tarball_gcs_dir ⇒ ::String
Returns Optional. (Optional) The output Cloud Storage directory for the diagnostic tarball. If not specified, a task-specific directory in the cluster's staging bucket will be used.
1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1725 class DiagnoseClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines who has access to the diagnostic tarball module TarballAccess # Tarball Access unspecified. Falls back to default access of the bucket TARBALL_ACCESS_UNSPECIFIED = 0 # Google Cloud Support group has read access to the # diagnostic tarball GOOGLE_CLOUD_SUPPORT = 1 # Google Cloud Dataproc Diagnose service account has read access to the # diagnostic tarball GOOGLE_DATAPROC_DIAGNOSE = 2 end end |
#yarn_application_ids ⇒ ::Array<::String>
Returns Optional. Specifies a list of yarn applications on which diagnosis is to be performed.
1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 1725 class DiagnoseClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines who has access to the diagnostic tarball module TarballAccess # Tarball Access unspecified. Falls back to default access of the bucket TARBALL_ACCESS_UNSPECIFIED = 0 # Google Cloud Support group has read access to the # diagnostic tarball GOOGLE_CLOUD_SUPPORT = 1 # Google Cloud Dataproc Diagnose service account has read access to the # diagnostic tarball GOOGLE_DATAPROC_DIAGNOSE = 2 end end |