Class: Google::Cloud::Dataproc::V1::DiskConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/clusters.rb

Overview

Specifies the config of disk options for a group of VM instances.

Instance Attribute Summary collapse

Instance Attribute Details

#boot_disk_provisioned_iops::Integer

Returns Optional. Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Note: This field is only supported if boot_disk_type is hyperdisk-balanced.

Returns:

  • (::Integer)

    Optional. Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Note: This field is only supported if boot_disk_type is hyperdisk-balanced.



922
923
924
925
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 922

class DiskConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#boot_disk_provisioned_throughput::Integer

Returns Optional. Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must be greater than or equal to 1. Note: This field is only supported if boot_disk_type is hyperdisk-balanced.

Returns:

  • (::Integer)

    Optional. Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must be greater than or equal to 1. Note: This field is only supported if boot_disk_type is hyperdisk-balanced.



922
923
924
925
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 922

class DiskConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#boot_disk_size_gb::Integer

Returns Optional. Size in GB of the boot disk (default is 500GB).

Returns:

  • (::Integer)

    Optional. Size in GB of the boot disk (default is 500GB).



922
923
924
925
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 922

class DiskConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#boot_disk_type::String

Returns Optional. Type of the boot disk (default is "pd-standard"). Valid values: "pd-balanced" (Persistent Disk Balanced Solid State Drive), "pd-ssd" (Persistent Disk Solid State Drive), or "pd-standard" (Persistent Disk Hard Disk Drive). See Disk types.

Returns:

  • (::String)

    Optional. Type of the boot disk (default is "pd-standard"). Valid values: "pd-balanced" (Persistent Disk Balanced Solid State Drive), "pd-ssd" (Persistent Disk Solid State Drive), or "pd-standard" (Persistent Disk Hard Disk Drive). See Disk types.



922
923
924
925
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 922

class DiskConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#local_ssd_interface::String

Returns Optional. Interface type of local SSDs (default is "scsi"). Valid values: "scsi" (Small Computer System Interface), "nvme" (Non-Volatile Memory Express). See local SSD performance.

Returns:

  • (::String)

    Optional. Interface type of local SSDs (default is "scsi"). Valid values: "scsi" (Small Computer System Interface), "nvme" (Non-Volatile Memory Express). See local SSD performance.



922
923
924
925
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 922

class DiskConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#num_local_ssds::Integer

Returns Optional. Number of attached SSDs, from 0 to 8 (default is 0). If SSDs are not attached, the boot disk is used to store runtime logs and HDFS data. If one or more SSDs are attached, this runtime bulk data is spread across them, and the boot disk contains only basic config and installed binaries.

Note: Local SSD options may vary by machine type and number of vCPUs selected.

Returns:

  • (::Integer)

    Optional. Number of attached SSDs, from 0 to 8 (default is 0). If SSDs are not attached, the boot disk is used to store runtime logs and HDFS data. If one or more SSDs are attached, this runtime bulk data is spread across them, and the boot disk contains only basic config and installed binaries.

    Note: Local SSD options may vary by machine type and number of vCPUs selected.



922
923
924
925
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 922

class DiskConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end