Class: Google::Cloud::Dataproc::V1::InstanceFlexibilityPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataproc/v1/clusters.rb

Overview

Instance flexibility Policy allowing a mixture of VM shapes and provisioning models.

Defined Under Namespace

Classes: InstanceSelection, InstanceSelectionResult

Instance Attribute Summary collapse

Instance Attribute Details

#instance_selection_list::Array<::Google::Cloud::Dataproc::V1::InstanceFlexibilityPolicy::InstanceSelection>

Returns Optional. List of instance selection options that the group will use when creating new VMs.

Returns:



642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 642

class InstanceFlexibilityPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines machines types and a rank to which the machines types belong.
  # @!attribute [rw] machine_types
  #   @return [::Array<::String>]
  #     Optional. Full machine-type names, e.g. "n1-standard-16".
  # @!attribute [rw] rank
  #   @return [::Integer]
  #     Optional. Preference of this instance selection. Lower number means
  #     higher preference. Dataproc will first try to create a VM based on the
  #     machine-type with priority rank and fallback to next rank based on
  #     availability. Machine types and instance selections with the same
  #     priority have the same preference.
  class InstanceSelection
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines a mapping from machine types to the number of VMs that are created
  # with each machine type.
  # @!attribute [r] machine_type
  #   @return [::String]
  #     Output only. Full machine-type names, e.g. "n1-standard-16".
  # @!attribute [r] vm_count
  #   @return [::Integer]
  #     Output only. Number of VM provisioned with the machine_type.
  class InstanceSelectionResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#instance_selection_results::Array<::Google::Cloud::Dataproc::V1::InstanceFlexibilityPolicy::InstanceSelectionResult> (readonly)

Returns Output only. A list of instance selection results in the group.

Returns:



642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 642

class InstanceFlexibilityPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines machines types and a rank to which the machines types belong.
  # @!attribute [rw] machine_types
  #   @return [::Array<::String>]
  #     Optional. Full machine-type names, e.g. "n1-standard-16".
  # @!attribute [rw] rank
  #   @return [::Integer]
  #     Optional. Preference of this instance selection. Lower number means
  #     higher preference. Dataproc will first try to create a VM based on the
  #     machine-type with priority rank and fallback to next rank based on
  #     availability. Machine types and instance selections with the same
  #     priority have the same preference.
  class InstanceSelection
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines a mapping from machine types to the number of VMs that are created
  # with each machine type.
  # @!attribute [r] machine_type
  #   @return [::String]
  #     Output only. Full machine-type names, e.g. "n1-standard-16".
  # @!attribute [r] vm_count
  #   @return [::Integer]
  #     Output only. Number of VM provisioned with the machine_type.
  class InstanceSelectionResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end