Class: Google::Cloud::Dataproc::V1::InstanceGroupConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::InstanceGroupConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataproc/v1/clusters.rb
Overview
The config settings for Compute Engine resources in an instance group, such as a master or worker group.
Defined Under Namespace
Modules: Preemptibility
Instance Attribute Summary collapse
-
#accelerators ⇒ ::Array<::Google::Cloud::Dataproc::V1::AcceleratorConfig>
Optional.
-
#disk_config ⇒ ::Google::Cloud::Dataproc::V1::DiskConfig
Optional.
-
#image_uri ⇒ ::String
Optional.
-
#instance_names ⇒ ::Array<::String>
readonly
Output only.
-
#is_preemptible ⇒ ::Boolean
readonly
Output only.
-
#machine_type_uri ⇒ ::String
Optional.
-
#managed_group_config ⇒ ::Google::Cloud::Dataproc::V1::ManagedGroupConfig
readonly
Output only.
-
#min_cpu_platform ⇒ ::String
Optional.
-
#num_instances ⇒ ::Integer
Optional.
-
#preemptibility ⇒ ::Google::Cloud::Dataproc::V1::InstanceGroupConfig::Preemptibility
Optional.
Instance Attribute Details
#accelerators ⇒ ::Array<::Google::Cloud::Dataproc::V1::AcceleratorConfig>
Returns Optional. The Compute Engine accelerator configuration for these instances.
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 505 class InstanceGroupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls the use of # [preemptible instances] # (https://cloud.google.com/compute/docs/instances/preemptible) # within the group. module Preemptibility # Preemptibility is unspecified, the system will choose the # appropriate setting for each instance group. PREEMPTIBILITY_UNSPECIFIED = 0 # Instances are non-preemptible. # # This option is allowed for all instance groups and is the only valid # value for Master and Worker instance groups. NON_PREEMPTIBLE = 1 # Instances are preemptible. # # This option is allowed only for secondary worker groups. PREEMPTIBLE = 2 end end |
#disk_config ⇒ ::Google::Cloud::Dataproc::V1::DiskConfig
Returns Optional. Disk option config settings.
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 505 class InstanceGroupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls the use of # [preemptible instances] # (https://cloud.google.com/compute/docs/instances/preemptible) # within the group. module Preemptibility # Preemptibility is unspecified, the system will choose the # appropriate setting for each instance group. PREEMPTIBILITY_UNSPECIFIED = 0 # Instances are non-preemptible. # # This option is allowed for all instance groups and is the only valid # value for Master and Worker instance groups. NON_PREEMPTIBLE = 1 # Instances are preemptible. # # This option is allowed only for secondary worker groups. PREEMPTIBLE = 2 end end |
#image_uri ⇒ ::String
Returns Optional. The Compute Engine image resource used for cluster instances.
The URI can represent an image or image family.
Image examples:
https://www.googleapis.com/compute/beta/projects/[project_id]/global/images/[image-id]projects/[project_id]/global/images/[image-id]image-id
Image family examples. Dataproc will use the most recent image from the family:
https://www.googleapis.com/compute/beta/projects/[project_id]/global/images/family/[custom-image-family-name]projects/[project_id]/global/images/family/[custom-image-family-name]
If the URI is unspecified, it will be inferred from
SoftwareConfig.image_version or the system default.
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 505 class InstanceGroupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls the use of # [preemptible instances] # (https://cloud.google.com/compute/docs/instances/preemptible) # within the group. module Preemptibility # Preemptibility is unspecified, the system will choose the # appropriate setting for each instance group. PREEMPTIBILITY_UNSPECIFIED = 0 # Instances are non-preemptible. # # This option is allowed for all instance groups and is the only valid # value for Master and Worker instance groups. NON_PREEMPTIBLE = 1 # Instances are preemptible. # # This option is allowed only for secondary worker groups. PREEMPTIBLE = 2 end end |
#instance_names ⇒ ::Array<::String> (readonly)
Returns Output only. The list of instance names. Dataproc derives the names
from cluster_name, num_instances, and the instance group.
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 505 class InstanceGroupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls the use of # [preemptible instances] # (https://cloud.google.com/compute/docs/instances/preemptible) # within the group. module Preemptibility # Preemptibility is unspecified, the system will choose the # appropriate setting for each instance group. PREEMPTIBILITY_UNSPECIFIED = 0 # Instances are non-preemptible. # # This option is allowed for all instance groups and is the only valid # value for Master and Worker instance groups. NON_PREEMPTIBLE = 1 # Instances are preemptible. # # This option is allowed only for secondary worker groups. PREEMPTIBLE = 2 end end |
#is_preemptible ⇒ ::Boolean (readonly)
Returns Output only. Specifies that this instance group contains preemptible instances.
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 505 class InstanceGroupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls the use of # [preemptible instances] # (https://cloud.google.com/compute/docs/instances/preemptible) # within the group. module Preemptibility # Preemptibility is unspecified, the system will choose the # appropriate setting for each instance group. PREEMPTIBILITY_UNSPECIFIED = 0 # Instances are non-preemptible. # # This option is allowed for all instance groups and is the only valid # value for Master and Worker instance groups. NON_PREEMPTIBLE = 1 # Instances are preemptible. # # This option is allowed only for secondary worker groups. PREEMPTIBLE = 2 end end |
#machine_type_uri ⇒ ::String
Returns Optional. The Compute Engine machine type used for cluster instances.
A full URL, partial URI, or short name are valid. Examples:
https://www.googleapis.com/compute/v1/projects/[project_id]/zones/us-east1-a/machineTypes/n1-standard-2projects/[project_id]/zones/us-east1-a/machineTypes/n1-standard-2n1-standard-2
Auto Zone Exception: If you are using the Dataproc
Auto Zone
Placement
feature, you must use the short name of the machine type
resource, for example, n1-standard-2.
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 505 class InstanceGroupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls the use of # [preemptible instances] # (https://cloud.google.com/compute/docs/instances/preemptible) # within the group. module Preemptibility # Preemptibility is unspecified, the system will choose the # appropriate setting for each instance group. PREEMPTIBILITY_UNSPECIFIED = 0 # Instances are non-preemptible. # # This option is allowed for all instance groups and is the only valid # value for Master and Worker instance groups. NON_PREEMPTIBLE = 1 # Instances are preemptible. # # This option is allowed only for secondary worker groups. PREEMPTIBLE = 2 end end |
#managed_group_config ⇒ ::Google::Cloud::Dataproc::V1::ManagedGroupConfig (readonly)
Returns Output only. The config for Compute Engine Instance Group Manager that manages this group. This is only used for preemptible instance groups.
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 505 class InstanceGroupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls the use of # [preemptible instances] # (https://cloud.google.com/compute/docs/instances/preemptible) # within the group. module Preemptibility # Preemptibility is unspecified, the system will choose the # appropriate setting for each instance group. PREEMPTIBILITY_UNSPECIFIED = 0 # Instances are non-preemptible. # # This option is allowed for all instance groups and is the only valid # value for Master and Worker instance groups. NON_PREEMPTIBLE = 1 # Instances are preemptible. # # This option is allowed only for secondary worker groups. PREEMPTIBLE = 2 end end |
#min_cpu_platform ⇒ ::String
Returns Optional. Specifies the minimum cpu platform for the Instance Group. See Dataproc -> Minimum CPU Platform.
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 505 class InstanceGroupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls the use of # [preemptible instances] # (https://cloud.google.com/compute/docs/instances/preemptible) # within the group. module Preemptibility # Preemptibility is unspecified, the system will choose the # appropriate setting for each instance group. PREEMPTIBILITY_UNSPECIFIED = 0 # Instances are non-preemptible. # # This option is allowed for all instance groups and is the only valid # value for Master and Worker instance groups. NON_PREEMPTIBLE = 1 # Instances are preemptible. # # This option is allowed only for secondary worker groups. PREEMPTIBLE = 2 end end |
#num_instances ⇒ ::Integer
Returns Optional. The number of VM instances in the instance group. For HA cluster master_config groups, must be set to 3. For standard cluster master_config groups, must be set to 1.
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 505 class InstanceGroupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls the use of # [preemptible instances] # (https://cloud.google.com/compute/docs/instances/preemptible) # within the group. module Preemptibility # Preemptibility is unspecified, the system will choose the # appropriate setting for each instance group. PREEMPTIBILITY_UNSPECIFIED = 0 # Instances are non-preemptible. # # This option is allowed for all instance groups and is the only valid # value for Master and Worker instance groups. NON_PREEMPTIBLE = 1 # Instances are preemptible. # # This option is allowed only for secondary worker groups. PREEMPTIBLE = 2 end end |
#preemptibility ⇒ ::Google::Cloud::Dataproc::V1::InstanceGroupConfig::Preemptibility
Returns Optional. Specifies the preemptibility of the instance group.
The default value for master and worker groups is
NON_PREEMPTIBLE. This default cannot be changed.
The default value for secondary instances is
PREEMPTIBLE.
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 505 class InstanceGroupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls the use of # [preemptible instances] # (https://cloud.google.com/compute/docs/instances/preemptible) # within the group. module Preemptibility # Preemptibility is unspecified, the system will choose the # appropriate setting for each instance group. PREEMPTIBILITY_UNSPECIFIED = 0 # Instances are non-preemptible. # # This option is allowed for all instance groups and is the only valid # value for Master and Worker instance groups. NON_PREEMPTIBLE = 1 # Instances are preemptible. # # This option is allowed only for secondary worker groups. PREEMPTIBLE = 2 end end |