Class: Google::Cloud::Dataproc::V1::JobController::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::JobController::Client
- Defined in:
- lib/google/cloud/dataproc/v1/job_controller/client.rb
Overview
Client for the JobController service.
The JobController provides methods to manage jobs.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Client
readonly
Get the associated client for mix-in of the IAMPolicy.
-
#operations_client ⇒ ::Google::Cloud::Dataproc::V1::JobController::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the JobController Client class.
Instance Method Summary collapse
-
#cancel_job(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Dataproc::V1::Job
Starts a job cancellation request.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the JobController Client instance.
-
#delete_job(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes the job from the project.
-
#get_job(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Dataproc::V1::Job
Gets the resource representation for a job in a project.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new JobController client object.
-
#list_jobs(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataproc::V1::Job>
Lists regions/{region}/jobs in a project.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#submit_job(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Dataproc::V1::Job
Submits a job to a cluster.
-
#submit_job_as_operation(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Submits job to a cluster.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_job(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Dataproc::V1::Job
Updates a job in a project.
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new JobController client object.
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/google/cloud/dataproc/v1/job_controller/client.rb', line 158 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/dataproc/v1/jobs_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = Operations.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.universe_domain = @config.universe_domain end @job_controller_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::Dataproc::V1::JobController::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @job_controller_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @iam_policy_client = Google::Iam::V1::IAMPolicy::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @job_controller_stub.endpoint config.universe_domain = @job_controller_stub.universe_domain config.logger = @job_controller_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Client (readonly)
Get the associated client for mix-in of the IAMPolicy.
236 237 238 |
# File 'lib/google/cloud/dataproc/v1/job_controller/client.rb', line 236 def iam_policy_client @iam_policy_client end |
#operations_client ⇒ ::Google::Cloud::Dataproc::V1::JobController::Operations (readonly)
Get the associated client for long-running operations.
229 230 231 |
# File 'lib/google/cloud/dataproc/v1/job_controller/client.rb', line 229 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the JobController Client class.
See Configuration for a description of the configuration fields.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/google/cloud/dataproc/v1/job_controller/client.rb', line 61 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Dataproc", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.submit_job.timeout = 900.0 default_config.rpcs.submit_job.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.submit_job_as_operation.timeout = 900.0 default_config.rpcs.submit_job_as_operation.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_job.timeout = 900.0 default_config.rpcs.get_job.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 13, 14] } default_config.rpcs.list_jobs.timeout = 900.0 default_config.rpcs.list_jobs.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 13, 14] } default_config.rpcs.update_job.timeout = 900.0 default_config.rpcs.update_job.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.cancel_job.timeout = 900.0 default_config.rpcs.cancel_job.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 13, 14] } default_config.rpcs.delete_job.timeout = 900.0 default_config.rpcs.delete_job.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#cancel_job(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::Job #cancel_job(project_id: nil, region: nil, job_id: nil) ⇒ ::Google::Cloud::Dataproc::V1::Job
Starts a job cancellation request. To access the job resource after cancellation, call regions/{region}/jobs.list or regions/{region}/jobs.get.
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 |
# File 'lib/google/cloud/dataproc/v1/job_controller/client.rb', line 849 def cancel_job request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::CancelJobRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.cancel_job..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.project_id header_params["project_id"] = request.project_id end if request.region header_params["region"] = request.region end if request.job_id header_params["job_id"] = request.job_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.cancel_job.timeout, metadata: , retry_policy: @config.rpcs.cancel_job.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @job_controller_stub.call_rpc :cancel_job, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the JobController Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
128 129 130 131 |
# File 'lib/google/cloud/dataproc/v1/job_controller/client.rb', line 128 def configure yield @config if block_given? @config end |
#delete_job(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_job(project_id: nil, region: nil, job_id: nil) ⇒ ::Google::Protobuf::Empty
Deletes the job from the project. If the job is active, the delete fails,
and the response returns FAILED_PRECONDITION.
946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 |
# File 'lib/google/cloud/dataproc/v1/job_controller/client.rb', line 946 def delete_job request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::DeleteJobRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_job..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.project_id header_params["project_id"] = request.project_id end if request.region header_params["region"] = request.region end if request.job_id header_params["job_id"] = request.job_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_job.timeout, metadata: , retry_policy: @config.rpcs.delete_job.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @job_controller_stub.call_rpc :delete_job, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_job(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::Job #get_job(project_id: nil, region: nil, job_id: nil) ⇒ ::Google::Cloud::Dataproc::V1::Job
Gets the resource representation for a job in a project.
519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 |
# File 'lib/google/cloud/dataproc/v1/job_controller/client.rb', line 519 def get_job request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::GetJobRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_job..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.project_id header_params["project_id"] = request.project_id end if request.region header_params["region"] = request.region end if request.job_id header_params["job_id"] = request.job_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_job.timeout, metadata: , retry_policy: @config.rpcs.get_job.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @job_controller_stub.call_rpc :get_job, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_jobs(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataproc::V1::Job> #list_jobs(project_id: nil, region: nil, page_size: nil, page_token: nil, cluster_name: nil, job_state_matcher: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataproc::V1::Job>
Lists regions/{region}/jobs in a project.
645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 |
# File 'lib/google/cloud/dataproc/v1/job_controller/client.rb', line 645 def list_jobs request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::ListJobsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_jobs..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.project_id header_params["project_id"] = request.project_id end if request.region header_params["region"] = request.region end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_jobs.timeout, metadata: , retry_policy: @config.rpcs.list_jobs.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @job_controller_stub.call_rpc :list_jobs, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @job_controller_stub, :list_jobs, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
243 244 245 |
# File 'lib/google/cloud/dataproc/v1/job_controller/client.rb', line 243 def logger @job_controller_stub.logger end |
#submit_job(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::Job #submit_job(project_id: nil, region: nil, job: nil, request_id: nil) ⇒ ::Google::Cloud::Dataproc::V1::Job
Submits a job to a cluster.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/google/cloud/dataproc/v1/job_controller/client.rb', line 311 def submit_job request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::SubmitJobRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.submit_job..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.project_id header_params["project_id"] = request.project_id end if request.region header_params["region"] = request.region end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.submit_job.timeout, metadata: , retry_policy: @config.rpcs.submit_job.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @job_controller_stub.call_rpc :submit_job, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#submit_job_as_operation(request, options = nil) ⇒ ::Gapic::Operation #submit_job_as_operation(project_id: nil, region: nil, job: nil, request_id: nil) ⇒ ::Gapic::Operation
Submits job to a cluster.
424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/google/cloud/dataproc/v1/job_controller/client.rb', line 424 def submit_job_as_operation request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::SubmitJobRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.submit_job_as_operation..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.project_id header_params["project_id"] = request.project_id end if request.region header_params["region"] = request.region end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.submit_job_as_operation.timeout, metadata: , retry_policy: @config.rpcs.submit_job_as_operation.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @job_controller_stub.call_rpc :submit_job_as_operation, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
138 139 140 |
# File 'lib/google/cloud/dataproc/v1/job_controller/client.rb', line 138 def universe_domain @job_controller_stub.universe_domain end |
#update_job(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::Job #update_job(project_id: nil, region: nil, job_id: nil, job: nil, update_mask: nil) ⇒ ::Google::Cloud::Dataproc::V1::Job
Updates a job in a project.
749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 |
# File 'lib/google/cloud/dataproc/v1/job_controller/client.rb', line 749 def update_job request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::UpdateJobRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_job..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.project_id header_params["project_id"] = request.project_id end if request.region header_params["region"] = request.region end if request.job_id header_params["job_id"] = request.job_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_job.timeout, metadata: , retry_policy: @config.rpcs.update_job.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @job_controller_stub.call_rpc :update_job, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |