Class: Google::Cloud::Dataproc::V1::KubernetesSoftwareConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::KubernetesSoftwareConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataproc/v1/shared.rb
Overview
The software configuration for this Dataproc cluster running on Kubernetes.
Defined Under Namespace
Classes: ComponentVersionEntry, PropertiesEntry
Instance Attribute Summary collapse
-
#component_version ⇒ ::Google::Protobuf::Map{::String => ::String}
The components that should be installed in this Dataproc cluster.
-
#properties ⇒ ::Google::Protobuf::Map{::String => ::String}
The properties to set on daemon config files.
Instance Attribute Details
#component_version ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns The components that should be installed in this Dataproc cluster. The key must be a string from the KubernetesComponent enumeration. The value is the version of the software to be installed. At least one entry must be specified.
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'proto_docs/google/cloud/dataproc/v1/shared.rb', line 325 class KubernetesSoftwareConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ComponentVersionEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class PropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#properties ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns The properties to set on daemon config files.
Property keys are specified in prefix:property format, for example
spark:spark.kubernetes.container.image. The following are supported
prefixes and their mappings:
- spark:
spark-defaults.conf
For more information, see Cluster properties.
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'proto_docs/google/cloud/dataproc/v1/shared.rb', line 325 class KubernetesSoftwareConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ComponentVersionEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class PropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |