Class: Google::Cloud::Dataproc::V1::ListBatchesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::ListBatchesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataproc/v1/batches.rb
Overview
A request to list batch workloads in a project.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Optional. The maximum number of batches to return in each response. The service may return fewer than this value. The default page size is 20; the maximum page size is 1000.
78 79 80 81 |
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 78 class ListBatchesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token received from a previous ListBatches call.
Provide this token to retrieve the subsequent page.
78 79 80 81 |
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 78 class ListBatchesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent, which owns this collection of batches.
78 79 80 81 |
# File 'proto_docs/google/cloud/dataproc/v1/batches.rb', line 78 class ListBatchesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |