Class: Google::Cloud::Dataproc::V1::SoftwareConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::SoftwareConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataproc/v1/clusters.rb
Overview
Specifies the selection and config of software inside the cluster.
Defined Under Namespace
Classes: PropertiesEntry
Instance Attribute Summary collapse
-
#image_version ⇒ ::String
Optional.
-
#optional_components ⇒ ::Array<::Google::Cloud::Dataproc::V1::Component>
Optional.
-
#properties ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
Instance Attribute Details
#image_version ⇒ ::String
Returns Optional. The version of software inside the cluster. It must be one of the supported Dataproc Versions, such as "1.2" (including a subminor version, such as "1.2.29"), or the "preview" version. If unspecified, it defaults to the latest Debian version.
934 935 936 937 938 939 940 941 942 943 944 945 946 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 934 class SoftwareConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class PropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#optional_components ⇒ ::Array<::Google::Cloud::Dataproc::V1::Component>
Returns Optional. The set of components to activate on the cluster.
934 935 936 937 938 939 940 941 942 943 944 945 946 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 934 class SoftwareConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class PropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#properties ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. The properties to set on daemon config files.
Property keys are specified in prefix:property format, for example
core:hadoop.tmp.dir. The following are supported prefixes
and their mappings:
- capacity-scheduler:
capacity-scheduler.xml - core:
core-site.xml - distcp:
distcp-default.xml - hdfs:
hdfs-site.xml - hive:
hive-site.xml - mapred:
mapred-site.xml - pig:
pig.properties - spark:
spark-defaults.conf - yarn:
yarn-site.xml
For more information, see Cluster properties.
934 935 936 937 938 939 940 941 942 943 944 945 946 |
# File 'proto_docs/google/cloud/dataproc/v1/clusters.rb', line 934 class SoftwareConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class PropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |