Class: Google::Cloud::Dataproc::V1::WorkflowTemplateService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Dataproc::V1::WorkflowTemplateService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb
Overview
REST client for the WorkflowTemplateService service.
The API interface for managing Workflow Templates in the Dataproc API.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Rest::Client
readonly
Get the associated client for mix-in of the IAMPolicy.
-
#operations_client ⇒ ::Google::Cloud::Dataproc::V1::WorkflowTemplateService::Rest::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the WorkflowTemplateService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the WorkflowTemplateService Client instance.
-
#create_workflow_template(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Dataproc::V1::WorkflowTemplate
Creates new workflow template.
-
#delete_workflow_template(request, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a workflow template.
-
#get_workflow_template(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Dataproc::V1::WorkflowTemplate
Retrieves the latest workflow template.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new WorkflowTemplateService REST client object.
-
#instantiate_inline_workflow_template(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Operation
Instantiates a template and begins execution.
-
#instantiate_workflow_template(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Operation
Instantiates a template and begins execution.
-
#list_workflow_templates(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dataproc::V1::WorkflowTemplate>
Lists workflows that match the specified filter in the request.
-
#update_workflow_template(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Dataproc::V1::WorkflowTemplate
Updates (replaces) workflow template.
Methods included from Paths
#location_path, #node_group_path, #region_path, #service_path, #workflow_template_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new WorkflowTemplateService REST client object.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 148 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-") credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = ::Google::Cloud::Dataproc::V1::WorkflowTemplateService::Rest::Operations.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint end @iam_policy_client = Google::Iam::V1::IAMPolicy::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.bindings_override = @config.bindings_override end @workflow_template_service_stub = ::Google::Cloud::Dataproc::V1::WorkflowTemplateService::Rest::ServiceStub.new endpoint: @config.endpoint, credentials: credentials end |
Instance Attribute Details
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Rest::Client (readonly)
Get the associated client for mix-in of the IAMPolicy.
198 199 200 |
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 198 def iam_policy_client @iam_policy_client end |
#operations_client ⇒ ::Google::Cloud::Dataproc::V1::WorkflowTemplateService::Rest::Operations (readonly)
Get the associated client for long-running operations.
191 192 193 |
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 191 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the WorkflowTemplateService Client class.
See Configuration for a description of the configuration fields.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 60 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Dataproc", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.create_workflow_template.timeout = 600.0 default_config.rpcs.create_workflow_template.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_workflow_template.timeout = 600.0 default_config.rpcs.get_workflow_template.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 13, 14] } default_config.rpcs.instantiate_workflow_template.timeout = 600.0 default_config.rpcs.instantiate_workflow_template.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.instantiate_inline_workflow_template.timeout = 600.0 default_config.rpcs.instantiate_inline_workflow_template.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.update_workflow_template.timeout = 600.0 default_config.rpcs.update_workflow_template.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.list_workflow_templates.timeout = 600.0 default_config.rpcs.list_workflow_templates.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 13, 14] } default_config.rpcs.delete_workflow_template.timeout = 600.0 default_config.rpcs.delete_workflow_template.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the WorkflowTemplateService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
127 128 129 130 |
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 127 def configure yield @config if block_given? @config end |
#create_workflow_template(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::WorkflowTemplate #create_workflow_template(parent: nil, template: nil) ⇒ ::Google::Cloud::Dataproc::V1::WorkflowTemplate
Creates new workflow template.
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 256 def create_workflow_template request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::CreateWorkflowTemplateRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_workflow_template..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION, transports_version_send: [:rest] [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_workflow_template.timeout, metadata: , retry_policy: @config.rpcs.create_workflow_template.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @workflow_template_service_stub.create_workflow_template request, do |result, operation| yield result, operation if block_given? return result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_workflow_template(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_workflow_template(name: nil, version: nil) ⇒ ::Google::Protobuf::Empty
Deletes a workflow template. It does not cancel in-progress workflows.
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 |
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 885 def delete_workflow_template request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::DeleteWorkflowTemplateRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_workflow_template..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION, transports_version_send: [:rest] [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_workflow_template.timeout, metadata: , retry_policy: @config.rpcs.delete_workflow_template.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @workflow_template_service_stub.delete_workflow_template request, do |result, operation| yield result, operation if block_given? return result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_workflow_template(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::WorkflowTemplate #get_workflow_template(name: nil, version: nil) ⇒ ::Google::Cloud::Dataproc::V1::WorkflowTemplate
Retrieves the latest workflow template.
Can retrieve previously instantiated template by specifying optional version parameter.
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 351 def get_workflow_template request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::GetWorkflowTemplateRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_workflow_template..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION, transports_version_send: [:rest] [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_workflow_template.timeout, metadata: , retry_policy: @config.rpcs.get_workflow_template.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @workflow_template_service_stub.get_workflow_template request, do |result, operation| yield result, operation if block_given? return result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#instantiate_inline_workflow_template(request, options = nil) ⇒ ::Gapic::Operation #instantiate_inline_workflow_template(parent: nil, template: nil, request_id: nil) ⇒ ::Gapic::Operation
Instantiates a template and begins execution.
This method is equivalent to executing the sequence CreateWorkflowTemplate, InstantiateWorkflowTemplate, DeleteWorkflowTemplate.
The returned Operation can be used to track execution of workflow by polling operations.get. The Operation will complete when entire workflow is finished.
The running workflow can be aborted via operations.cancel. This will cause any inflight jobs to be cancelled and workflow-owned clusters to be deleted.
The Operation.metadata will be WorkflowMetadata. Also see Using WorkflowMetadata.
On successful completion, Operation.response will be Empty.
615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 |
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 615 def instantiate_inline_workflow_template request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::InstantiateInlineWorkflowTemplateRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.instantiate_inline_workflow_template..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION, transports_version_send: [:rest] [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.instantiate_inline_workflow_template.timeout, metadata: , retry_policy: @config.rpcs.instantiate_inline_workflow_template.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @workflow_template_service_stub.instantiate_inline_workflow_template request, do |result, operation| result = ::Gapic::Operation.new result, @operations_client, options: yield result, operation if block_given? return result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#instantiate_workflow_template(request, options = nil) ⇒ ::Gapic::Operation #instantiate_workflow_template(name: nil, version: nil, request_id: nil, parameters: nil) ⇒ ::Gapic::Operation
Instantiates a template and begins execution.
The returned Operation can be used to track execution of workflow by polling operations.get. The Operation will complete when entire workflow is finished.
The running workflow can be aborted via operations.cancel. This will cause any inflight jobs to be cancelled and workflow-owned clusters to be deleted.
The Operation.metadata will be WorkflowMetadata. Also see Using WorkflowMetadata.
On successful completion, Operation.response will be Empty.
484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 484 def instantiate_workflow_template request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::InstantiateWorkflowTemplateRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.instantiate_workflow_template..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION, transports_version_send: [:rest] [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.instantiate_workflow_template.timeout, metadata: , retry_policy: @config.rpcs.instantiate_workflow_template.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @workflow_template_service_stub.instantiate_workflow_template request, do |result, operation| result = ::Gapic::Operation.new result, @operations_client, options: yield result, operation if block_given? return result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_workflow_templates(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dataproc::V1::WorkflowTemplate> #list_workflow_templates(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Dataproc::V1::WorkflowTemplate>
Lists workflows that match the specified filter in the request.
793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 |
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 793 def list_workflow_templates request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::ListWorkflowTemplatesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_workflow_templates..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION, transports_version_send: [:rest] [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_workflow_templates.timeout, metadata: , retry_policy: @config.rpcs.list_workflow_templates.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @workflow_template_service_stub.list_workflow_templates request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @workflow_template_service_stub, :list_workflow_templates, "templates", request, result, yield result, operation if block_given? return result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#update_workflow_template(request, options = nil) ⇒ ::Google::Cloud::Dataproc::V1::WorkflowTemplate #update_workflow_template(template: nil) ⇒ ::Google::Cloud::Dataproc::V1::WorkflowTemplate
Updates (replaces) workflow template. The updated template must contain version that matches the current server version.
697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 |
# File 'lib/google/cloud/dataproc/v1/workflow_template_service/rest/client.rb', line 697 def update_workflow_template request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataproc::V1::UpdateWorkflowTemplateRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_workflow_template..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataproc::V1::VERSION, transports_version_send: [:rest] [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_workflow_template.timeout, metadata: , retry_policy: @config.rpcs.update_workflow_template.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @workflow_template_service_stub.update_workflow_template request, do |result, operation| yield result, operation if block_given? return result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |